/*
   MAPI Implementation

   OpenChange Project

   Copyright (C) Julien Kerihuel 2006

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/


/* parser auto-generated by mparse */

typedef [v1_enum, flag(NDR_PAHEX)] enum {
	PR_ACKNOWLEDGEMENT_MODE                             = 0x00010003,
	PR_ACKNOWLEDGEMENT_MODE_ERROR                       = 0x0001000a,
	PR_ALTERNATE_RECIPIENT_ALLOWED                      = 0x0002000b,
	PR_ALTERNATE_RECIPIENT_ALLOWED_ERROR                = 0x0002000a,
	PR_AUTHORIZING_USERS                                = 0x00030102,
	PR_AUTHORIZING_USERS_ERROR                          = 0x0003000a,
	PR_AUTO_FORWARD_COMMENT                             = 0x0004001e,
	PR_AUTO_FORWARD_COMMENT_UNICODE                     = 0x0004001f,
	PR_AUTO_FORWARD_COMMENT_ERROR                       = 0x0004000a,
	PR_AUTO_FORWARDED                                   = 0x0005000b,
	PR_AUTO_FORWARDED_ERROR                             = 0x0005000a,
	PR_CONTENT_CONFIDENTIALITY_ALGORITHM_ID             = 0x00060102,
	PR_CONTENT_CONFIDENTIALITY_ALGORITHM_ID_ERROR       = 0x0006000a,
	PR_CONTENT_CORRELATOR                               = 0x00070102,
	PR_CONTENT_CORRELATOR_ERROR                         = 0x0007000a,
	PR_CONTENT_IDENTIFIER                               = 0x0008001e,
	PR_CONTENT_IDENTIFIER_UNICODE                       = 0x0008001f,
	PR_CONTENT_IDENTIFIER_ERROR                         = 0x0008000a,
	PR_CONTENT_LENGTH                                   = 0x00090003,
	PR_CONTENT_LENGTH_ERROR                             = 0x0009000a,
	PR_CONTENT_RETURN_REQUESTED                         = 0x000a000b,
	PR_CONTENT_RETURN_REQUESTED_ERROR                   = 0x000a000a,
	PR_CONVERSATION_KEY                                 = 0x000b0102,
	PR_CONVERSATION_KEY_ERROR                           = 0x000b000a,
	PR_CONVERSION_EITS                                  = 0x000c0102,
	PR_CONVERSION_EITS_ERROR                            = 0x000c000a,
	PR_CONVERSION_WITH_LOSS_PROHIBITED                  = 0x000d000b,
	PR_CONVERSION_WITH_LOSS_PROHIBITED_ERROR            = 0x000d000a,
	PR_CONVERTED_EITS                                   = 0x000e0102,
	PR_CONVERTED_EITS_ERROR                             = 0x000e000a,
	PR_DEFERRED_DELIVERY_TIME                           = 0x000f0040,
	PR_DEFERRED_DELIVERY_TIME_ERROR                     = 0x000f000a,
	PR_DELIVER_TIME                                     = 0x00100040,
	PR_DELIVER_TIME_ERROR                               = 0x0010000a,
	PR_DISCARD_REASON                                   = 0x00110003,
	PR_DISCARD_REASON_ERROR                             = 0x0011000a,
	PR_DISCLOSURE_OF_RECIPIENTS                         = 0x0012000b,
	PR_DISCLOSURE_OF_RECIPIENTS_ERROR                   = 0x0012000a,
	PR_DL_EXPANSION_HISTORY                             = 0x00130102,
	PR_DL_EXPANSION_HISTORY_ERROR                       = 0x0013000a,
	PR_DL_EXPANSION_PROHIBITED                          = 0x0014000b,
	PR_DL_EXPANSION_PROHIBITED_ERROR                    = 0x0014000a,
	PR_EXPIRY_TIME                                      = 0x00150040,
	PR_EXPIRY_TIME_ERROR                                = 0x0015000a,
	PR_IMPLICIT_CONVERSION_PROHIBITED                   = 0x0016000b,
	PR_IMPLICIT_CONVERSION_PROHIBITED_ERROR             = 0x0016000a,
	PR_IMPORTANCE                                       = 0x00170003,
	PR_IMPORTANCE_ERROR                                 = 0x0017000a,
	PR_IPM_ID                                           = 0x00180102,
	PR_IPM_ID_ERROR                                     = 0x0018000a,
	PR_LATEST_DELIVERY_TIME                             = 0x00190040,
	PR_LATEST_DELIVERY_TIME_ERROR                       = 0x0019000a,
	PR_MESSAGE_CLASS                                    = 0x001a001e,
	PR_MESSAGE_CLASS_UNICODE                            = 0x001a001f,
	PR_MESSAGE_CLASS_ERROR                              = 0x001a000a,
	PR_MESSAGE_DELIVERY_ID                              = 0x001b0102,
	PR_MESSAGE_DELIVERY_ID_ERROR                        = 0x001b000a,
	PR_MESSAGE_SECURITY_LABEL                           = 0x001e0102,
	PR_MESSAGE_SECURITY_LABEL_ERROR                     = 0x001e000a,
	PR_OBSOLETED_IPMS                                   = 0x001f0102,
	PR_OBSOLETED_IPMS_ERROR                             = 0x001f000a,
	PR_ORIGINALLY_INTENDED_RECIPIENT_NAME               = 0x00200102,
	PR_ORIGINALLY_INTENDED_RECIPIENT_NAME_ERROR         = 0x0020000a,
	PR_ORIGINAL_EITS                                    = 0x00210102,
	PR_ORIGINAL_EITS_ERROR                              = 0x0021000a,
	PR_ORIGINATOR_CERTIFICATE                           = 0x00220102,
	PR_ORIGINATOR_CERTIFICATE_ERROR                     = 0x0022000a,
	PR_ORIGINATOR_DELIVERY_REPORT_REQUESTED             = 0x0023000b,
	PR_ORIGINATOR_DELIVERY_REPORT_REQUESTED_ERROR       = 0x0023000a,
	PR_ORIGINATOR_RETURN_ADDRESS                        = 0x00240102,
	PR_ORIGINATOR_RETURN_ADDRESS_ERROR                  = 0x0024000a,
	PR_PARENT_KEY                                       = 0x00250102,
	PR_PARENT_KEY_ERROR                                 = 0x0025000a,
	PR_PRIORITY                                         = 0x00260003,
	PR_PRIORITY_ERROR                                   = 0x0026000a,
	PR_ORIGIN_CHECK                                     = 0x00270102,
	PR_ORIGIN_CHECK_ERROR                               = 0x0027000a,
	PR_PROOF_OF_SUBMISSION_REQUESTED                    = 0x0028000b,
	PR_PROOF_OF_SUBMISSION_REQUESTED_ERROR              = 0x0028000a,
	PR_READ_RECEIPT_REQUESTED                           = 0x0029000b,
	PR_READ_RECEIPT_REQUESTED_ERROR                     = 0x0029000a,
	PR_RECEIPT_TIME                                     = 0x002a0040,
	PR_RECEIPT_TIME_ERROR                               = 0x002a000a,
	PR_RECIPIENT_REASSIGNMENT_PROHIBITED                = 0x002b000b,
	PR_RECIPIENT_REASSIGNMENT_PROHIBITED_ERROR          = 0x002b000a,
	PR_REDIRECTION_HISTORY                              = 0x002c0102,
	PR_REDIRECTION_HISTORY_ERROR                        = 0x002c000a,
	PR_RELATED_IPMS                                     = 0x002d0102,
	PR_RELATED_IPMS_ERROR                               = 0x002d000a,
	PR_ORIGINAL_SENSITIVITY                             = 0x002e0003,
	PR_ORIGINAL_SENSITIVITY_ERROR                       = 0x002e000a,
	PR_LANGUAGES                                        = 0x002f001e,
	PR_LANGUAGES_UNICODE                                = 0x002f001f,
	PR_LANGUAGES_ERROR                                  = 0x002f000a,
	PR_REPLY_TIME                                       = 0x00300040,
	PR_REPLY_TIME_ERROR                                 = 0x0030000a,
	PR_REPORT_TAG                                       = 0x00310102,
	PR_REPORT_TAG_ERROR                                 = 0x0031000a,
	PR_REPORT_TIME                                      = 0x00320040,
	PR_REPORT_TIME_ERROR                                = 0x0032000a,
	PR_RETURNED_IPM                                     = 0x0033000b,
	PR_RETURNED_IPM_ERROR                               = 0x0033000a,
	PR_SECURITY                                         = 0x00340003,
	PR_SECURITY_ERROR                                   = 0x0034000a,
	PR_INCOMPLETE_COPY                                  = 0x0035000b,
	PR_INCOMPLETE_COPY_ERROR                            = 0x0035000a,
	PR_SENSITIVITY                                      = 0x00360003,
	PR_SENSITIVITY_ERROR                                = 0x0036000a,
	PR_SUBJECT                                          = 0x0037001e,
	PR_SUBJECT_UNICODE                                  = 0x0037001f,
	PR_SUBJECT_ERROR                                    = 0x0037000a,
	PR_SUBJECT_IPM                                      = 0x00380102,
	PR_SUBJECT_IPM_ERROR                                = 0x0038000a,
	PR_CLIENT_SUBMIT_TIME                               = 0x00390040,
	PR_CLIENT_SUBMIT_TIME_ERROR                         = 0x0039000a,
	PR_REPORT_NAME                                      = 0x003a001e,
	PR_REPORT_NAME_UNICODE                              = 0x003a001f,
	PR_REPORT_NAME_ERROR                                = 0x003a000a,
	PR_SENT_REPRESENTING_SEARCH_KEY                     = 0x003b0102,
	PR_SENT_REPRESENTING_SEARCH_KEY_ERROR               = 0x003b000a,
	PR_X400_CONTENT_TYPE                                = 0x003c0102,
	PR_X400_CONTENT_TYPE_ERROR                          = 0x003c000a,
	PR_SUBJECT_PREFIX                                   = 0x003d001e,
	PR_SUBJECT_PREFIX_UNICODE                           = 0x003d001f,
	PR_SUBJECT_PREFIX_ERROR                             = 0x003d000a,
	PR_NON_RECEIPT_REASON                               = 0x003e0003,
	PR_NON_RECEIPT_REASON_ERROR                         = 0x003e000a,
	PR_RECEIVED_BY_ENTRYID                              = 0x003f0102,
	PR_RECEIVED_BY_ENTRYID_ERROR                        = 0x003f000a,
	PR_RECEIVED_BY_NAME                                 = 0x0040001e,
	PR_RECEIVED_BY_NAME_UNICODE                         = 0x0040001f,
	PR_RECEIVED_BY_NAME_ERROR                           = 0x0040000a,
	PR_SENT_REPRESENTING_ENTRYID                        = 0x00410102,
	PR_SENT_REPRESENTING_ENTRYID_ERROR                  = 0x0041000a,
	PR_SENT_REPRESENTING_NAME                           = 0x0042001e,
	PR_SENT_REPRESENTING_NAME_UNICODE                   = 0x0042001f,
	PR_SENT_REPRESENTING_NAME_ERROR                     = 0x0042000a,
	PR_RCVD_REPRESENTING_ENTRYID                        = 0x00430102,
	PR_RCVD_REPRESENTING_ENTRYID_ERROR                  = 0x0043000a,
	PR_RCVD_REPRESENTING_NAME                           = 0x0044001e,
	PR_RCVD_REPRESENTING_NAME_UNICODE                   = 0x0044001f,
	PR_RCVD_REPRESENTING_NAME_ERROR                     = 0x0044000a,
	PR_REPORT_ENTRYID                                   = 0x00450102,
	PR_REPORT_ENTRYID_ERROR                             = 0x0045000a,
	PR_READ_RECEIPT_ENTRYID                             = 0x00460102,
	PR_READ_RECEIPT_ENTRYID_ERROR                       = 0x0046000a,
	PR_MESSAGE_SUBMISSION_ID                            = 0x00470102,
	PR_MESSAGE_SUBMISSION_ID_ERROR                      = 0x0047000a,
	PR_PROVIDER_SUBMIT_TIME                             = 0x00480040,
	PR_PROVIDER_SUBMIT_TIME_ERROR                       = 0x0048000a,
	PR_ORIGINAL_SUBJECT                                 = 0x0049001e,
	PR_ORIGINAL_SUBJECT_UNICODE                         = 0x0049001f,
	PR_ORIGINAL_SUBJECT_ERROR                           = 0x0049000a,
	PR_DISC_VAL                                         = 0x004a000b,
	PR_DISC_VAL_ERROR                                   = 0x004a000a,
	PR_ORIG_MESSAGE_CLASS                               = 0x004b001e,
	PR_ORIG_MESSAGE_CLASS_UNICODE                       = 0x004b001f,
	PR_ORIG_MESSAGE_CLASS_ERROR                         = 0x004b000a,
	PR_ORIGINAL_AUTHOR_ENTRYID                          = 0x004c0102,
	PR_ORIGINAL_AUTHOR_ENTRYID_ERROR                    = 0x004c000a,
	PR_ORIGINAL_AUTHOR_NAME                             = 0x004d001e,
	PR_ORIGINAL_AUTHOR_NAME_UNICODE                     = 0x004d001f,
	PR_ORIGINAL_AUTHOR_NAME_ERROR                       = 0x004d000a,
	PR_ORIGINAL_SUBMIT_TIME                             = 0x004e0040,
	PR_ORIGINAL_SUBMIT_TIME_ERROR                       = 0x004e000a,
	PR_REPLY_RECIPIENT_ENTRIES                          = 0x004f0102,
	PR_REPLY_RECIPIENT_ENTRIES_ERROR                    = 0x004f000a,
	PR_REPLY_RECIPIENT_NAMES                            = 0x0050001e,
	PR_REPLY_RECIPIENT_NAMES_UNICODE                    = 0x0050001f,
	PR_REPLY_RECIPIENT_NAMES_ERROR                      = 0x0050000a,
	PR_RECEIVED_BY_SEARCH_KEY                           = 0x00510102,
	PR_RECEIVED_BY_SEARCH_KEY_ERROR                     = 0x0051000a,
	PR_RCVD_REPRESENTING_SEARCH_KEY                     = 0x00520102,
	PR_RCVD_REPRESENTING_SEARCH_KEY_ERROR               = 0x0052000a,
	PR_READ_RECEIPT_SEARCH_KEY                          = 0x00530102,
	PR_READ_RECEIPT_SEARCH_KEY_ERROR                    = 0x0053000a,
	PR_REPORT_SEARCH_KEY                                = 0x00540102,
	PR_REPORT_SEARCH_KEY_ERROR                          = 0x0054000a,
	PR_ORIGINAL_DELIVERY_TIME                           = 0x00550040,
	PR_ORIGINAL_DELIVERY_TIME_ERROR                     = 0x0055000a,
	PR_ORIGINAL_AUTHOR_SEARCH_KEY                       = 0x00560102,
	PR_ORIGINAL_AUTHOR_SEARCH_KEY_ERROR                 = 0x0056000a,
	PR_MESSAGE_TO_ME                                    = 0x0057000b,
	PR_MESSAGE_TO_ME_ERROR                              = 0x0057000a,
	PR_MESSAGE_CC_ME                                    = 0x0058000b,
	PR_MESSAGE_CC_ME_ERROR                              = 0x0058000a,
	PR_MESSAGE_RECIP_ME                                 = 0x0059000b,
	PR_MESSAGE_RECIP_ME_ERROR                           = 0x0059000a,
	PR_ORIGINAL_SENDER_NAME                             = 0x005a001e,
	PR_ORIGINAL_SENDER_NAME_UNICODE                     = 0x005a001f,
	PR_ORIGINAL_SENDER_NAME_ERROR                       = 0x005a000a,
	PR_ORIGINAL_SENDER_ENTRYID                          = 0x005b0102,
	PR_ORIGINAL_SENDER_ENTRYID_ERROR                    = 0x005b000a,
	PR_ORIGINAL_SENDER_SEARCH_KEY                       = 0x005c0102,
	PR_ORIGINAL_SENDER_SEARCH_KEY_ERROR                 = 0x005c000a,
	PR_ORIGINAL_SENT_REPRESENTING_NAME                  = 0x005d001e,
	PR_ORIGINAL_SENT_REPRESENTING_NAME_UNICODE          = 0x005d001f,
	PR_ORIGINAL_SENT_REPRESENTING_NAME_ERROR            = 0x005d000a,
	PR_ORIGINAL_SENT_REPRESENTING_ENTRYID               = 0x005e0102,
	PR_ORIGINAL_SENT_REPRESENTING_ENTRYID_ERROR         = 0x005e000a,
	PR_ORIGINAL_SENT_REPRESENTING_SEARCH_KEY            = 0x005f0102,
	PR_ORIGINAL_SENT_REPRESENTING_SEARCH_KEY_ERROR      = 0x005f000a,
	PR_START_DATE                                       = 0x00600040,
	PR_START_DATE_ERROR                                 = 0x0060000a,
	PR_END_DATE                                         = 0x00610040,
	PR_END_DATE_ERROR                                   = 0x0061000a,
	PR_OWNER_APPT_ID                                    = 0x00620003,
	PR_OWNER_APPT_ID_ERROR                              = 0x0062000a,
	PR_RESPONSE_REQUESTED                               = 0x0063000b,
	PR_RESPONSE_REQUESTED_ERROR                         = 0x0063000a,
	PR_SENT_REPRESENTING_ADDRTYPE                       = 0x0064001e,
	PR_SENT_REPRESENTING_ADDRTYPE_UNICODE               = 0x0064001f,
	PR_SENT_REPRESENTING_ADDRTYPE_ERROR                 = 0x0064000a,
	PR_SENT_REPRESENTING_EMAIL_ADDRESS                  = 0x0065001e,
	PR_SENT_REPRESENTING_EMAIL_ADDRESS_UNICODE          = 0x0065001f,
	PR_SENT_REPRESENTING_EMAIL_ADDRESS_ERROR            = 0x0065000a,
	PR_ORIGINAL_SENDER_ADDRTYPE                         = 0x0066001e,
	PR_ORIGINAL_SENDER_ADDRTYPE_UNICODE                 = 0x0066001f,
	PR_ORIGINAL_SENDER_ADDRTYPE_ERROR                   = 0x0066000a,
	PR_ORIGINAL_SENDER_EMAIL_ADDRESS                    = 0x0067001e,
	PR_ORIGINAL_SENDER_EMAIL_ADDRESS_UNICODE            = 0x0067001f,
	PR_ORIGINAL_SENDER_EMAIL_ADDRESS_ERROR              = 0x0067000a,
	PR_ORIGINAL_SENT_REPRESENTING_ADDRTYPE              = 0x0068001e,
	PR_ORIGINAL_SENT_REPRESENTING_ADDRTYPE_UNICODE      = 0x0068001f,
	PR_ORIGINAL_SENT_REPRESENTING_ADDRTYPE_ERROR        = 0x0068000a,
	PR_ORIGINAL_SENT_REPRESENTING_EMAIL_ADDRESS         = 0x0069001e,
	PR_ORIGINAL_SENT_REPRESENTING_EMAIL_ADDRESS_UNICODE = 0x0069001f,
	PR_ORIGINAL_SENT_REPRESENTING_EMAIL_ADDRESS_ERROR   = 0x0069000a,
	PR_CONVERSATION_TOPIC                               = 0x0070001e,
	PR_CONVERSATION_TOPIC_UNICODE                       = 0x0070001f,
	PR_CONVERSATION_TOPIC_ERROR                         = 0x0070000a,
	PR_CONVERSATION_INDEX                               = 0x00710102,
	PR_CONVERSATION_INDEX_ERROR                         = 0x0071000a,
	PR_ORIGINAL_DISPLAY_BCC                             = 0x0072001e,
	PR_ORIGINAL_DISPLAY_BCC_UNICODE                     = 0x0072001f,
	PR_ORIGINAL_DISPLAY_BCC_ERROR                       = 0x0072000a,
	PR_ORIGINAL_DISPLAY_CC                              = 0x0073001e,
	PR_ORIGINAL_DISPLAY_CC_UNICODE                      = 0x0073001f,
	PR_ORIGINAL_DISPLAY_CC_ERROR                        = 0x0073000a,
	PR_ORIGINAL_DISPLAY_TO                              = 0x0074001e,
	PR_ORIGINAL_DISPLAY_TO_UNICODE                      = 0x0074001f,
	PR_ORIGINAL_DISPLAY_TO_ERROR                        = 0x0074000a,
	PR_RECEIVED_BY_ADDRTYPE                             = 0x0075001e,
	PR_RECEIVED_BY_ADDRTYPE_UNICODE                     = 0x0075001f,
	PR_RECEIVED_BY_ADDRTYPE_ERROR                       = 0x0075000a,
	PR_RECEIVED_BY_EMAIL_ADDRESS                        = 0x0076001e,
	PR_RECEIVED_BY_EMAIL_ADDRESS_UNICODE                = 0x0076001f,
	PR_RECEIVED_BY_EMAIL_ADDRESS_ERROR                  = 0x0076000a,
	PR_RCVD_REPRESENTING_ADDRTYPE                       = 0x0077001e,
	PR_RCVD_REPRESENTING_ADDRTYPE_UNICODE               = 0x0077001f,
	PR_RCVD_REPRESENTING_ADDRTYPE_ERROR                 = 0x0077000a,
	PR_RCVD_REPRESENTING_EMAIL_ADDRESS                  = 0x0078001e,
	PR_RCVD_REPRESENTING_EMAIL_ADDRESS_UNICODE          = 0x0078001f,
	PR_RCVD_REPRESENTING_EMAIL_ADDRESS_ERROR            = 0x0078000a,
	PR_ORIGINAL_AUTHOR_ADDRTYPE                         = 0x0079001e,
	PR_ORIGINAL_AUTHOR_ADDRTYPE_UNICODE                 = 0x0079001f,
	PR_ORIGINAL_AUTHOR_ADDRTYPE_ERROR                   = 0x0079000a,
	PR_ORIGINAL_AUTHOR_EMAIL_ADDRESS                    = 0x007a001e,
	PR_ORIGINAL_AUTHOR_EMAIL_ADDRESS_UNICODE            = 0x007a001f,
	PR_ORIGINAL_AUTHOR_EMAIL_ADDRESS_ERROR              = 0x007a000a,
	PR_ORIGINALLY_INTENDED_RECIP_ADDRTYPE               = 0x007b001e,
	PR_ORIGINALLY_INTENDED_RECIP_ADDRTYPE_UNICODE       = 0x007b001f,
	PR_ORIGINALLY_INTENDED_RECIP_ADDRTYPE_ERROR         = 0x007b000a,
	PR_ORIGINALLY_INTENDED_RECIP_EMAIL_ADDRESS          = 0x007c001e,
	PR_ORIGINALLY_INTENDED_RECIP_EMAIL_ADDRESS_UNICODE  = 0x007c001f,
	PR_ORIGINALLY_INTENDED_RECIP_EMAIL_ADDRESS_ERROR    = 0x007c000a,
	PR_TRANSPORT_MESSAGE_HEADERS                        = 0x007d001e,
	PR_TRANSPORT_MESSAGE_HEADERS_UNICODE                = 0x007d001f,
	PR_TRANSPORT_MESSAGE_HEADERS_ERROR                  = 0x007d000a,
	PR_DELEGATION                                       = 0x007e0102,
	PR_DELEGATION_ERROR                                 = 0x007e000a,
	PR_TNEF_CORRELATION_KEY                             = 0x007f0102,
	PR_TNEF_CORRELATION_KEY_ERROR                       = 0x007f000a,
	PR_CONTENT_INTEGRITY_CHECK                          = 0x0c000102,
	PR_CONTENT_INTEGRITY_CHECK_ERROR                    = 0x0c00000a,
	PR_EXPLICIT_CONVERSION                              = 0x0c010003,
	PR_EXPLICIT_CONVERSION_ERROR                        = 0x0c01000a,
	PR_IPM_RETURN_REQUESTED                             = 0x0c02000b,
	PR_IPM_RETURN_REQUESTED_ERROR                       = 0x0c02000a,
	PR_MESSAGE_TOKEN                                    = 0x0c030102,
	PR_MESSAGE_TOKEN_ERROR                              = 0x0c03000a,
	PR_NDR_REASON_CODE                                  = 0x0c040003,
	PR_NDR_REASON_CODE_ERROR                            = 0x0c04000a,
	PR_NDR_DIAG_CODE                                    = 0x0c050003,
	PR_NDR_DIAG_CODE_ERROR                              = 0x0c05000a,
	PR_NON_RECEIPT_NOTIFICATION_REQUESTED               = 0x0c06000b,
	PR_NON_RECEIPT_NOTIFICATION_REQUESTED_ERROR         = 0x0c06000a,
	PR_DELIVERY_POINT                                   = 0x0c070003,
	PR_DELIVERY_POINT_ERROR                             = 0x0c07000a,
	PR_ORIGINATOR_NON_DELIVERY_REPORT_REQUESTED         = 0x0c08000b,
	PR_ORIGINATOR_NON_DELIVERY_REPORT_REQUESTED_ERROR   = 0x0c08000a,
	PR_ORIGINATOR_REQUESTED_ALTERNATE_RECIPIENT         = 0x0c090102,
	PR_ORIGINATOR_REQUESTED_ALTERNATE_RECIPIENT_ERROR   = 0x0c09000a,
	PR_PHYSICAL_DELIVERY_BUREAU_FAX_DELIVERY            = 0x0c0a000b,
	PR_PHYSICAL_DELIVERY_BUREAU_FAX_DELIVERY_ERROR      = 0x0c0a000a,
	PR_PHYSICAL_DELIVERY_MODE                           = 0x0c0b0003,
	PR_PHYSICAL_DELIVERY_MODE_ERROR                     = 0x0c0b000a,
	PR_PHYSICAL_DELIVERY_REPORT_REQUEST                 = 0x0c0c0003,
	PR_PHYSICAL_DELIVERY_REPORT_REQUEST_ERROR           = 0x0c0c000a,
	PR_PHYSICAL_FORWARDING_ADDRESS                      = 0x0c0d0102,
	PR_PHYSICAL_FORWARDING_ADDRESS_ERROR                = 0x0c0d000a,
	PR_PHYSICAL_FORWARDING_ADDRESS_REQUESTED            = 0x0c0e000b,
	PR_PHYSICAL_FORWARDING_ADDRESS_REQUESTED_ERROR      = 0x0c0e000a,
	PR_PHYSICAL_FORWARDING_PROHIBITED                   = 0x0c0f000b,
	PR_PHYSICAL_FORWARDING_PROHIBITED_ERROR             = 0x0c0f000a,
	PR_PHYSICAL_RENDITION_ATTRIBUTES                    = 0x0c100102,
	PR_PHYSICAL_RENDITION_ATTRIBUTES_ERROR              = 0x0c10000a,
	PR_PROOF_OF_DELIVERY                                = 0x0c110102,
	PR_PROOF_OF_DELIVERY_ERROR                          = 0x0c11000a,
	PR_PROOF_OF_DELIVERY_REQUESTED                      = 0x0c12000b,
	PR_PROOF_OF_DELIVERY_REQUESTED_ERROR                = 0x0c12000a,
	PR_RECIPIENT_CERTIFICATE                            = 0x0c130102,
	PR_RECIPIENT_CERTIFICATE_ERROR                      = 0x0c13000a,
	PR_RECIPIENT_NUMBER_FOR_ADVICE                      = 0x0c14001e,
	PR_RECIPIENT_NUMBER_FOR_ADVICE_UNICODE              = 0x0c14001f,
	PR_RECIPIENT_NUMBER_FOR_ADVICE_ERROR                = 0x0c14000a,
	PR_RECIPIENT_TYPE                                   = 0x0c150003,
	PR_RECIPIENT_TYPE_ERROR                             = 0x0c15000a,
	PR_REGISTERED_MAIL_TYPE                             = 0x0c160003,
	PR_REGISTERED_MAIL_TYPE_ERROR                       = 0x0c16000a,
	PR_REPLY_REQUESTED                                  = 0x0c17000b,
	PR_REPLY_REQUESTED_ERROR                            = 0x0c17000a,
	PR_REQUESTED_DELIVERY_METHOD                        = 0x0c180003,
	PR_REQUESTED_DELIVERY_METHOD_ERROR                  = 0x0c18000a,
	PR_SENDER_ENTRYID                                   = 0x0c190102,
	PR_SENDER_ENTRYID_ERROR                             = 0x0c19000a,
	PR_SENDER_NAME                                      = 0x0c1a001e,
	PR_SENDER_NAME_UNICODE                              = 0x0c1a001f,
	PR_SENDER_NAME_ERROR                                = 0x0c1a000a,
	PR_SUPPLEMENTARY_INFO                               = 0x0c1b001e,
	PR_SUPPLEMENTARY_INFO_UNICODE                       = 0x0c1b001f,
	PR_SUPPLEMENTARY_INFO_ERROR                         = 0x0c1b000a,
	PR_TYPE_OF_MTS_USER                                 = 0x0c1c0003,
	PR_TYPE_OF_MTS_USER_ERROR                           = 0x0c1c000a,
	PR_SENDER_SEARCH_KEY                                = 0x0c1d0102,
	PR_SENDER_SEARCH_KEY_ERROR                          = 0x0c1d000a,
	PR_SENDER_ADDRTYPE                                  = 0x0c1e001e,
	PR_SENDER_ADDRTYPE_UNICODE                          = 0x0c1e001f,
	PR_SENDER_ADDRTYPE_ERROR                            = 0x0c1e000a,
	PR_SENDER_EMAIL_ADDRESS                             = 0x0c1f001e,
	PR_SENDER_EMAIL_ADDRESS_UNICODE                     = 0x0c1f001f,
	PR_SENDER_EMAIL_ADDRESS_ERROR                       = 0x0c1f000a,
	PR_CURRENT_VERSION                                  = 0x0e000014,
	PR_CURRENT_VERSION_ERROR                            = 0x0e00000a,
	PR_DELETE_AFTER_SUBMIT                              = 0x0e01000b,
	PR_DELETE_AFTER_SUBMIT_ERROR                        = 0x0e01000a,
	PR_DISPLAY_BCC                                      = 0x0e02001e,
	PR_DISPLAY_BCC_UNICODE                              = 0x0e02001f,
	PR_DISPLAY_BCC_ERROR                                = 0x0e02000a,
	PR_DISPLAY_CC                                       = 0x0e03001e,
	PR_DISPLAY_CC_UNICODE                               = 0x0e03001f,
	PR_DISPLAY_CC_ERROR                                 = 0x0e03000a,
	PR_DISPLAY_TO                                       = 0x0e04001e,
	PR_DISPLAY_TO_UNICODE                               = 0x0e04001f,
	PR_DISPLAY_TO_ERROR                                 = 0x0e04000a,
	PR_PARENT_DISPLAY                                   = 0x0e05001e,
	PR_PARENT_DISPLAY_UNICODE                           = 0x0e05001f,
	PR_PARENT_DISPLAY_ERROR                             = 0x0e05000a,
	PR_MESSAGE_DELIVERY_TIME                            = 0x0e060040,
	PR_MESSAGE_DELIVERY_TIME_ERROR                      = 0x0e06000a,
	PR_MESSAGE_FLAGS                                    = 0x0e070003,
	PR_MESSAGE_FLAGS_ERROR                              = 0x0e07000a,
	PR_MESSAGE_SIZE                                     = 0x0e080003,
	PR_MESSAGE_SIZE_ERROR                               = 0x0e08000a,
	PR_MESSAGE_SIZE_EXTENDED                            = 0x0e080014,
	PR_PARENT_ENTRYID                                   = 0x0e090102,
	PR_PARENT_ENTRYID_ERROR                             = 0x0e09000a,
	PR_SENTMAIL_ENTRYID                                 = 0x0e0a0102,
	PR_SENTMAIL_ENTRYID_ERROR                           = 0x0e0a000a,
	PR_CORRELATE                                        = 0x0e0c000b,
	PR_CORRELATE_ERROR                                  = 0x0e0c000a,
	PR_CORRELATE_MTSID                                  = 0x0e0d0102,
	PR_CORRELATE_MTSID_ERROR                            = 0x0e0d000a,
	PR_DISCRETE_VALUES                                  = 0x0e0e000b,
	PR_DISCRETE_VALUES_ERROR                            = 0x0e0e000a,
	PR_RESPONSIBILITY                                   = 0x0e0f000b,
	PR_RESPONSIBILITY_ERROR                             = 0x0e0f000a,
	PR_SPOOLER_STATUS                                   = 0x0e100003,
	PR_SPOOLER_STATUS_ERROR                             = 0x0e10000a,
	PR_TRANSPORT_STATUS                                 = 0x0e110003,
	PR_TRANSPORT_STATUS_ERROR                           = 0x0e11000a,
	PR_MESSAGE_RECIPIENTS                               = 0x0e12000d,
	PR_MESSAGE_RECIPIENTS_ERROR                         = 0x0e12000a,
	PR_MESSAGE_ATTACHMENTS                              = 0x0e13000d,
	PR_MESSAGE_ATTACHMENTS_ERROR                        = 0x0e13000a,
	PR_SUBMIT_FLAGS                                     = 0x0e140003,
	PR_SUBMIT_FLAGS_ERROR                               = 0x0e14000a,
	PR_RECIPIENT_STATUS                                 = 0x0e150003,
	PR_RECIPIENT_STATUS_ERROR                           = 0x0e15000a,
	PR_TRANSPORT_KEY                                    = 0x0e160003,
	PR_TRANSPORT_KEY_ERROR                              = 0x0e16000a,
	PR_MSG_STATUS                                       = 0x0e170003,
	PR_MSG_STATUS_ERROR                                 = 0x0e17000a,
	PR_MESSAGE_DOWNLOAD_TIME                            = 0x0e180003,
	PR_MESSAGE_DOWNLOAD_TIME_ERROR                      = 0x0e18000a,
	PR_CREATION_VERSION                                 = 0x0e190014,
	PR_CREATION_VERSION_ERROR                           = 0x0e19000a,
	PR_MODIFY_VERSION                                   = 0x0e1a0014,
	PR_MODIFY_VERSION_ERROR                             = 0x0e1a000a,
	PR_HASATTACH                                        = 0x0e1b000b,
	PR_HASATTACH_ERROR                                  = 0x0e1b000a,
	PR_BODY_CRC                                         = 0x0e1c0003,
	PR_BODY_CRC_ERROR                                   = 0x0e1c000a,
	PR_NORMALIZED_SUBJECT                               = 0x0e1d001e,
	PR_NORMALIZED_SUBJECT_UNICODE                       = 0x0e1d001f,
	PR_NORMALIZED_SUBJECT_ERROR                         = 0x0e1d000a,
	PR_RTF_IN_SYNC                                      = 0x0e1f000b,
	PR_RTF_IN_SYNC_ERROR                                = 0x0e1f000a,
	PR_ATTACH_SIZE                                      = 0x0e200003,
	PR_ATTACH_SIZE_ERROR                                = 0x0e20000a,
	PR_ATTACH_NUM                                       = 0x0e210003,
	PR_ATTACH_NUM_ERROR                                 = 0x0e21000a,
	PR_PREPROCESS                                       = 0x0e22000b,
	PR_PREPROCESS_ERROR                                 = 0x0e22000a,
	PR_INTERNET_ARTICLE_NUMBER                          = 0x0e230003,
	PR_INTERNET_ARTICLE_NUMBER_ERROR                    = 0x0e23000a,
	PR_NEWSGROUP_NAME                                   = 0x0e24001e,
	PR_NEWSGROUP_NAME_UNICODE                           = 0x0e24001f,
	PR_NEWSGROUP_NAME_ERROR                             = 0x0e24000a,
	PR_ORIGINATING_MTA_CERTIFICATE                      = 0x0e250102,
	PR_ORIGINATING_MTA_CERTIFICATE_ERROR                = 0x0e25000a,
	PR_PROOF_OF_SUBMISSION                              = 0x0e260102,
	PR_PROOF_OF_SUBMISSION_ERROR                        = 0x0e26000a,
	PR_NT_SECURITY_DESCRIPTOR                           = 0x0e270102,
	PR_NT_SECURITY_DESCRIPTOR_ERROR                     = 0x0e27000a,
	PR_CREATOR_SID                                      = 0x0e580102,
	PR_CREATOR_SID_ERROR                                = 0x0e58000a,
	PR_LAST_MODIFIER_SID                                = 0x0e590102,
	PR_LAST_MODIFIER_SID_ERROR                          = 0x0e59000a,
	PR_MIME_HANDLER_CLASSIDS                            = 0x0e5e0048,
	PR_MIME_HANDLER_CLASSIDS_ERROR                      = 0x0e5e000a,
	PR_URL_COMP_NAME_POSTFIX                            = 0x0e610003,
	PR_URL_COMP_NAME_POSTFIX_ERROR                      = 0x0e61000a,
	PR_URL_COMP_NAME_SET                                = 0x0e62000b,
	PR_URL_COMP_NAME_SET_ERROR                          = 0x0e62000a,
	PR_SUBFOLDER_CT                                     = 0x0e630003,
	PR_SUBFOLDER_CT_ERROR                               = 0x0e63000a,
	PR_DELETED_SUBFOLDER_CT                             = 0x0e640003,
	PR_DELETED_SUBFOLDER_CT_ERROR                       = 0x0e64000a,
	PR_DELETE_TIME                                      = 0x0e660040,
	PR_DELETE_TIME_ERROR                                = 0x0e66000a,
	PR_AGE_LIMIT                                        = 0x0e670102,
	PR_AGE_LIMIT_ERROR                                  = 0x0e67000a,
	PR_TRUST_SENDER                                     = 0x0e790003,
	PR_TRUST_SENDER_ERROR                               = 0x0e79000a,
	PR_ATTACH_VIRUS_SCAN_INFO                           = 0x0e960102,
	PR_ATTACH_VIRUS_SCAN_INFO_ERROR                     = 0x0e96000a,
	PR_ACCESS                                           = 0x0ff40003,
	PR_ACCESS_ERROR                                     = 0x0ff4000a,
	PR_ROW_TYPE                                         = 0x0ff50003,
	PR_ROW_TYPE_ERROR                                   = 0x0ff5000a,
	PR_INSTANCE_KEY                                     = 0x0ff60102,
	PR_INSTANCE_KEY_ERROR                               = 0x0ff6000a,
	PR_ACCESS_LEVEL                                     = 0x0ff70003,
	PR_ACCESS_LEVEL_ERROR                               = 0x0ff7000a,
	PR_MAPPING_SIGNATURE                                = 0x0ff80102,
	PR_MAPPING_SIGNATURE_ERROR                          = 0x0ff8000a,
	PR_RECORD_KEY                                       = 0x0ff90102,
	PR_RECORD_KEY_ERROR                                 = 0x0ff9000a,
	PR_STORE_RECORD_KEY                                 = 0x0ffa0102,
	PR_STORE_RECORD_KEY_ERROR                           = 0x0ffa000a,
	PR_STORE_ENTRYID                                    = 0x0ffb0102,
	PR_STORE_ENTRYID_ERROR                              = 0x0ffb000a,
	PR_MINI_ICON                                        = 0x0ffc0102,
	PR_MINI_ICON_ERROR                                  = 0x0ffc000a,
	PR_ICON                                             = 0x0ffd0102,
	PR_ICON_ERROR                                       = 0x0ffd000a,
	PR_OBJECT_TYPE                                      = 0x0ffe0003,
	PR_OBJECT_TYPE_ERROR                                = 0x0ffe000a,
	PR_ENTRYID                                          = 0x0fff0102,
	PR_ENTRYID_ERROR                                    = 0x0fff000a,
	PR_BODY                                             = 0x1000001e,
	PR_BODY_UNICODE                                     = 0x1000001f,
	PR_BODY_ERROR                                       = 0x1000000a,
	PR_REPORT_TEXT                                      = 0x1001001e,
	PR_REPORT_TEXT_UNICODE                              = 0x1001001f,
	PR_REPORT_TEXT_ERROR                                = 0x1001000a,
	PR_ORIGINATOR_AND_DL_EXPANSION_HISTORY              = 0x10020102,
	PR_ORIGINATOR_AND_DL_EXPANSION_HISTORY_ERROR        = 0x1002000a,
	PR_REPORTING_DL_NAME                                = 0x10030102,
	PR_REPORTING_DL_NAME_ERROR                          = 0x1003000a,
	PR_REPORTING_MTA_CERTIFICATE                        = 0x10040102,
	PR_REPORTING_MTA_CERTIFICATE_ERROR                  = 0x1004000a,
	PR_RTF_SYNC_BODY_CRC                                = 0x10060003,
	PR_RTF_SYNC_BODY_CRC_ERROR                          = 0x1006000a,
	PR_RTF_SYNC_BODY_COUNT                              = 0x10070003,
	PR_RTF_SYNC_BODY_COUNT_ERROR                        = 0x1007000a,
	PR_RTF_SYNC_BODY_TAG                                = 0x1008001e,
	PR_RTF_SYNC_BODY_TAG_UNICODE                        = 0x1008001f,
	PR_RTF_SYNC_BODY_TAG_ERROR                          = 0x1008000a,
	PR_RTF_COMPRESSED                                   = 0x10090102,
	PR_RTF_COMPRESSED_ERROR                             = 0x1009000a,
	PR_RTF_SYNC_PREFIX_COUNT                            = 0x10100003,
	PR_RTF_SYNC_PREFIX_COUNT_ERROR                      = 0x1010000a,
	PR_RTF_SYNC_TRAILING_COUNT                          = 0x10110003,
	PR_RTF_SYNC_TRAILING_COUNT_ERROR                    = 0x1011000a,
	PR_ORIGINALLY_INTENDED_RECIP_ENTRYID                = 0x10120102,
	PR_ORIGINALLY_INTENDED_RECIP_ENTRYID_ERROR          = 0x1012000a,
	PR_HTML                                             = 0x10130102,
	PR_HTML_ERROR                                       = 0x1013000a,
	PR_INTERNET_APPROVED                                = 0x1030001e,
	PR_INTERNET_APPROVED_UNICODE                        = 0x1030001f,
	PR_INTERNET_APPROVED_ERROR                          = 0x1030000a,
	PR_INTERNET_CONTROL                                 = 0x1031001e,
	PR_INTERNET_CONTROL_UNICODE                         = 0x1031001f,
	PR_INTERNET_CONTROL_ERROR                           = 0x1031000a,
	PR_INTERNET_DISTRIBUTION                            = 0x1032001e,
	PR_INTERNET_DISTRIBUTION_UNICODE                    = 0x1032001f,
	PR_INTERNET_DISTRIBUTION_ERROR                      = 0x1032000a,
	PR_INTERNET_FOLLOWUP_TO                             = 0x1033001e,
	PR_INTERNET_FOLLOWUP_TO_UNICODE                     = 0x1033001f,
	PR_INTERNET_FOLLOWUP_TO_ERROR                       = 0x1033000a,
	PR_INTERNET_LINES                                   = 0x10340003,
	PR_INTERNET_LINES_ERROR                             = 0x1034000a,
	PR_INTERNET_MESSAGE_ID                              = 0x1035001e,
	PR_INTERNET_MESSAGE_ID_UNICODE                      = 0x1035001f,
	PR_INTERNET_MESSAGE_ID_ERROR                        = 0x1035000a,
	PR_INTERNET_NEWSGROUPS                              = 0x1036001e,
	PR_INTERNET_NEWSGROUPS_UNICODE                      = 0x1036001f,
	PR_INTERNET_NEWSGROUPS_ERROR                        = 0x1036000a,
	PR_INTERNET_ORGANIZATION                            = 0x1037001e,
	PR_INTERNET_ORGANIZATION_UNICODE                    = 0x1037001f,
	PR_INTERNET_ORGANIZATION_ERROR                      = 0x1037000a,
	PR_INTERNET_NNTP_PATH                               = 0x1038001e,
	PR_INTERNET_NNTP_PATH_UNICODE                       = 0x1038001f,
	PR_INTERNET_NNTP_PATH_ERROR                         = 0x1038000a,
	PR_INTERNET_REFERENCES                              = 0x1039001e,
	PR_INTERNET_REFERENCES_UNICODE                      = 0x1039001f,
	PR_INTERNET_REFERENCES_ERROR                        = 0x1039000a,
	PR_SUPERSEDES                                       = 0x103a001e,
	PR_SUPERSEDES_UNICODE                               = 0x103a001f,
	PR_SUPERSEDES_ERROR                                 = 0x103a000a,
	PR_POST_FOLDER_ENTRIES                              = 0x103b0102,
	PR_POST_FOLDER_ENTRIES_ERROR                        = 0x103b000a,
	PR_POST_FOLDER_NAMES                                = 0x103c001e,
	PR_POST_FOLDER_NAMES_UNICODE                        = 0x103c001f,
	PR_POST_FOLDER_NAMES_ERROR                          = 0x103c000a,
	PR_POST_REPLY_FOLDER_ENTRIES                        = 0x103d0102,
	PR_POST_REPLY_FOLDER_ENTRIES_ERROR                  = 0x103d000a,
	PR_POST_REPLY_FOLDER_NAMES                          = 0x103e001e,
	PR_POST_REPLY_FOLDER_NAMES_UNICODE                  = 0x103e001f,
	PR_POST_REPLY_FOLDER_NAMES_ERROR                    = 0x103e000a,
	PR_POST_REPLY_DENIED                                = 0x103f0102,
	PR_POST_REPLY_DENIED_ERROR                          = 0x103f000a,
	PR_NNTP_XREF                                        = 0x1040001e,
	PR_NNTP_XREF_UNICODE                                = 0x1040001f,
	PR_NNTP_XREF_ERROR                                  = 0x1040000a,
	PR_INTERNET_PRECEDENCE                              = 0x1041001e,
	PR_INTERNET_PRECEDENCE_UNICODE                      = 0x1041001f,
	PR_INTERNET_PRECEDENCE_ERROR                        = 0x1041000a,
	PR_IN_REPLY_TO_ID                                   = 0x1042001e,
	PR_IN_REPLY_TO_ID_UNICODE                           = 0x1042001f,
	PR_IN_REPLY_TO_ID_ERROR                             = 0x1042000a,
	PR_LIST_HELP                                        = 0x1043001e,
	PR_LIST_HELP_UNICODE                                = 0x1043001f,
	PR_LIST_HELP_ERROR                                  = 0x1043000a,
	PR_LIST_SUBSCRIBE                                   = 0x1044001e,
	PR_LIST_SUBSCRIBE_UNICODE                           = 0x1044001f,
	PR_LIST_SUBSCRIBE_ERROR                             = 0x1044000a,
	PR_LIST_UNSUBSCRIBE                                 = 0x1045001e,
	PR_LIST_UNSUBSCRIBE_UNICODE                         = 0x1045001f,
	PR_LIST_UNSUBSCRIBE_ERROR                           = 0x1045000a,
	PR_ACTION                                           = 0x10800003,
	PR_ACTION_ERROR                                     = 0x1080000a,
	PR_ACTION_FLAG                                      = 0x10810003,
	PR_ACTION_FLAG_ERROR                                = 0x1081000a,
	PR_ACTION_DATE                                      = 0x10820040,
	PR_ACTION_DATE_ERROR                                = 0x1082000a,
	PR_FLAG_STATUS                                      = 0x10900003,
	PR_FLAG_STATUS_ERROR                                = 0x1090000a,
	PR_FLAG_COMPLETE                                    = 0x10910040,
	PR_FLAG_COMPLETE_ERROR                              = 0x1091000a,
	PR_SMTP_TEMP_TBL_DATA                               = 0x10c00102,
	PR_SMTP_TEMP_TBL_DATA_ERROR                         = 0x10c0000a,
	PR_SMTP_TEMP_TBL_DATA_2                             = 0x10c10003,
	PR_SMTP_TEMP_TBL_DATA_2_ERROR                       = 0x10c1000a,
	PR_SMTP_TEMP_TBL_DATA_3                             = 0x10c20102,
	PR_SMTP_TEMP_TBL_DATA_3_ERROR                       = 0x10c2000a,
	PR_CAL_START_TIME                                   = 0x10c30040,
	PR_CAL_START_TIME_ERROR                             = 0x10c3000a,
	PR_CAL_END_TIME                                     = 0x10c40040,
	PR_CAL_END_TIME_ERROR                               = 0x10c4000a,
	PR_CAL_RECURRING_ID                                 = 0x10c50040,
	PR_CAL_RECURRING_ID_ERROR                           = 0x10c5000a,
	PR_DAV_SUBMIT_DATA                                  = 0x10c6001e,
	PR_DAV_SUBMIT_DATA_UNICODE                          = 0x10c6001f,
	PR_DAV_SUBMIT_DATA_ERROR                            = 0x10c6000a,
	PR_CDO_EXPANSION_INDEX                              = 0x10c70003,
	PR_CDO_EXPANSION_INDEX_ERROR                        = 0x10c7000a,
	PR_IFS_INTERNAL_DATA                                = 0x10c80102,
	PR_IFS_INTERNAL_DATA_ERROR                          = 0x10c8000a,
	PR_CAL_REMINDER_NEXT_TIME                           = 0x10ca0040,
	PR_CAL_REMINDER_NEXT_TIME_ERROR                     = 0x10ca000a,
	PR_OWA_URL                                          = 0x10f1001e,
	PR_OWA_URL_UNICODE                                  = 0x10f1001f,
	PR_OWA_URL_ERROR                                    = 0x10f1000a,
	PR_DISABLE_FULL_FIDELITY                            = 0x10f2000b,
	PR_DISABLE_FULL_FIDELITY_ERROR                      = 0x10f2000a,
	PR_URL_COMP_NAME                                    = 0x10f3001e,
	PR_URL_COMP_NAME_UNICODE                            = 0x10f3001f,
	PR_URL_COMP_NAME_ERROR                              = 0x10f3000a,
	PR_ATTR_HIDDEN                                      = 0x10f4000b,
	PR_ATTR_HIDDEN_ERROR                                = 0x10f4000a,
	PR_ATTR_SYSTEM                                      = 0x10f5000b,
	PR_ATTR_SYSTEM_ERROR                                = 0x10f5000a,
	PR_ATTR_READONLY                                    = 0x10f6000b,
	PR_ATTR_READONLY_ERROR                              = 0x10f6000a,
	PR_P1_CONTENT                                       = 0x11000102,
	PR_P1_CONTENT_ERROR                                 = 0x1100000a,
	PR_P1_CONTENT_TYPE                                  = 0x11010102,
	PR_P1_CONTENT_TYPE_ERROR                            = 0x1101000a,
	PR_ROWID                                            = 0x30000003,
	PR_ROWID_ERROR                                      = 0x3000000a,
	PR_DISPLAY_NAME                                     = 0x3001001e,
	PR_DISPLAY_NAME_UNICODE                             = 0x3001001f,
	PR_DISPLAY_NAME_ERROR                               = 0x3001000a,
	PR_ADDRTYPE                                         = 0x3002001e,
	PR_ADDRTYPE_UNICODE                                 = 0x3002001f,
	PR_ADDRTYPE_ERROR                                   = 0x3002000a,
	PR_EMAIL_ADDRESS                                    = 0x3003001e,
	PR_EMAIL_ADDRESS_UNICODE                            = 0x3003001f,
	PR_EMAIL_ADDRESS_ERROR                              = 0x3003000a,
	PR_COMMENT                                          = 0x3004001e,
	PR_COMMENT_UNICODE                                  = 0x3004001f,
	PR_COMMENT_ERROR                                    = 0x3004000a,
	PR_DEPTH                                            = 0x30050003,
	PR_DEPTH_ERROR                                      = 0x3005000a,
	PR_PROVIDER_DISPLAY                                 = 0x3006001e,
	PR_PROVIDER_DISPLAY_UNICODE                         = 0x3006001f,
	PR_PROVIDER_DISPLAY_ERROR                           = 0x3006000a,
	PR_CREATION_TIME                                    = 0x30070040,
	PR_CREATION_TIME_ERROR                              = 0x3007000a,
	PR_LAST_MODIFICATION_TIME                           = 0x30080040,
	PR_LAST_MODIFICATION_TIME_ERROR                     = 0x3008000a,
	PR_RESOURCE_FLAGS                                   = 0x30090003,
	PR_RESOURCE_FLAGS_ERROR                             = 0x3009000a,
	PR_PROVIDER_DLL_NAME                                = 0x300a001e,
	PR_PROVIDER_DLL_NAME_UNICODE                        = 0x300a001f,
	PR_PROVIDER_DLL_NAME_ERROR                          = 0x300a000a,
	PR_SEARCH_KEY                                       = 0x300b0102,
	PR_SEARCH_KEY_ERROR                                 = 0x300b000a,
	PR_PROVIDER_UID                                     = 0x300c0102,
	PR_PROVIDER_UID_ERROR                               = 0x300c000a,
	PR_PROVIDER_ORDINAL                                 = 0x300d0003,
	PR_PROVIDER_ORDINAL_ERROR                           = 0x300d000a,
	PR_FORM_VERSION                                     = 0x3301001e,
	PR_FORM_VERSION_UNICODE                             = 0x3301001f,
	PR_FORM_VERSION_ERROR                               = 0x3301000a,
	PR_FORM_CLSID                                       = 0x33020048,
	PR_FORM_CLSID_ERROR                                 = 0x3302000a,
	PR_FORM_CONTACT_NAME                                = 0x3303001e,
	PR_FORM_CONTACT_NAME_UNICODE                        = 0x3303001f,
	PR_FORM_CONTACT_NAME_ERROR                          = 0x3303000a,
	PR_FORM_CATEGORY                                    = 0x3304001e,
	PR_FORM_CATEGORY_UNICODE                            = 0x3304001f,
	PR_FORM_CATEGORY_ERROR                              = 0x3304000a,
	PR_FORM_CATEGORY_SUB                                = 0x3305001e,
	PR_FORM_CATEGORY_SUB_UNICODE                        = 0x3305001f,
	PR_FORM_CATEGORY_SUB_ERROR                          = 0x3305000a,
	PR_FORM_HOST_MAP                                    = 0x33061003,
	PR_FORM_HOST_MAP_ERROR                              = 0x3306000a,
	PR_FORM_HIDDEN                                      = 0x3307000b,
	PR_FORM_HIDDEN_ERROR                                = 0x3307000a,
	PR_FORM_DESIGNER_NAME                               = 0x3308001e,
	PR_FORM_DESIGNER_NAME_UNICODE                       = 0x3308001f,
	PR_FORM_DESIGNER_NAME_ERROR                         = 0x3308000a,
	PR_FORM_DESIGNER_GUID                               = 0x33090048,
	PR_FORM_DESIGNER_GUID_ERROR                         = 0x3309000a,
	PR_FORM_MESSAGE_BEHAVIOR                            = 0x330a0003,
	PR_FORM_MESSAGE_BEHAVIOR_ERROR                      = 0x330a000a,
	PR_DEFAULT_STORE                                    = 0x3400000b,
	PR_DEFAULT_STORE_ERROR                              = 0x3400000a,
	PR_STORE_SUPPORT_MASK                               = 0x340d0003,
	PR_STORE_SUPPORT_MASK_ERROR                         = 0x340d000a,
	PR_STORE_STATE                                      = 0x340e0003,
	PR_STORE_STATE_ERROR                                = 0x340e000a,
	PR_IPM_SUBTREE_SEARCH_KEY                           = 0x34100102,
	PR_IPM_SUBTREE_SEARCH_KEY_ERROR                     = 0x3410000a,
	PR_IPM_OUTBOX_SEARCH_KEY                            = 0x34110102,
	PR_IPM_OUTBOX_SEARCH_KEY_ERROR                      = 0x3411000a,
	PR_IPM_WASTEBASKET_SEARCH_KEY                       = 0x34120102,
	PR_IPM_WASTEBASKET_SEARCH_KEY_ERROR                 = 0x3412000a,
	PR_IPM_SENTMAIL_SEARCH_KEY                          = 0x34130102,
	PR_IPM_SENTMAIL_SEARCH_KEY_ERROR                    = 0x3413000a,
	PR_MDB_PROVIDER                                     = 0x34140102,
	PR_MDB_PROVIDER_ERROR                               = 0x3414000a,
	PR_RECEIVE_FOLDER_SETTINGS                          = 0x3415000d,
	PR_RECEIVE_FOLDER_SETTINGS_ERROR                    = 0x3415000a,
	PR_VALID_FOLDER_MASK                                = 0x35df0003,
	PR_VALID_FOLDER_MASK_ERROR                          = 0x35df000a,
	PR_IPM_SUBTREE_ENTRYID                              = 0x35e00102,
	PR_IPM_SUBTREE_ENTRYID_ERROR                        = 0x35e0000a,
	PR_IPM_OUTBOX_ENTRYID                               = 0x35e20102,
	PR_IPM_OUTBOX_ENTRYID_ERROR                         = 0x35e2000a,
	PR_IPM_WASTEBASKET_ENTRYID                          = 0x35e30102,
	PR_IPM_WASTEBASKET_ENTRYID_ERROR                    = 0x35e3000a,
	PR_IPM_SENTMAIL_ENTRYID                             = 0x35e40102,
	PR_IPM_SENTMAIL_ENTRYID_ERROR                       = 0x35e4000a,
	PR_VIEWS_ENTRYID                                    = 0x35e50102,
	PR_VIEWS_ENTRYID_ERROR                              = 0x35e5000a,
	PR_COMMON_VIEWS_ENTRYID                             = 0x35e60102,
	PR_COMMON_VIEWS_ENTRYID_ERROR                       = 0x35e6000a,
	PR_FINDER_ENTRYID                                   = 0x35e70102,
	PR_FINDER_ENTRYID_ERROR                             = 0x35e7000a,
	PR_CONTAINER_FLAGS                                  = 0x36000003,
	PR_CONTAINER_FLAGS_ERROR                            = 0x3600000a,
	PR_FOLDER_TYPE                                      = 0x36010003,
	PR_FOLDER_TYPE_ERROR                                = 0x3601000a,
	PR_CONTENT_COUNT                                    = 0x36020003,
	PR_CONTENT_COUNT_ERROR                              = 0x3602000a,
	PR_CONTENT_UNREAD                                   = 0x36030003,
	PR_CONTENT_UNREAD_ERROR                             = 0x3603000a,
	PR_CREATE_TEMPLATES                                 = 0x3604000d,
	PR_CREATE_TEMPLATES_ERROR                           = 0x3604000a,
	PR_DETAILS_TABLE                                    = 0x3605000d,
	PR_DETAILS_TABLE_ERROR                              = 0x3605000a,
	PR_SEARCH                                           = 0x3607000d,
	PR_SEARCH_ERROR                                     = 0x3607000a,
	PR_SELECTABLE                                       = 0x3609000b,
	PR_SELECTABLE_ERROR                                 = 0x3609000a,
	PR_SUBFOLDERS                                       = 0x360a000b,
	PR_SUBFOLDERS_ERROR                                 = 0x360a000a,
	PR_STATUS                                           = 0x360b0003,
	PR_STATUS_ERROR                                     = 0x360b000a,
	PR_ANR                                              = 0x360c001e,
	PR_ANR_UNICODE                                      = 0x360c001f,
	PR_ANR_ERROR                                        = 0x360c000a,
	PR_CONTENTS_SORT_ORDER                              = 0x360d1003,
	PR_CONTENTS_SORT_ORDER_ERROR                        = 0x360d000a,
	PR_CONTAINER_HIERARCHY                              = 0x360e000d,
	PR_CONTAINER_HIERARCHY_ERROR                        = 0x360e000a,
	PR_CONTAINER_CONTENTS                               = 0x360f000d,
	PR_CONTAINER_CONTENTS_ERROR                         = 0x360f000a,
	PR_FOLDER_ASSOCIATED_CONTENTS                       = 0x3610000d,
	PR_FOLDER_ASSOCIATED_CONTENTS_ERROR                 = 0x3610000a,
	PR_DEF_CREATE_DL                                    = 0x36110102,
	PR_DEF_CREATE_DL_ERROR                              = 0x3611000a,
	PR_DEF_CREATE_MAILUSER                              = 0x36120102,
	PR_DEF_CREATE_MAILUSER_ERROR                        = 0x3612000a,
	PR_CONTAINER_CLASS                                  = 0x3613001e,
	PR_CONTAINER_CLASS_UNICODE                          = 0x3613001f,
	PR_CONTAINER_CLASS_ERROR                            = 0x3613000a,
	PR_CONTAINER_MODIFY_VERSION                         = 0x36140014,
	PR_CONTAINER_MODIFY_VERSION_ERROR                   = 0x3614000a,
	PR_AB_PROVIDER_ID                                   = 0x36150102,
	PR_AB_PROVIDER_ID_ERROR                             = 0x3615000a,
	PR_DEFAULT_VIEW_ENTRYID                             = 0x36160102,
	PR_DEFAULT_VIEW_ENTRYID_ERROR                       = 0x3616000a,
	PR_ASSOC_CONTENT_COUNT                              = 0x36170003,
	PR_ASSOC_CONTENT_COUNT_ERROR                        = 0x3617000a,
	PR_PACKED_NAME_PROPS                                = 0x361c0102,
	PR_PACKED_NAME_PROPS_ERROR                          = 0x361c000a,
	PR_IPM_APPOINTMENT_ENTRYID                          = 0x36d00102,
	PR_IPM_APPOINTMENT_ENTRYID_ERROR                    = 0x36d0000a,
	PR_IPM_CONTACT_ENTRYID                              = 0x36d10102,
	PR_IPM_CONTACT_ENTRYID_ERROR                        = 0x36d1000a,
	PR_IPM_JOURNAL_ENTRYID                              = 0x36d20102,
	PR_IPM_JOURNAL_ENTRYID_ERROR                        = 0x36d2000a,
	PR_IPM_NOTE_ENTRYID                                 = 0x36d30102,
	PR_IPM_NOTE_ENTRYID_ERROR                           = 0x36d3000a,
	PR_IPM_TASK_ENTRYID                                 = 0x36d40102,
	PR_IPM_TASK_ENTRYID_ERROR                           = 0x36d4000a,
	PR_REMINDERS_ONLINE_ENTRYID                         = 0x36d50102,
	PR_REMINDERS_ONLINE_ENTRYID_ERROR                   = 0x36d5000a,
	PR_REMINDERS_OFFLINE_ENTRYID                        = 0x36d60102,
	PR_REMINDERS_OFFLINE_ENTRYID_ERROR                  = 0x36d6000a,
	PR_IPM_DRAFTS_ENTRYID                               = 0x36d70102,
	PR_IPM_DRAFTS_ENTRYID_ERROR                         = 0x36d7000a,
	PR_OUTLOOK_2003_ENTRYIDS                            = 0x36d81102,
	PR_OUTLOOK_2003_ENTRYIDS_ERROR                      = 0x36d8000a,
	PR_FOLDER_WEBVIEWINFO                               = 0x36df0102,
	PR_FOLDER_WEBVIEWINFO_ERROR                         = 0x36df000a,
	PR_FOLDER_XVIEWINFO_E                               = 0x36e00102,
	PR_FOLDER_XVIEWINFO_E_ERROR                         = 0x36e0000a,
	PR_FOLDER_VIEWS_ONLY                                = 0x36e10003,
	PR_FOLDER_VIEWS_ONLY_ERROR                          = 0x36e1000a,
	PR_FREEBUSY_ENTRYIDS                                = 0x36e41102,
	PR_FREEBUSY_ENTRYIDS_ERROR                          = 0x36e4000a,
	PR_DEF_MSG_CLASS                                    = 0x36e5001e,
	PR_DEF_MSG_CLASS_UNICODE                            = 0x36e5001f,
	PR_DEF_MSG_CLASS_ERROR                              = 0x36e5000a,
	PR_DEF_FORM_NAME                                    = 0x36e6001e,
	PR_DEF_FORM_NAME_UNICODE                            = 0x36e6001f,
	PR_DEF_FORM_NAME_ERROR                              = 0x36e6000a,
	PR_GENERATE_EXCHANGE_VIEWS                          = 0x36e9000b,
	PR_GENERATE_EXCHANGE_VIEWS_ERROR                    = 0x36e9000a,
	PR_AGING_PERIOD                                     = 0x36ec0003,
	PR_AGING_PERIOD_ERROR                               = 0x36ec000a,
	PR_AGING_GRANULARITY                                = 0x36ee0003,
	PR_AGING_GRANULARITY_ERROR                          = 0x36ee000a,
	PR_ATTACHMENT_X400_PARAMETERS                       = 0x37000102,
	PR_ATTACHMENT_X400_PARAMETERS_ERROR                 = 0x3700000a,
	PR_ATTACH_DATA_OBJ                                  = 0x3701000d,
	PR_ATTACH_DATA_OBJ_ERROR                            = 0x3701000a,
	PR_ATTACH_DATA_BIN                                  = 0x37010102,
	PR_ATTACH_ENCODING                                  = 0x37020102,
	PR_ATTACH_ENCODING_ERROR                            = 0x3702000a,
	PR_ATTACH_EXTENSION                                 = 0x3703001e,
	PR_ATTACH_EXTENSION_UNICODE                         = 0x3703001f,
	PR_ATTACH_EXTENSION_ERROR                           = 0x3703000a,
	PR_ATTACH_FILENAME                                  = 0x3704001e,
	PR_ATTACH_FILENAME_UNICODE                          = 0x3704001f,
	PR_ATTACH_FILENAME_ERROR                            = 0x3704000a,
	PR_ATTACH_METHOD                                    = 0x37050003,
	PR_ATTACH_METHOD_ERROR                              = 0x3705000a,
	PR_ATTACH_LONG_FILENAME                             = 0x3707001e,
	PR_ATTACH_LONG_FILENAME_UNICODE                     = 0x3707001f,
	PR_ATTACH_LONG_FILENAME_ERROR                       = 0x3707000a,
	PR_ATTACH_PATHNAME                                  = 0x3708001e,
	PR_ATTACH_PATHNAME_UNICODE                          = 0x3708001f,
	PR_ATTACH_PATHNAME_ERROR                            = 0x3708000a,
	PR_ATTACH_RENDERING                                 = 0x37090102,
	PR_ATTACH_RENDERING_ERROR                           = 0x3709000a,
	PR_ATTACH_TAG                                       = 0x370a0102,
	PR_ATTACH_TAG_ERROR                                 = 0x370a000a,
	PR_RENDERING_POSITION                               = 0x370b0003,
	PR_RENDERING_POSITION_ERROR                         = 0x370b000a,
	PR_ATTACH_TRANSPORT_NAME                            = 0x370c001e,
	PR_ATTACH_TRANSPORT_NAME_UNICODE                    = 0x370c001f,
	PR_ATTACH_TRANSPORT_NAME_ERROR                      = 0x370c000a,
	PR_ATTACH_LONG_PATHNAME                             = 0x370d001e,
	PR_ATTACH_LONG_PATHNAME_UNICODE                     = 0x370d001f,
	PR_ATTACH_LONG_PATHNAME_ERROR                       = 0x370d000a,
	PR_ATTACH_MIME_TAG                                  = 0x370e001e,
	PR_ATTACH_MIME_TAG_UNICODE                          = 0x370e001f,
	PR_ATTACH_MIME_TAG_ERROR                            = 0x370e000a,
	PR_ATTACH_ADDITIONAL_INFO                           = 0x370f0102,
	PR_ATTACH_ADDITIONAL_INFO_ERROR                     = 0x370f000a,
	PR_ATTACH_CONTENT_ID                                = 0x3712001e,
	PR_ATTACH_CONTENT_ID_UNICODE                        = 0x3712001f,
	PR_ATTACH_CONTENT_ID_ERROR                          = 0x3712000a,
	PR_ATTACH_CONTENT_LOCATION                          = 0x3713001e,
	PR_ATTACH_CONTENT_LOCATION_UNICODE                  = 0x3713001f,
	PR_ATTACH_CONTENT_LOCATION_ERROR                    = 0x3713000a,
	PR_ATTACH_FLAGS                                     = 0x37140003,
	PR_ATTACH_FLAGS_ERROR                               = 0x3714000a,
	PR_ATTACH_CONTENT_DISPOSITION                       = 0x3716001e,
	PR_ATTACH_CONTENT_DISPOSITION_UNICODE               = 0x3716001f,
	PR_ATTACH_CONTENT_DISPOSITION_ERROR                 = 0x3716000a,
	PR_SYNCEVENT_SUPPRESS_GUID                          = 0x38800102,
	PR_SYNCEVENT_SUPPRESS_GUID_ERROR                    = 0x3880000a,
	PR_DISPLAY_TYPE                                     = 0x39000003,
	PR_DISPLAY_TYPE_ERROR                               = 0x3900000a,
	PR_TEMPLATEID                                       = 0x39020102,
	PR_TEMPLATEID_ERROR                                 = 0x3902000a,
	PR_PRIMARY_CAPABILITY                               = 0x39040102,
	PR_PRIMARY_CAPABILITY_ERROR                         = 0x3904000a,
	PR_SMTP_ADDRESS                                     = 0x39fe001e,
	PR_SMTP_ADDRESS_UNICODE                             = 0x39fe001f,
	PR_SMTP_ADDRESS_ERROR                               = 0x39fe000a,
	PR_7BIT_DISPLAY_NAME                                = 0x39ff001e,
	PR_7BIT_DISPLAY_NAME_UNICODE                        = 0x39ff001f,
	PR_7BIT_DISPLAY_NAME_ERROR                          = 0x39ff000a,
	PR_ACCOUNT                                          = 0x3a00001e,
	PR_ACCOUNT_UNICODE                                  = 0x3a00001f,
	PR_ACCOUNT_ERROR                                    = 0x3a00000a,
	PR_ALTERNATE_RECIPIENT                              = 0x3a010102,
	PR_ALTERNATE_RECIPIENT_ERROR                        = 0x3a01000a,
	PR_CALLBACK_TELEPHONE_NUMBER                        = 0x3a02001e,
	PR_CALLBACK_TELEPHONE_NUMBER_UNICODE                = 0x3a02001f,
	PR_CALLBACK_TELEPHONE_NUMBER_ERROR                  = 0x3a02000a,
	PR_CONVERSION_PROHIBITED                            = 0x3a03000b,
	PR_CONVERSION_PROHIBITED_ERROR                      = 0x3a03000a,
	PR_DISCLOSE_RECIPIENTS                              = 0x3a04000b,
	PR_DISCLOSE_RECIPIENTS_ERROR                        = 0x3a04000a,
	PR_GENERATION                                       = 0x3a05001e,
	PR_GENERATION_UNICODE                               = 0x3a05001f,
	PR_GENERATION_ERROR                                 = 0x3a05000a,
	PR_GIVEN_NAME                                       = 0x3a06001e,
	PR_GIVEN_NAME_UNICODE                               = 0x3a06001f,
	PR_GIVEN_NAME_ERROR                                 = 0x3a06000a,
	PR_GOVERNMENT_ID_NUMBER                             = 0x3a07001e,
	PR_GOVERNMENT_ID_NUMBER_UNICODE                     = 0x3a07001f,
	PR_GOVERNMENT_ID_NUMBER_ERROR                       = 0x3a07000a,
	PR_OFFICE_TELEPHONE_NUMBER                          = 0x3a08001e,
	PR_OFFICE_TELEPHONE_NUMBER_UNICODE                  = 0x3a08001f,
	PR_OFFICE_TELEPHONE_NUMBER_ERROR                    = 0x3a08000a,
	PR_HOME_TELEPHONE_NUMBER                            = 0x3a09001e,
	PR_HOME_TELEPHONE_NUMBER_UNICODE                    = 0x3a09001f,
	PR_HOME_TELEPHONE_NUMBER_ERROR                      = 0x3a09000a,
	PR_INITIALS                                         = 0x3a0a001e,
	PR_INITIALS_UNICODE                                 = 0x3a0a001f,
	PR_INITIALS_ERROR                                   = 0x3a0a000a,
	PR_KEYWORD                                          = 0x3a0b001e,
	PR_KEYWORD_UNICODE                                  = 0x3a0b001f,
	PR_KEYWORD_ERROR                                    = 0x3a0b000a,
	PR_LANGUAGE                                         = 0x3a0c001e,
	PR_LANGUAGE_UNICODE                                 = 0x3a0c001f,
	PR_LANGUAGE_ERROR                                   = 0x3a0c000a,
	PR_LOCATION                                         = 0x3a0d001e,
	PR_LOCATION_UNICODE                                 = 0x3a0d001f,
	PR_LOCATION_ERROR                                   = 0x3a0d000a,
	PR_MAIL_PERMISSION                                  = 0x3a0e000b,
	PR_MAIL_PERMISSION_ERROR                            = 0x3a0e000a,
	PR_MHS_COMMON_NAME                                  = 0x3a0f001e,
	PR_MHS_COMMON_NAME_UNICODE                          = 0x3a0f001f,
	PR_MHS_COMMON_NAME_ERROR                            = 0x3a0f000a,
	PR_ORGANIZATIONAL_ID_NUMBER                         = 0x3a10001e,
	PR_ORGANIZATIONAL_ID_NUMBER_UNICODE                 = 0x3a10001f,
	PR_ORGANIZATIONAL_ID_NUMBER_ERROR                   = 0x3a10000a,
	PR_SURNAME                                          = 0x3a11001e,
	PR_SURNAME_UNICODE                                  = 0x3a11001f,
	PR_SURNAME_ERROR                                    = 0x3a11000a,
	PR_ORIGINAL_ENTRYID                                 = 0x3a120102,
	PR_ORIGINAL_ENTRYID_ERROR                           = 0x3a12000a,
	PR_ORIGINAL_DISPLAY_NAME                            = 0x3a13001e,
	PR_ORIGINAL_DISPLAY_NAME_UNICODE                    = 0x3a13001f,
	PR_ORIGINAL_DISPLAY_NAME_ERROR                      = 0x3a13000a,
	PR_ORIGINAL_SEARCH_KEY                              = 0x3a140102,
	PR_ORIGINAL_SEARCH_KEY_ERROR                        = 0x3a14000a,
	PR_POSTAL_ADDRESS                                   = 0x3a15001e,
	PR_POSTAL_ADDRESS_UNICODE                           = 0x3a15001f,
	PR_POSTAL_ADDRESS_ERROR                             = 0x3a15000a,
	PR_COMPANY_NAME                                     = 0x3a16001e,
	PR_COMPANY_NAME_UNICODE                             = 0x3a16001f,
	PR_COMPANY_NAME_ERROR                               = 0x3a16000a,
	PR_TITLE                                            = 0x3a17001e,
	PR_TITLE_UNICODE                                    = 0x3a17001f,
	PR_TITLE_ERROR                                      = 0x3a17000a,
	PR_DEPARTMENT_NAME                                  = 0x3a18001e,
	PR_DEPARTMENT_NAME_UNICODE                          = 0x3a18001f,
	PR_DEPARTMENT_NAME_ERROR                            = 0x3a18000a,
	PR_OFFICE_LOCATION                                  = 0x3a19001e,
	PR_OFFICE_LOCATION_UNICODE                          = 0x3a19001f,
	PR_OFFICE_LOCATION_ERROR                            = 0x3a19000a,
	PR_PRIMARY_TELEPHONE_NUMBER                         = 0x3a1a001e,
	PR_PRIMARY_TELEPHONE_NUMBER_UNICODE                 = 0x3a1a001f,
	PR_PRIMARY_TELEPHONE_NUMBER_ERROR                   = 0x3a1a000a,
	PR_OFFICE2_TELEPHONE_NUMBER                         = 0x3a1b001e,
	PR_OFFICE2_TELEPHONE_NUMBER_UNICODE                 = 0x3a1b001f,
	PR_OFFICE2_TELEPHONE_NUMBER_ERROR                   = 0x3a1b000a,
	PR_MOBILE_TELEPHONE_NUMBER                          = 0x3a1c001e,
	PR_MOBILE_TELEPHONE_NUMBER_UNICODE                  = 0x3a1c001f,
	PR_MOBILE_TELEPHONE_NUMBER_ERROR                    = 0x3a1c000a,
	PR_RADIO_TELEPHONE_NUMBER                           = 0x3a1d001e,
	PR_RADIO_TELEPHONE_NUMBER_UNICODE                   = 0x3a1d001f,
	PR_RADIO_TELEPHONE_NUMBER_ERROR                     = 0x3a1d000a,
	PR_CAR_TELEPHONE_NUMBER                             = 0x3a1e001e,
	PR_CAR_TELEPHONE_NUMBER_UNICODE                     = 0x3a1e001f,
	PR_CAR_TELEPHONE_NUMBER_ERROR                       = 0x3a1e000a,
	PR_OTHER_TELEPHONE_NUMBER                           = 0x3a1f001e,
	PR_OTHER_TELEPHONE_NUMBER_UNICODE                   = 0x3a1f001f,
	PR_OTHER_TELEPHONE_NUMBER_ERROR                     = 0x3a1f000a,
	PR_TRANSMITTABLE_DISPLAY_NAME                       = 0x3a20001e,
	PR_TRANSMITTABLE_DISPLAY_NAME_UNICODE               = 0x3a20001f,
	PR_TRANSMITTABLE_DISPLAY_NAME_ERROR                 = 0x3a20000a,
	PR_PAGER_TELEPHONE_NUMBER                           = 0x3a21001e,
	PR_PAGER_TELEPHONE_NUMBER_UNICODE                   = 0x3a21001f,
	PR_PAGER_TELEPHONE_NUMBER_ERROR                     = 0x3a21000a,
	PR_USER_CERTIFICATE                                 = 0x3a220102,
	PR_USER_CERTIFICATE_ERROR                           = 0x3a22000a,
	PR_PRIMARY_FAX_NUMBER                               = 0x3a23001e,
	PR_PRIMARY_FAX_NUMBER_UNICODE                       = 0x3a23001f,
	PR_PRIMARY_FAX_NUMBER_ERROR                         = 0x3a23000a,
	PR_HOME_FAX_NUMBER                                  = 0x3a25001e,
	PR_HOME_FAX_NUMBER_UNICODE                          = 0x3a25001f,
	PR_HOME_FAX_NUMBER_ERROR                            = 0x3a25000a,
	PR_COUNTRY                                          = 0x3a26001e,
	PR_COUNTRY_UNICODE                                  = 0x3a26001f,
	PR_COUNTRY_ERROR                                    = 0x3a26000a,
	PR_LOCALITY                                         = 0x3a27001e,
	PR_LOCALITY_UNICODE                                 = 0x3a27001f,
	PR_LOCALITY_ERROR                                   = 0x3a27000a,
	PR_STATE_OR_PROVINCE                                = 0x3a28001e,
	PR_STATE_OR_PROVINCE_UNICODE                        = 0x3a28001f,
	PR_STATE_OR_PROVINCE_ERROR                          = 0x3a28000a,
	PR_STREET_ADDRESS                                   = 0x3a29001e,
	PR_STREET_ADDRESS_UNICODE                           = 0x3a29001f,
	PR_STREET_ADDRESS_ERROR                             = 0x3a29000a,
	PR_POSTAL_CODE                                      = 0x3a2a001e,
	PR_POSTAL_CODE_UNICODE                              = 0x3a2a001f,
	PR_POSTAL_CODE_ERROR                                = 0x3a2a000a,
	PR_POST_OFFICE_BOX                                  = 0x3a2b001e,
	PR_POST_OFFICE_BOX_UNICODE                          = 0x3a2b001f,
	PR_POST_OFFICE_BOX_ERROR                            = 0x3a2b000a,
	PR_TELEX_NUMBER                                     = 0x3a2c001e,
	PR_TELEX_NUMBER_UNICODE                             = 0x3a2c001f,
	PR_TELEX_NUMBER_ERROR                               = 0x3a2c000a,
	PR_ISDN_NUMBER                                      = 0x3a2d001e,
	PR_ISDN_NUMBER_UNICODE                              = 0x3a2d001f,
	PR_ISDN_NUMBER_ERROR                                = 0x3a2d000a,
	PR_ASSISTANT_TELEPHONE_NUMBER                       = 0x3a2e001e,
	PR_ASSISTANT_TELEPHONE_NUMBER_UNICODE               = 0x3a2e001f,
	PR_ASSISTANT_TELEPHONE_NUMBER_ERROR                 = 0x3a2e000a,
	PR_HOME2_TELEPHONE_NUMBER                           = 0x3a2f001e,
	PR_HOME2_TELEPHONE_NUMBER_UNICODE                   = 0x3a2f001f,
	PR_HOME2_TELEPHONE_NUMBER_ERROR                     = 0x3a2f000a,
	PR_ASSISTANT                                        = 0x3a30001e,
	PR_ASSISTANT_UNICODE                                = 0x3a30001f,
	PR_ASSISTANT_ERROR                                  = 0x3a30000a,
	PR_SEND_RICH_INFO                                   = 0x3a40000b,
	PR_SEND_RICH_INFO_ERROR                             = 0x3a40000a,
	PR_WEDDING_ANNIVERSARY                              = 0x3a410040,
	PR_WEDDING_ANNIVERSARY_ERROR                        = 0x3a41000a,
	PR_BIRTHDAY                                         = 0x3a420040,
	PR_BIRTHDAY_ERROR                                   = 0x3a42000a,
	PR_HOBBIES                                          = 0x3a43001e,
	PR_HOBBIES_UNICODE                                  = 0x3a43001f,
	PR_HOBBIES_ERROR                                    = 0x3a43000a,
	PR_MIDDLE_NAME                                      = 0x3a44001e,
	PR_MIDDLE_NAME_UNICODE                              = 0x3a44001f,
	PR_MIDDLE_NAME_ERROR                                = 0x3a44000a,
	PR_DISPLAY_NAME_PREFIX                              = 0x3a45001e,
	PR_DISPLAY_NAME_PREFIX_UNICODE                      = 0x3a45001f,
	PR_DISPLAY_NAME_PREFIX_ERROR                        = 0x3a45000a,
	PR_PROFESSION                                       = 0x3a46001e,
	PR_PROFESSION_UNICODE                               = 0x3a46001f,
	PR_PROFESSION_ERROR                                 = 0x3a46000a,
	PR_PREFERRED_BY_NAME                                = 0x3a47001e,
	PR_PREFERRED_BY_NAME_UNICODE                        = 0x3a47001f,
	PR_PREFERRED_BY_NAME_ERROR                          = 0x3a47000a,
	PR_SPOUSE_NAME                                      = 0x3a48001e,
	PR_SPOUSE_NAME_UNICODE                              = 0x3a48001f,
	PR_SPOUSE_NAME_ERROR                                = 0x3a48000a,
	PR_COMPUTER_NETWORK_NAME                            = 0x3a49001e,
	PR_COMPUTER_NETWORK_NAME_UNICODE                    = 0x3a49001f,
	PR_COMPUTER_NETWORK_NAME_ERROR                      = 0x3a49000a,
	PR_CUSTOMER_ID                                      = 0x3a4a001e,
	PR_CUSTOMER_ID_UNICODE                              = 0x3a4a001f,
	PR_CUSTOMER_ID_ERROR                                = 0x3a4a000a,
	PR_TTYTDD_PHONE_NUMBER                              = 0x3a4b001e,
	PR_TTYTDD_PHONE_NUMBER_UNICODE                      = 0x3a4b001f,
	PR_TTYTDD_PHONE_NUMBER_ERROR                        = 0x3a4b000a,
	PR_FTP_SITE                                         = 0x3a4c001e,
	PR_FTP_SITE_UNICODE                                 = 0x3a4c001f,
	PR_FTP_SITE_ERROR                                   = 0x3a4c000a,
	PR_GENDER                                           = 0x3a4d0002,
	PR_GENDER_ERROR                                     = 0x3a4d000a,
	PR_MANAGER_NAME                                     = 0x3a4e001e,
	PR_MANAGER_NAME_UNICODE                             = 0x3a4e001f,
	PR_MANAGER_NAME_ERROR                               = 0x3a4e000a,
	PR_NICKNAME                                         = 0x3a4f001e,
	PR_NICKNAME_UNICODE                                 = 0x3a4f001f,
	PR_NICKNAME_ERROR                                   = 0x3a4f000a,
	PR_PERSONAL_HOME_PAGE                               = 0x3a50001e,
	PR_PERSONAL_HOME_PAGE_UNICODE                       = 0x3a50001f,
	PR_PERSONAL_HOME_PAGE_ERROR                         = 0x3a50000a,
	PR_BUSINESS_HOME_PAGE                               = 0x3a51001e,
	PR_BUSINESS_HOME_PAGE_UNICODE                       = 0x3a51001f,
	PR_BUSINESS_HOME_PAGE_ERROR                         = 0x3a51000a,
	PR_CONTACT_VERSION                                  = 0x3a520048,
	PR_CONTACT_VERSION_ERROR                            = 0x3a52000a,
	PR_CONTACT_ENTRYIDS                                 = 0x3a531102,
	PR_CONTACT_ENTRYIDS_ERROR                           = 0x3a53000a,
	PR_CONTACT_ADDRTYPES                                = 0x3a54101e,
	PR_CONTACT_ADDRTYPES_UNICODE                        = 0x3a54101f,
	PR_CONTACT_ADDRTYPES_ERROR                          = 0x3a54000a,
	PR_CONTACT_DEFAULT_ADDRESS_INDEX                    = 0x3a550003,
	PR_CONTACT_DEFAULT_ADDRESS_INDEX_ERROR              = 0x3a55000a,
	PR_CONTACT_EMAIL_ADDRESSES                          = 0x3a56101e,
	PR_CONTACT_EMAIL_ADDRESSES_UNICODE                  = 0x3a56101f,
	PR_CONTACT_EMAIL_ADDRESSES_ERROR                    = 0x3a56000a,
	PR_COMPANY_MAIN_PHONE_NUMBER                        = 0x3a57001e,
	PR_COMPANY_MAIN_PHONE_NUMBER_UNICODE                = 0x3a57001f,
	PR_COMPANY_MAIN_PHONE_NUMBER_ERROR                  = 0x3a57000a,
	PR_CHILDRENS_NAMES                                  = 0x3a58101e,
	PR_CHILDRENS_NAMES_UNICODE                          = 0x3a58101f,
	PR_CHILDRENS_NAMES_ERROR                            = 0x3a58000a,
	PR_HOME_ADDRESS_CITY                                = 0x3a59001e,
	PR_HOME_ADDRESS_CITY_UNICODE                        = 0x3a59001f,
	PR_HOME_ADDRESS_CITY_ERROR                          = 0x3a59000a,
	PR_HOME_ADDRESS_COUNTRY                             = 0x3a5a001e,
	PR_HOME_ADDRESS_COUNTRY_UNICODE                     = 0x3a5a001f,
	PR_HOME_ADDRESS_COUNTRY_ERROR                       = 0x3a5a000a,
	PR_HOME_ADDRESS_POSTAL_CODE                         = 0x3a5b001e,
	PR_HOME_ADDRESS_POSTAL_CODE_UNICODE                 = 0x3a5b001f,
	PR_HOME_ADDRESS_POSTAL_CODE_ERROR                   = 0x3a5b000a,
	PR_HOME_ADDRESS_STATE_OR_PROVINCE                   = 0x3a5c001e,
	PR_HOME_ADDRESS_STATE_OR_PROVINCE_UNICODE           = 0x3a5c001f,
	PR_HOME_ADDRESS_STATE_OR_PROVINCE_ERROR             = 0x3a5c000a,
	PR_HOME_ADDRESS_STREET                              = 0x3a5d001e,
	PR_HOME_ADDRESS_STREET_UNICODE                      = 0x3a5d001f,
	PR_HOME_ADDRESS_STREET_ERROR                        = 0x3a5d000a,
	PR_HOME_ADDRESS_POST_OFFICE_BOX                     = 0x3a5e001e,
	PR_HOME_ADDRESS_POST_OFFICE_BOX_UNICODE             = 0x3a5e001f,
	PR_HOME_ADDRESS_POST_OFFICE_BOX_ERROR               = 0x3a5e000a,
	PR_OTHER_ADDRESS_CITY                               = 0x3a5f001e,
	PR_OTHER_ADDRESS_CITY_UNICODE                       = 0x3a5f001f,
	PR_OTHER_ADDRESS_CITY_ERROR                         = 0x3a5f000a,
	PR_OTHER_ADDRESS_COUNTRY                            = 0x3a60001e,
	PR_OTHER_ADDRESS_COUNTRY_UNICODE                    = 0x3a60001f,
	PR_OTHER_ADDRESS_COUNTRY_ERROR                      = 0x3a60000a,
	PR_OTHER_ADDRESS_POSTAL_CODE                        = 0x3a61001e,
	PR_OTHER_ADDRESS_POSTAL_CODE_UNICODE                = 0x3a61001f,
	PR_OTHER_ADDRESS_POSTAL_CODE_ERROR                  = 0x3a61000a,
	PR_OTHER_ADDRESS_STATE_OR_PROVINCE                  = 0x3a62001e,
	PR_OTHER_ADDRESS_STATE_OR_PROVINCE_UNICODE          = 0x3a62001f,
	PR_OTHER_ADDRESS_STATE_OR_PROVINCE_ERROR            = 0x3a62000a,
	PR_OTHER_ADDRESS_STREET                             = 0x3a63001e,
	PR_OTHER_ADDRESS_STREET_UNICODE                     = 0x3a63001f,
	PR_OTHER_ADDRESS_STREET_ERROR                       = 0x3a63000a,
	PR_OTHER_ADDRESS_POST_OFFICE_BOX                    = 0x3a64001e,
	PR_OTHER_ADDRESS_POST_OFFICE_BOX_UNICODE            = 0x3a64001f,
	PR_OTHER_ADDRESS_POST_OFFICE_BOX_ERROR              = 0x3a64000a,
	PR_USER_X509_CERTIFICATE                            = 0x3a701102,
	PR_USER_X509_CERTIFICATE_ERROR                      = 0x3a70000a,
	PR_SEND_INTERNET_ENCODING                           = 0x3a710003,
	PR_SEND_INTERNET_ENCODING_ERROR                     = 0x3a71000a,
	PR_STORE_PROVIDERS                                  = 0x3d000102,
	PR_STORE_PROVIDERS_ERROR                            = 0x3d00000a,
	PR_AB_PROVIDERS                                     = 0x3d010102,
	PR_AB_PROVIDERS_ERROR                               = 0x3d01000a,
	PR_TRANSPORT_PROVIDERS                              = 0x3d020102,
	PR_TRANSPORT_PROVIDERS_ERROR                        = 0x3d02000a,
	PR_DEFAULT_PROFILE                                  = 0x3d04000b,
	PR_DEFAULT_PROFILE_ERROR                            = 0x3d04000a,
	PR_AB_SEARCH_PATH                                   = 0x3d051102,
	PR_AB_SEARCH_PATH_ERROR                             = 0x3d05000a,
	PR_AB_DEFAULT_DIR                                   = 0x3d060102,
	PR_AB_DEFAULT_DIR_ERROR                             = 0x3d06000a,
	PR_AB_DEFAULT_PAB                                   = 0x3d070102,
	PR_AB_DEFAULT_PAB_ERROR                             = 0x3d07000a,
	PR_FILTERING_HOOKS                                  = 0x3d080102,
	PR_FILTERING_HOOKS_ERROR                            = 0x3d08000a,
	PR_SERVICE_NAME                                     = 0x3d09001e,
	PR_SERVICE_NAME_UNICODE                             = 0x3d09001f,
	PR_SERVICE_NAME_ERROR                               = 0x3d09000a,
	PR_SERVICE_DLL_NAME                                 = 0x3d0a001e,
	PR_SERVICE_DLL_NAME_UNICODE                         = 0x3d0a001f,
	PR_SERVICE_DLL_NAME_ERROR                           = 0x3d0a000a,
	PR_SERVICE_ENTRY_NAME                               = 0x3d0b001e,
	PR_SERVICE_ENTRY_NAME_UNICODE                       = 0x3d0b001f,
	PR_SERVICE_ENTRY_NAME_ERROR                         = 0x3d0b000a,
	PR_SERVICE_UID                                      = 0x3d0c0102,
	PR_SERVICE_UID_ERROR                                = 0x3d0c000a,
	PR_SERVICE_EXTRA_UIDS                               = 0x3d0d0102,
	PR_SERVICE_EXTRA_UIDS_ERROR                         = 0x3d0d000a,
	PR_SERVICES                                         = 0x3d0e0102,
	PR_SERVICES_ERROR                                   = 0x3d0e000a,
	PR_SERVICE_SUPPORT_FILES                            = 0x3d0f101e,
	PR_SERVICE_SUPPORT_FILES_UNICODE                    = 0x3d0f101f,
	PR_SERVICE_SUPPORT_FILES_ERROR                      = 0x3d0f000a,
	PR_SERVICE_DELETE_FILES                             = 0x3d10101e,
	PR_SERVICE_DELETE_FILES_UNICODE                     = 0x3d10101f,
	PR_SERVICE_DELETE_FILES_ERROR                       = 0x3d10000a,
	PR_AB_SEARCH_PATH_UPDATE                            = 0x3d110102,
	PR_AB_SEARCH_PATH_UPDATE_ERROR                      = 0x3d11000a,
	PR_PROFILE_NAME                                     = 0x3d12001e,
	PR_PROFILE_NAME_UNICODE                             = 0x3d12001f,
	PR_PROFILE_NAME_ERROR                               = 0x3d12000a,
	PR_SERVICE_INSTALL_ID                               = 0x3d13001e,
	PR_SERVICE_INSTALL_ID_UNICODE                       = 0x3d13001f,
	PR_SERVICE_INSTALL_ID_ERROR                         = 0x3d13000a,
	PR_ADMIN_SECURITY_DESCRIPTOR                        = 0x3d210102,
	PR_ADMIN_SECURITY_DESCRIPTOR_ERROR                  = 0x3d21000a,
	PR_IDENTITY_DISPLAY                                 = 0x3e00001e,
	PR_IDENTITY_DISPLAY_UNICODE                         = 0x3e00001f,
	PR_IDENTITY_DISPLAY_ERROR                           = 0x3e00000a,
	PR_IDENTITY_ENTRYID                                 = 0x3e010102,
	PR_IDENTITY_ENTRYID_ERROR                           = 0x3e01000a,
	PR_RESOURCE_METHODS                                 = 0x3e020003,
	PR_RESOURCE_METHODS_ERROR                           = 0x3e02000a,
	PR_RESOURCE_TYPE                                    = 0x3e030003,
	PR_RESOURCE_TYPE_ERROR                              = 0x3e03000a,
	PR_STATUS_CODE                                      = 0x3e040003,
	PR_STATUS_CODE_ERROR                                = 0x3e04000a,
	PR_IDENTITY_SEARCH_KEY                              = 0x3e050102,
	PR_IDENTITY_SEARCH_KEY_ERROR                        = 0x3e05000a,
	PR_OWN_STORE_ENTRYID                                = 0x3e060102,
	PR_OWN_STORE_ENTRYID_ERROR                          = 0x3e06000a,
	PR_RESOURCE_PATH                                    = 0x3e07001e,
	PR_RESOURCE_PATH_UNICODE                            = 0x3e07001f,
	PR_RESOURCE_PATH_ERROR                              = 0x3e07000a,
	PR_STATUS_STRING                                    = 0x3e08001e,
	PR_STATUS_STRING_UNICODE                            = 0x3e08001f,
	PR_STATUS_STRING_ERROR                              = 0x3e08000a,
	PR_X400_DEFERRED_DELIVERY_CANCEL                    = 0x3e09000b,
	PR_X400_DEFERRED_DELIVERY_CANCEL_ERROR              = 0x3e09000a,
	PR_HEADER_FOLDER_ENTRYID                            = 0x3e0a0102,
	PR_HEADER_FOLDER_ENTRYID_ERROR                      = 0x3e0a000a,
	PR_REMOTE_PROGRESS                                  = 0x3e0b0003,
	PR_REMOTE_PROGRESS_ERROR                            = 0x3e0b000a,
	PR_REMOTE_PROGRESS_TEXT                             = 0x3e0c001e,
	PR_REMOTE_PROGRESS_TEXT_UNICODE                     = 0x3e0c001f,
	PR_REMOTE_PROGRESS_TEXT_ERROR                       = 0x3e0c000a,
	PR_REMOTE_VALIDATE_OK                               = 0x3e0d000b,
	PR_REMOTE_VALIDATE_OK_ERROR                         = 0x3e0d000a,
	PR_CONTROL_FLAGS                                    = 0x3f000003,
	PR_CONTROL_FLAGS_ERROR                              = 0x3f00000a,
	PR_CONTROL_STRUCTURE                                = 0x3f010102,
	PR_CONTROL_STRUCTURE_ERROR                          = 0x3f01000a,
	PR_CONTROL_TYPE                                     = 0x3f020003,
	PR_CONTROL_TYPE_ERROR                               = 0x3f02000a,
	PR_DELTAX                                           = 0x3f030003,
	PR_DELTAX_ERROR                                     = 0x3f03000a,
	PR_DELTAY                                           = 0x3f040003,
	PR_DELTAY_ERROR                                     = 0x3f04000a,
	PR_XPOS                                             = 0x3f050003,
	PR_XPOS_ERROR                                       = 0x3f05000a,
	PR_YPOS                                             = 0x3f060003,
	PR_YPOS_ERROR                                       = 0x3f06000a,
	PR_CONTROL_ID                                       = 0x3f070102,
	PR_CONTROL_ID_ERROR                                 = 0x3f07000a,
	PR_INITIAL_DETAILS_PANE                             = 0x3f080003,
	PR_INITIAL_DETAILS_PANE_ERROR                       = 0x3f08000a,
	PR_DID                                              = 0x3f800014,
	PR_DID_ERROR                                        = 0x3f80000a,
	PR_SEQID                                            = 0x3f810014,
	PR_SEQID_ERROR                                      = 0x3f81000a,
	PR_DRAFTID                                          = 0x3f820014,
	PR_DRAFTID_ERROR                                    = 0x3f82000a,
	PR_CHECK_IN_TIME                                    = 0x3f830040,
	PR_CHECK_IN_TIME_ERROR                              = 0x3f83000a,
	PR_CHECK_IN_COMMENT                                 = 0x3f84001e,
	PR_CHECK_IN_COMMENT_UNICODE                         = 0x3f84001f,
	PR_CHECK_IN_COMMENT_ERROR                           = 0x3f84000a,
	PR_VERSION_OP_CODE                                  = 0x3f850003,
	PR_VERSION_OP_CODE_ERROR                            = 0x3f85000a,
	PR_VERSION_OP_DATA                                  = 0x3f860102,
	PR_VERSION_OP_DATA_ERROR                            = 0x3f86000a,
	PR_VERSION_SEQUENCE_NUMBER                          = 0x3f870003,
	PR_VERSION_SEQUENCE_NUMBER_ERROR                    = 0x3f87000a,
	PR_ATTACH_ID                                        = 0x3f880014,
	PR_ATTACH_ID_ERROR                                  = 0x3f88000a,
	PR_PKM_DOC_STATUS                                   = 0x3f8d001e,
	PR_PKM_DOC_STATUS_UNICODE                           = 0x3f8d001f,
	PR_PKM_DOC_STATUS_ERROR                             = 0x3f8d000a,
	PR_MV_PKM_OPERATION_REQ                             = 0x3f8e101e,
	PR_MV_PKM_OPERATION_REQ_UNICODE                     = 0x3f8e101f,
	PR_MV_PKM_OPERATION_REQ_ERROR                       = 0x3f8e000a,
	PR_PKM_DOC_INTERNAL_STATE                           = 0x3f8f001e,
	PR_PKM_DOC_INTERNAL_STATE_UNICODE                   = 0x3f8f001f,
	PR_PKM_DOC_INTERNAL_STATE_ERROR                     = 0x3f8f000a,
	PR_VERSIONING_FLAGS                                 = 0x3f900002,
	PR_VERSIONING_FLAGS_ERROR                           = 0x3f90000a,
	PR_PKM_LAST_UNAPPROVED_VID                          = 0x3f910102,
	PR_PKM_LAST_UNAPPROVED_VID_ERROR                    = 0x3f91000a,
	PR_MV_PKM_VERSION_LABELS                            = 0x3f92101e,
	PR_MV_PKM_VERSION_LABELS_UNICODE                    = 0x3f92101f,
	PR_MV_PKM_VERSION_LABELS_ERROR                      = 0x3f92000a,
	PR_MV_PKM_VERSION_STATUS                            = 0x3f93101e,
	PR_MV_PKM_VERSION_STATUS_UNICODE                    = 0x3f93101f,
	PR_MV_PKM_VERSION_STATUS_ERROR                      = 0x3f93000a,
	PR_PKM_INTERNAL_DATA                                = 0x3f940102,
	PR_PKM_INTERNAL_DATA_ERROR                          = 0x3f94000a,
	PR_LAST_CONFLICT                                    = 0x3fc90102,
	PR_LAST_CONFLICT_ERROR                              = 0x3fc9000a,
	PR_CONFLICT_MSG_KEY                                 = 0x3fca0102,
	PR_CONFLICT_MSG_KEY_ERROR                           = 0x3fca000a,
	PR_REPL_HEADER                                      = 0x3fd00102,
	PR_REPL_HEADER_ERROR                                = 0x3fd0000a,
	PR_REPL_STATUS                                      = 0x3fd10102,
	PR_REPL_STATUS_ERROR                                = 0x3fd1000a,
	PR_REPL_CHANGES                                     = 0x3fd20102,
	PR_REPL_CHANGES_ERROR                               = 0x3fd2000a,
	PR_REPL_RGM                                         = 0x3fd30102,
	PR_REPL_RGM_ERROR                                   = 0x3fd3000a,
	PR_RMI                                              = 0x3fd40102,
	PR_RMI_ERROR                                        = 0x3fd4000a,
	PR_INTERNAL_POST_REPLY                              = 0x3fd50102,
	PR_INTERNAL_POST_REPLY_ERROR                        = 0x3fd5000a,
	PR_NTSD_MODIFICATION_TIME                           = 0x3fd60040,
	PR_NTSD_MODIFICATION_TIME_ERROR                     = 0x3fd6000a,
	PR_PREVIEW_UNREAD                                   = 0x3fd8001e,
	PR_PREVIEW_UNREAD_UNICODE                           = 0x3fd8001f,
	PR_PREVIEW_UNREAD_ERROR                             = 0x3fd8000a,
	PR_PREVIEW                                          = 0x3fd9001e,
	PR_PREVIEW_UNICODE                                  = 0x3fd9001f,
	PR_PREVIEW_ERROR                                    = 0x3fd9000a,
	PR_ABSTRACT                                         = 0x3fda001e,
	PR_ABSTRACT_UNICODE                                 = 0x3fda001f,
	PR_ABSTRACT_ERROR                                   = 0x3fda000a,
	PR_DL_REPORT_FLAGS                                  = 0x3fdb0003,
	PR_DL_REPORT_FLAGS_ERROR                            = 0x3fdb000a,
	PR_BILATERAL_INFO                                   = 0x3fdc0102,
	PR_BILATERAL_INFO_ERROR                             = 0x3fdc000a,
	PR_MSG_BODY_ID                                      = 0x3fdd0003,
	PR_MSG_BODY_ID_ERROR                                = 0x3fdd000a,
	PR_INTERNET_CPID                                    = 0x3fde0003,
	PR_INTERNET_CPID_ERROR                              = 0x3fde000a,
	PR_AUTO_RESPONSE_SUPPRESS                           = 0x3fdf0003,
	PR_AUTO_RESPONSE_SUPPRESS_ERROR                     = 0x3fdf000a,
	PR_ACL_TABLE                                        = 0x3fe0000d,
	PR_ACL_TABLE_ERROR                                  = 0x3fe0000a,
	PR_ACL_DATA                                         = 0x3fe00102,
	PR_RULES_TABLE                                      = 0x3fe1000d,
	PR_RULES_TABLE_ERROR                                = 0x3fe1000a,
	PR_RULES_DATA                                       = 0x3fe10102,
	PR_FOLDER_DESIGN_FLAGS                              = 0x3fe20003,
	PR_FOLDER_DESIGN_FLAGS_ERROR                        = 0x3fe2000a,
	PR_DELEGATED_BY_RULE                                = 0x3fe3000b,
	PR_DELEGATED_BY_RULE_ERROR                          = 0x3fe3000a,
	PR_DESIGN_IN_PROGRESS                               = 0x3fe4000b,
	PR_DESIGN_IN_PROGRESS_ERROR                         = 0x3fe4000a,
	PR_SECURE_ORIGINATION                               = 0x3fe5000b,
	PR_SECURE_ORIGINATION_ERROR                         = 0x3fe5000a,
	PR_PUBLISH_IN_ADDRESS_BOOK                          = 0x3fe6000b,
	PR_PUBLISH_IN_ADDRESS_BOOK_ERROR                    = 0x3fe6000a,
	PR_RESOLVE_METHOD                                   = 0x3fe70003,
	PR_RESOLVE_METHOD_ERROR                             = 0x3fe7000a,
	PR_ADDRESS_BOOK_DISPLAY_NAME                        = 0x3fe8001e,
	PR_ADDRESS_BOOK_DISPLAY_NAME_UNICODE                = 0x3fe8001f,
	PR_ADDRESS_BOOK_DISPLAY_NAME_ERROR                  = 0x3fe8000a,
	PR_EFORMS_LOCALE_ID                                 = 0x3fe90003,
	PR_EFORMS_LOCALE_ID_ERROR                           = 0x3fe9000a,
	PR_HAS_DAMS                                         = 0x3fea000b,
	PR_HAS_DAMS_ERROR                                   = 0x3fea000a,
	PR_DEFERRED_SEND_NUMBER                             = 0x3feb0003,
	PR_DEFERRED_SEND_NUMBER_ERROR                       = 0x3feb000a,
	PR_DEFERRED_SEND_UNITS                              = 0x3fec0003,
	PR_DEFERRED_SEND_UNITS_ERROR                        = 0x3fec000a,
	PR_EXPIRY_NUMBER                                    = 0x3fed0003,
	PR_EXPIRY_NUMBER_ERROR                              = 0x3fed000a,
	PR_EXPIRY_UNITS                                     = 0x3fee0003,
	PR_EXPIRY_UNITS_ERROR                               = 0x3fee000a,
	PR_DEFERRED_SEND_TIME                               = 0x3fef0040,
	PR_DEFERRED_SEND_TIME_ERROR                         = 0x3fef000a,
	PR_CONFLICT_ENTRYID                                 = 0x3ff00102,
	PR_CONFLICT_ENTRYID_ERROR                           = 0x3ff0000a,
	PR_MESSAGE_LOCALE_ID                                = 0x3ff10003,
	PR_MESSAGE_LOCALE_ID_ERROR                          = 0x3ff1000a,
	PR_RULE_TRIGGER_HISTORY                             = 0x3ff20102,
	PR_RULE_TRIGGER_HISTORY_ERROR                       = 0x3ff2000a,
	PR_MOVE_TO_STORE_ENTRYID                            = 0x3ff30102,
	PR_MOVE_TO_STORE_ENTRYID_ERROR                      = 0x3ff3000a,
	PR_MOVE_TO_FOLDER_ENTRYID                           = 0x3ff40102,
	PR_MOVE_TO_FOLDER_ENTRYID_ERROR                     = 0x3ff4000a,
	PR_STORAGE_QUOTA_LIMIT                              = 0x3ff50003,
	PR_STORAGE_QUOTA_LIMIT_ERROR                        = 0x3ff5000a,
	PR_EXCESS_STORAGE_USED                              = 0x3ff60003,
	PR_EXCESS_STORAGE_USED_ERROR                        = 0x3ff6000a,
	PR_SVR_GENERATING_QUOTA_MSG                         = 0x3ff7001e,
	PR_SVR_GENERATING_QUOTA_MSG_UNICODE                 = 0x3ff7001f,
	PR_SVR_GENERATING_QUOTA_MSG_ERROR                   = 0x3ff7000a,
	PR_CREATOR_NAME                                     = 0x3ff8001e,
	PR_CREATOR_NAME_UNICODE                             = 0x3ff8001f,
	PR_CREATOR_NAME_ERROR                               = 0x3ff8000a,
	PR_CREATOR_ENTRYID                                  = 0x3ff90102,
	PR_CREATOR_ENTRYID_ERROR                            = 0x3ff9000a,
	PR_LAST_MODIFIER_NAME                               = 0x3ffa001e,
	PR_LAST_MODIFIER_NAME_UNICODE                       = 0x3ffa001f,
	PR_LAST_MODIFIER_NAME_ERROR                         = 0x3ffa000a,
	PR_LAST_MODIFIER_ENTRYID                            = 0x3ffb0102,
	PR_LAST_MODIFIER_ENTRYID_ERROR                      = 0x3ffb000a,
	PR_REPLY_RECIPIENT_SMTP_PROXIES                     = 0x3ffc001e,
	PR_REPLY_RECIPIENT_SMTP_PROXIES_UNICODE             = 0x3ffc001f,
	PR_REPLY_RECIPIENT_SMTP_PROXIES_ERROR               = 0x3ffc000a,
	PR_MESSAGE_CODEPAGE                                 = 0x3ffd0003,
	PR_MESSAGE_CODEPAGE_ERROR                           = 0x3ffd000a,
	PR_EXTENDED_ACL_DATA                                = 0x3ffe0102,
	PR_EXTENDED_ACL_DATA_ERROR                          = 0x3ffe000a,
	PR_FROM_I_HAVE                                      = 0x3fff000b,
	PR_FROM_I_HAVE_ERROR                                = 0x3fff000a,
	PR_NEW_ATTACH                                       = 0x40000003,
	PR_NEW_ATTACH_ERROR                                 = 0x4000000a,
	PR_START_EMBED                                      = 0x40010003,
	PR_START_EMBED_ERROR                                = 0x4001000a,
	PR_END_EMBED                                        = 0x40020003,
	PR_END_EMBED_ERROR                                  = 0x4002000a,
	PR_START_RECIP                                      = 0x40030003,
	PR_START_RECIP_ERROR                                = 0x4003000a,
	PR_END_RECIP                                        = 0x40040003,
	PR_END_RECIP_ERROR                                  = 0x4004000a,
	PR_END_CC_RECIP                                     = 0x40050003,
	PR_END_CC_RECIP_ERROR                               = 0x4005000a,
	PR_END_BCC_RECIP                                    = 0x40060003,
	PR_END_BCC_RECIP_ERROR                              = 0x4006000a,
	PR_END_P1_RECIP                                     = 0x40070003,
	PR_END_P1_RECIP_ERROR                               = 0x4007000a,
	PR_START_TOP_FLD                                    = 0x40090003,
	PR_START_TOP_FLD_ERROR                              = 0x4009000a,
	PR_START_SUB_FLD                                    = 0x400a0003,
	PR_START_SUB_FLD_ERROR                              = 0x400a000a,
	PR_END_FOLDER                                       = 0x400b0003,
	PR_END_FOLDER_ERROR                                 = 0x400b000a,
	PR_START_MESSAGE                                    = 0x400c0003,
	PR_START_MESSAGE_ERROR                              = 0x400c000a,
	PR_END_MESSAGE                                      = 0x400d0003,
	PR_END_MESSAGE_ERROR                                = 0x400d000a,
	PR_END_ATTACH                                       = 0x400e0003,
	PR_END_ATTACH_ERROR                                 = 0x400e000a,
	PR_EC_WARNING                                       = 0x400f0003,
	PR_EC_WARNING_ERROR                                 = 0x400f000a,
	PR_START_FAI_MSG                                    = 0x40100003,
	PR_START_FAI_MSG_ERROR                              = 0x4010000a,
	PR_NEW_FX_FOLDER                                    = 0x40110102,
	PR_NEW_FX_FOLDER_ERROR                              = 0x4011000a,
	PR_INCR_SYNC_CHG                                    = 0x40120003,
	PR_INCR_SYNC_CHG_ERROR                              = 0x4012000a,
	PR_INCR_SYNC_DEL                                    = 0x40130003,
	PR_INCR_SYNC_DEL_ERROR                              = 0x4013000a,
	PR_INCR_SYNC_END                                    = 0x40140003,
	PR_INCR_SYNC_END_ERROR                              = 0x4014000a,
	PR_INCR_SYNC_MSG                                    = 0x40150003,
	PR_INCR_SYNC_MSG_ERROR                              = 0x4015000a,
	PR_FX_DEL_PROP                                      = 0x40160003,
	PR_FX_DEL_PROP_ERROR                                = 0x4016000a,
	PR_IDSET_GIVEN                                      = 0x40170003,
	PR_IDSET_GIVEN_ERROR                                = 0x4017000a,
	PR_SENDER_FLAGS                                     = 0x40190003,
	PR_SENDER_FLAGS_ERROR                               = 0x4019000a,
	PR_SENT_REPRESENTING_FLAGS                          = 0x401a0003,
	PR_SENT_REPRESENTING_FLAGS_ERROR                    = 0x401a000a,
	PR_RCVD_BY_FLAGS                                    = 0x401b0003,
	PR_RCVD_BY_FLAGS_ERROR                              = 0x401b000a,
	PR_RCVD_REPRESENTING_FLAGS                          = 0x401c0003,
	PR_RCVD_REPRESENTING_FLAGS_ERROR                    = 0x401c000a,
	PR_ORIGINAL_SENDER_FLAGS                            = 0x401d0003,
	PR_ORIGINAL_SENDER_FLAGS_ERROR                      = 0x401d000a,
	PR_ORIGINAL_SENT_REPRESENTING_FLAGS                 = 0x401e0003,
	PR_ORIGINAL_SENT_REPRESENTING_FLAGS_ERROR           = 0x401e000a,
	PR_REPORT_FLAGS                                     = 0x401f0003,
	PR_REPORT_FLAGS_ERROR                               = 0x401f000a,
	PR_READ_RECEIPT_FLAGS                               = 0x40200003,
	PR_READ_RECEIPT_FLAGS_ERROR                         = 0x4020000a,
	PR_SOFT_DELETES                                     = 0x4021000b,
	PR_SOFT_DELETES_ERROR                               = 0x4021000a,
	PR_MESSAGE_SUBMISSION_ID_FROM_CLIENT                = 0x402c0102,
	PR_MESSAGE_SUBMISSION_ID_FROM_CLIENT_ERROR          = 0x402c000a,
	PR_SENDER_SIMPLE_DISP_NAME                          = 0x4030001e,
	PR_SENDER_SIMPLE_DISP_NAME_UNICODE                  = 0x4030001f,
	PR_SENDER_SIMPLE_DISP_NAME_ERROR                    = 0x4030000a,
	PR_SENT_REPRESENTING_SIMPLE_DISP_NAME               = 0x4031001e,
	PR_SENT_REPRESENTING_SIMPLE_DISP_NAME_UNICODE       = 0x4031001f,
	PR_SENT_REPRESENTING_SIMPLE_DISP_NAME_ERROR         = 0x4031000a,
	PR_CREATOR_SIMPLE_DISP_NAME                         = 0x4038001e,
	PR_CREATOR_SIMPLE_DISP_NAME_UNICODE                 = 0x4038001f,
	PR_CREATOR_SIMPLE_DISP_NAME_ERROR                   = 0x4038000a,
	PR_ORG_ADDR_TYPE                                    = 0x403d001e,
	PR_ORG_ADDR_TYPE_UNICODE                            = 0x403d001f,
	PR_ORG_ADDR_TYPE_ERROR                              = 0x403d000a,
	PR_ORG_EMAIL_ADDR                                   = 0x403e001e,
	PR_ORG_EMAIL_ADDR_UNICODE                           = 0x403e001f,
	PR_ORG_EMAIL_ADDR_ERROR                             = 0x403e000a,
	PR_CREATOR_FLAGS                                    = 0x40590003,
	PR_CREATOR_FLAGS_ERROR                              = 0x4059000a,
	PR_MODIFIER_FLAGS                                   = 0x405a0003,
	PR_MODIFIER_FLAGS_ERROR                             = 0x405a000a,
	PR_ORIGINATOR_FLAGS                                 = 0x405b0003,
	PR_ORIGINATOR_FLAGS_ERROR                           = 0x405b000a,
	PR_REPORT_DESTINATION_FLAGS                         = 0x405c0003,
	PR_REPORT_DESTINATION_FLAGS_ERROR                   = 0x405c000a,
	PR_ORIGINAL_AUTHOR_FLAGS                            = 0x405d0003,
	PR_ORIGINAL_AUTHOR_FLAGS_ERROR                      = 0x405d000a,
	PR_ORIGINATOR_SEARCH_KEY                            = 0x40610102,
	PR_ORIGINATOR_SEARCH_KEY_ERROR                      = 0x4061000a,
	PR_REPORT_DESTINATION_SEARCH_KEY                    = 0x40640102,
	PR_REPORT_DESTINATION_SEARCH_KEY_ERROR              = 0x4064000a,
	PR_ER_FLAG                                          = 0x40650003,
	PR_ER_FLAG_ERROR                                    = 0x4065000a,
	PR_INTERNET_SUBJECT                                 = 0x40680102,
	PR_INTERNET_SUBJECT_ERROR                           = 0x4068000a,
	PR_INTERNET_SENT_REPRESENTING_NAME                  = 0x40690102,
	PR_INTERNET_SENT_REPRESENTING_NAME_ERROR            = 0x4069000a,
	PR_INET_MAIL_OVERRIDE_FORMAT                        = 0x59020003,
	PR_INET_MAIL_OVERRIDE_FORMAT_ERROR                  = 0x5902000a,
	PR_MSG_EDITOR_FORMAT                                = 0x59090003,
	PR_MSG_EDITOR_FORMAT_ERROR                          = 0x5909000a,
	PR_DOTSTUFF_STATE                                   = 0x60010003,
	PR_DOTSTUFF_STATE_ERROR                             = 0x6001000a,
	PR_RULE_SERVER_RULE_ID                              = 0x65a00014,
	PR_RULE_SERVER_RULE_ID_ERROR                        = 0x65a0000a,
	PR_REPLY_TEMPLATE_ID                                = 0x65c20102,
	PR_REPLY_TEMPLATE_ID_ERROR                          = 0x65c2000a,
	PR_SOURCE_KEY                                       = 0x65e00102,
	PR_SOURCE_KEY_ERROR                                 = 0x65e0000a,
	PR_PARENT_SOURCE_KEY                                = 0x65e10102,
	PR_PARENT_SOURCE_KEY_ERROR                          = 0x65e1000a,
	PR_CHANGE_KEY                                       = 0x65e20102,
	PR_CHANGE_KEY_ERROR                                 = 0x65e2000a,
	PR_PREDECESSOR_CHANGE_LIST                          = 0x65e30102,
	PR_PREDECESSOR_CHANGE_LIST_ERROR                    = 0x65e3000a,
	PR_SYNCHRONIZE_FLAGS                                = 0x65e40003,
	PR_SYNCHRONIZE_FLAGS_ERROR                          = 0x65e4000a,
	PR_AUTO_ADD_NEW_SUBS                                = 0x65e5000b,
	PR_AUTO_ADD_NEW_SUBS_ERROR                          = 0x65e5000a,
	PR_NEW_SUBS_GET_AUTO_ADD                            = 0x65e6000b,
	PR_NEW_SUBS_GET_AUTO_ADD_ERROR                      = 0x65e6000a,
	PR_MESSAGE_SITE_NAME                                = 0x65e7001e,
	PR_MESSAGE_SITE_NAME_UNICODE                        = 0x65e7001f,
	PR_MESSAGE_SITE_NAME_ERROR                          = 0x65e7000a,
	PR_MESSAGE_PROCESSED                                = 0x65e8000b,
	PR_MESSAGE_PROCESSED_ERROR                          = 0x65e8000a,
	PR_RULE_MSG_STATE                                   = 0x65e90003,
	PR_RULE_MSG_STATE_ERROR                             = 0x65e9000a,
	PR_RULE_MSG_USER_FLAGS                              = 0x65ea0003,
	PR_RULE_MSG_USER_FLAGS_ERROR                        = 0x65ea000a,
	PR_RULE_MSG_PROVIDER                                = 0x65eb001e,
	PR_RULE_MSG_PROVIDER_UNICODE                        = 0x65eb001f,
	PR_RULE_MSG_PROVIDER_ERROR                          = 0x65eb000a,
	PR_RULE_MSG_NAME                                    = 0x65ec001e,
	PR_RULE_MSG_NAME_UNICODE                            = 0x65ec001f,
	PR_RULE_MSG_NAME_ERROR                              = 0x65ec000a,
	PR_RULE_MSG_LEVEL                                   = 0x65ed0003,
	PR_RULE_MSG_LEVEL_ERROR                             = 0x65ed000a,
	PR_RULE_MSG_PROVIDER_DATA                           = 0x65ee0102,
	PR_RULE_MSG_PROVIDER_DATA_ERROR                     = 0x65ee000a,
	PR_RULE_MSG_ACTIONS                                 = 0x65ef0102,
	PR_RULE_MSG_ACTIONS_ERROR                           = 0x65ef000a,
	PR_RULE_MSG_CONDITION                               = 0x65f00102,
	PR_RULE_MSG_CONDITION_ERROR                         = 0x65f0000a,
	PR_RULE_MSG_CONDITION_LCID                          = 0x65f10003,
	PR_RULE_MSG_CONDITION_LCID_ERROR                    = 0x65f1000a,
	PR_RULE_MSG_VERSION                                 = 0x65f20002,
	PR_RULE_MSG_VERSION_ERROR                           = 0x65f2000a,
	PR_RULE_MSG_SEQUENCE                                = 0x65f30003,
	PR_RULE_MSG_SEQUENCE_ERROR                          = 0x65f3000a,
	PR_PREVENT_MSG_CREATE                               = 0x65f4000b,
	PR_PREVENT_MSG_CREATE_ERROR                         = 0x65f4000a,
	PR_IMAP_INTERNAL_DATE                               = 0x65f50040,
	PR_IMAP_INTERNAL_DATE_ERROR                         = 0x65f5000a,
	PR_PROFILE_VERSION                                  = 0x66000003,
	PR_PROFILE_VERSION_ERROR                            = 0x6600000a,
	PR_PROFILE_CONFIG_FLAGS                             = 0x66010003,
	PR_PROFILE_CONFIG_FLAGS_ERROR                       = 0x6601000a,
	PR_PROFILE_HOME_SERVER                              = 0x6602001e,
	PR_PROFILE_HOME_SERVER_UNICODE                      = 0x6602001f,
	PR_PROFILE_HOME_SERVER_ERROR                        = 0x6602000a,
	PR_PROFILE_USER                                     = 0x6603001e,
	PR_PROFILE_USER_UNICODE                             = 0x6603001f,
	PR_PROFILE_USER_ERROR                               = 0x6603000a,
	PR_PROFILE_CONNECT_FLAGS                            = 0x66040003,
	PR_PROFILE_CONNECT_FLAGS_ERROR                      = 0x6604000a,
	PR_PROFILE_TRANSPORT_FLAGS                          = 0x66050003,
	PR_PROFILE_TRANSPORT_FLAGS_ERROR                    = 0x6605000a,
	PR_PROFILE_UI_STATE                                 = 0x66060003,
	PR_PROFILE_UI_STATE_ERROR                           = 0x6606000a,
	PR_PROFILE_UNRESOLVED_NAME                          = 0x6607001e,
	PR_PROFILE_UNRESOLVED_NAME_UNICODE                  = 0x6607001f,
	PR_PROFILE_UNRESOLVED_NAME_ERROR                    = 0x6607000a,
	PR_PROFILE_UNRESOLVED_SERVER                        = 0x6608001e,
	PR_PROFILE_UNRESOLVED_SERVER_UNICODE                = 0x6608001f,
	PR_PROFILE_UNRESOLVED_SERVER_ERROR                  = 0x6608000a,
	PR_PROFILE_OPEN_FLAGS                               = 0x66090003,
	PR_PROFILE_OPEN_FLAGS_ERROR                         = 0x6609000a,
	PR_PROFILE_BINDING_ORDER                            = 0x6609001e,
	PR_PROFILE_BINDING_ORDER_UNICODE                    = 0x6609001f,
	PR_PROFILE_TYPE                                     = 0x660a0003,
	PR_PROFILE_TYPE_ERROR                               = 0x660a000a,
	PR_PROFILE_MAILBOX                                  = 0x660b001e,
	PR_PROFILE_MAILBOX_UNICODE                          = 0x660b001f,
	PR_PROFILE_MAILBOX_ERROR                            = 0x660b000a,
	PR_PROFILE_SERVER                                   = 0x660c001e,
	PR_PROFILE_SERVER_UNICODE                           = 0x660c001f,
	PR_PROFILE_SERVER_ERROR                             = 0x660c000a,
	PR_PROFILE_MAX_RESTRICT                             = 0x660d0003,
	PR_PROFILE_MAX_RESTRICT_ERROR                       = 0x660d000a,
	PR_PROFILE_AB_FILES_PATH                            = 0x660e001e,
	PR_PROFILE_AB_FILES_PATH_UNICODE                    = 0x660e001f,
	PR_PROFILE_AB_FILES_PATH_ERROR                      = 0x660e000a,
	PR_PROFILE_FAVFLD_DISPLAY_NAME                      = 0x660f001e,
	PR_PROFILE_FAVFLD_DISPLAY_NAME_UNICODE              = 0x660f001f,
	PR_PROFILE_FAVFLD_DISPLAY_NAME_ERROR                = 0x660f000a,
	PR_PROFILE_OFFLINE_STORE_PATH                       = 0x6610001e,
	PR_PROFILE_OFFLINE_STORE_PATH_UNICODE               = 0x6610001f,
	PR_PROFILE_OFFLINE_STORE_PATH_ERROR                 = 0x6610000a,
	PR_PROFILE_OFFLINE_INFO                             = 0x66110102,
	PR_PROFILE_OFFLINE_INFO_ERROR                       = 0x6611000a,
	PR_PROFILE_HOME_SERVER_DN                           = 0x6612001e,
	PR_PROFILE_HOME_SERVER_DN_UNICODE                   = 0x6612001f,
	PR_PROFILE_HOME_SERVER_DN_ERROR                     = 0x6612000a,
	PR_PROFILE_HOME_SERVER_ADDRS                        = 0x6613101e,
	PR_PROFILE_HOME_SERVER_ADDRS_UNICODE                = 0x6613101f,
	PR_PROFILE_HOME_SERVER_ADDRS_ERROR                  = 0x6613000a,
	PR_PROFILE_SERVER_DN                                = 0x6614001e,
	PR_PROFILE_SERVER_DN_UNICODE                        = 0x6614001f,
	PR_PROFILE_SERVER_DN_ERROR                          = 0x6614000a,
	PR_PROFILE_FAVFLD_COMMENT                           = 0x6615001e,
	PR_PROFILE_FAVFLD_COMMENT_UNICODE                   = 0x6615001f,
	PR_PROFILE_FAVFLD_COMMENT_ERROR                     = 0x6615000a,
	PR_PROFILE_ALLPUB_DISPLAY_NAME                      = 0x6616001e,
	PR_PROFILE_ALLPUB_DISPLAY_NAME_UNICODE              = 0x6616001f,
	PR_PROFILE_ALLPUB_DISPLAY_NAME_ERROR                = 0x6616000a,
	PR_PROFILE_ALLPUB_COMMENT                           = 0x6617001e,
	PR_PROFILE_ALLPUB_COMMENT_UNICODE                   = 0x6617001f,
	PR_PROFILE_ALLPUB_COMMENT_ERROR                     = 0x6617000a,
	PR_DISABLE_WINSOCK                                  = 0x66180003,
	PR_DISABLE_WINSOCK_ERROR                            = 0x6618000a,
	PR_IN_TRANSIT                                       = 0x6618000b,
	PR_PROFILE_AUTH_PACKAGE                             = 0x66190003,
	PR_PROFILE_AUTH_PACKAGE_ERROR                       = 0x6619000a,
	PR_USER_ENTRYID                                     = 0x66190102,
	PR_USER_NAME                                        = 0x661a001e,
	PR_USER_NAME_UNICODE                                = 0x661a001f,
	PR_USER_NAME_ERROR                                  = 0x661a000a,
	PR_MAILBOX_OWNER_ENTRYID                            = 0x661b0102,
	PR_MAILBOX_OWNER_ENTRYID_ERROR                      = 0x661b000a,
	PR_MAILBOX_OWNER_NAME                               = 0x661c001e,
	PR_MAILBOX_OWNER_NAME_UNICODE                       = 0x661c001f,
	PR_MAILBOX_OWNER_NAME_ERROR                         = 0x661c000a,
	PR_OOF_STATE                                        = 0x661d000b,
	PR_OOF_STATE_ERROR                                  = 0x661d000a,
	PR_SCHEDULE_FOLDER_ENTRYID                          = 0x661e0102,
	PR_SCHEDULE_FOLDER_ENTRYID_ERROR                    = 0x661e000a,
	PR_IPM_DAF_ENTRYID                                  = 0x661f0102,
	PR_IPM_DAF_ENTRYID_ERROR                            = 0x661f000a,
	PR_NON_IPM_SUBTREE_ENTRYID                          = 0x66200102,
	PR_NON_IPM_SUBTREE_ENTRYID_ERROR                    = 0x6620000a,
	PR_EFORMS_REGISTRY_ENTRYID                          = 0x66210102,
	PR_EFORMS_REGISTRY_ENTRYID_ERROR                    = 0x6621000a,
	PR_SPLUS_FREE_BUSY_ENTRYID                          = 0x66220102,
	PR_SPLUS_FREE_BUSY_ENTRYID_ERROR                    = 0x6622000a,
	PR_HIERARCHY_SERVER                                 = 0x6623001e,
	PR_HIERARCHY_SERVER_UNICODE                         = 0x6623001f,
	PR_HIERARCHY_SERVER_ERROR                           = 0x6623000a,
	PR_OFFLINE_ADDRBOOK_ENTRYID                         = 0x66230102,
	PR_EFORMS_FOR_LOCALE_ENTRYID                        = 0x66240102,
	PR_EFORMS_FOR_LOCALE_ENTRYID_ERROR                  = 0x6624000a,
	PR_FREE_BUSY_FOR_LOCAL_SITE_ENTRYID                 = 0x66250102,
	PR_FREE_BUSY_FOR_LOCAL_SITE_ENTRYID_ERROR           = 0x6625000a,
	PR_ADDRBOOK_FOR_LOCAL_SITE_ENTRYID                  = 0x66260102,
	PR_ADDRBOOK_FOR_LOCAL_SITE_ENTRYID_ERROR            = 0x6626000a,
	PR_OFFLINE_MESSAGE_ENTRYID                          = 0x66270102,
	PR_OFFLINE_MESSAGE_ENTRYID_ERROR                    = 0x6627000a,
	PR_GW_MTSIN_ENTRYID                                 = 0x66280102,
	PR_GW_MTSIN_ENTRYID_ERROR                           = 0x6628000a,
	PR_GW_MTSOUT_ENTRYID                                = 0x66290102,
	PR_GW_MTSOUT_ENTRYID_ERROR                          = 0x6629000a,
	PR_TRANSFER_ENABLED                                 = 0x662a000b,
	PR_TRANSFER_ENABLED_ERROR                           = 0x662a000a,
	PR_TEST_LINE_SPEED                                  = 0x662b0102,
	PR_TEST_LINE_SPEED_ERROR                            = 0x662b000a,
	PR_HIERARCHY_SYNCHRONIZER                           = 0x662c000d,
	PR_HIERARCHY_SYNCHRONIZER_ERROR                     = 0x662c000a,
	PR_CONTENTS_SYNCHRONIZER                            = 0x662d000d,
	PR_CONTENTS_SYNCHRONIZER_ERROR                      = 0x662d000a,
	PR_COLLECTOR                                        = 0x662e000d,
	PR_COLLECTOR_ERROR                                  = 0x662e000a,
	PR_FAST_TRANSFER                                    = 0x662f000d,
	PR_FAST_TRANSFER_ERROR                              = 0x662f000a,
	PR_IPM_FAVORITES_ENTRYID                            = 0x66300102,
	PR_IPM_FAVORITES_ENTRYID_ERROR                      = 0x6630000a,
	PR_IPM_PUBLIC_FOLDERS_ENTRYID                       = 0x66310102,
	PR_IPM_PUBLIC_FOLDERS_ENTRYID_ERROR                 = 0x6631000a,
	PR_STORE_OFFLINE                                    = 0x6632000b,
	PR_STORE_OFFLINE_ERROR                              = 0x6632000a,
	PR_CHANGE_ADVISOR                                   = 0x6634000d,
	PR_CHANGE_ADVISOR_ERROR                             = 0x6634000a,
	PR_FAVORITES_DEFAULT_NAME                           = 0x6635001e,
	PR_FAVORITES_DEFAULT_NAME_UNICODE                   = 0x6635001f,
	PR_FAVORITES_DEFAULT_NAME_ERROR                     = 0x6635000a,
	PR_SYS_CONFIG_FOLDER_ENTRYID                        = 0x66360102,
	PR_SYS_CONFIG_FOLDER_ENTRYID_ERROR                  = 0x6636000a,
	PR_CHANGE_NOTIFICATION_GUID                         = 0x66370048,
	PR_CHANGE_NOTIFICATION_GUID_ERROR                   = 0x6637000a,
	PR_FOLDER_CHILD_COUNT                               = 0x66380003,
	PR_FOLDER_CHILD_COUNT_ERROR                         = 0x6638000a,
	PR_RIGHTS                                           = 0x66390003,
	PR_RIGHTS_ERROR                                     = 0x6639000a,
	PR_HAS_RULES                                        = 0x663a000b,
	PR_HAS_RULES_ERROR                                  = 0x663a000a,
	PR_ADDRESS_BOOK_ENTRYID                             = 0x663b0102,
	PR_ADDRESS_BOOK_ENTRYID_ERROR                       = 0x663b000a,
	PR_PUBLIC_FOLDER_ENTRYID                            = 0x663c0102,
	PR_PUBLIC_FOLDER_ENTRYID_ERROR                      = 0x663c000a,
	PR_OFFLINE_FLAGS                                    = 0x663d0003,
	PR_OFFLINE_FLAGS_ERROR                              = 0x663d000a,
	PR_HIERARCHY_CHANGE_NUM                             = 0x663e0003,
	PR_HIERARCHY_CHANGE_NUM_ERROR                       = 0x663e000a,
	PR_HAS_MODERATOR_RULES                              = 0x663f000b,
	PR_HAS_MODERATOR_RULES_ERROR                        = 0x663f000a,
	PR_DELETED_MSG_COUNT                                = 0x66400003,
	PR_DELETED_MSG_COUNT_ERROR                          = 0x6640000a,
	PR_DELETED_FOLDER_COUNT                             = 0x66410003,
	PR_DELETED_FOLDER_COUNT_ERROR                       = 0x6641000a,
	PR_OLDEST_DELETED_ON                                = 0x66420040,
	PR_OLDEST_DELETED_ON_ERROR                          = 0x6642000a,
	PR_DELETED_ASSOC_MSG_COUNT                          = 0x66430003,
	PR_DELETED_ASSOC_MSG_COUNT_ERROR                    = 0x6643000a,
	PR_REPLICA_SERVER                                   = 0x6644001e,
	PR_REPLICA_SERVER_UNICODE                           = 0x6644001f,
	PR_REPLICA_SERVER_ERROR                             = 0x6644000a,
	PR_CLIENT_ACTIONS                                   = 0x66450102,
	PR_CLIENT_ACTIONS_ERROR                             = 0x6645000a,
	PR_DAM_ORIGINAL_ENTRYID                             = 0x66460102,
	PR_DAM_ORIGINAL_ENTRYID_ERROR                       = 0x6646000a,
	PR_DAM_BACK_PATCHED                                 = 0x6647000b,
	PR_DAM_BACK_PATCHED_ERROR                           = 0x6647000a,
	PR_RULE_ERROR                                       = 0x66480003,
	PR_RULE_ERROR_ERROR                                 = 0x6648000a,
	PR_RULE_ACTION_TYPE                                 = 0x66490003,
	PR_RULE_ACTION_TYPE_ERROR                           = 0x6649000a,
	PR_HAS_NAMED_PROPERTIES                             = 0x664a000b,
	PR_HAS_NAMED_PROPERTIES_ERROR                       = 0x664a000a,
	PR_REPLICA_VERSION                                  = 0x664b0014,
	PR_REPLICA_VERSION_ERROR                            = 0x664b000a,
	PR_RULE_ACTION_NUMBER                               = 0x66500003,
	PR_RULE_ACTION_NUMBER_ERROR                         = 0x6650000a,
	PR_RULE_FOLDER_ENTRYID                              = 0x66510102,
	PR_RULE_FOLDER_ENTRYID_ERROR                        = 0x6651000a,
	PR_ACTIVE_USER_ENTRYID                              = 0x66520102,
	PR_ACTIVE_USER_ENTRYID_ERROR                        = 0x6652000a,
	PR_0X400_ENVELOPE_TYPE                              = 0x66530003,
	PR_0X400_ENVELOPE_TYPE_ERROR                        = 0x6653000a,
	PR_MSG_FOLD_TIME                                    = 0x66540040,
	PR_MSG_FOLD_TIME_ERROR                              = 0x6654000a,
	PR_ICS_CHANGE_KEY                                   = 0x66550102,
	PR_ICS_CHANGE_KEY_ERROR                             = 0x6655000a,
	PR_GW_ADMIN_OPERATIONS                              = 0x66580003,
	PR_GW_ADMIN_OPERATIONS_ERROR                        = 0x6658000a,
	PR_INTERNET_CONTENT                                 = 0x66590102,
	PR_INTERNET_CONTENT_ERROR                           = 0x6659000a,
	PR_HAS_ATTACH_FROM_IMAIL                            = 0x665a000b,
	PR_HAS_ATTACH_FROM_IMAIL_ERROR                      = 0x665a000a,
	PR_ORIGINATOR_NAME                                  = 0x665b001e,
	PR_ORIGINATOR_NAME_UNICODE                          = 0x665b001f,
	PR_ORIGINATOR_NAME_ERROR                            = 0x665b000a,
	PR_ORIGINATOR_ADDR                                  = 0x665c001e,
	PR_ORIGINATOR_ADDR_UNICODE                          = 0x665c001f,
	PR_ORIGINATOR_ADDR_ERROR                            = 0x665c000a,
	PR_ORIGINATOR_ADDRTYPE                              = 0x665d001e,
	PR_ORIGINATOR_ADDRTYPE_UNICODE                      = 0x665d001f,
	PR_ORIGINATOR_ADDRTYPE_ERROR                        = 0x665d000a,
	PR_ORIGINATOR_ENTRYID                               = 0x665e0102,
	PR_ORIGINATOR_ENTRYID_ERROR                         = 0x665e000a,
	PR_ARRIVAL_TIME                                     = 0x665f0040,
	PR_ARRIVAL_TIME_ERROR                               = 0x665f000a,
	PR_TRACE_INFO                                       = 0x66600102,
	PR_TRACE_INFO_ERROR                                 = 0x6660000a,
	PR_SUBJECT_TRACE_INFO                               = 0x66610102,
	PR_SUBJECT_TRACE_INFO_ERROR                         = 0x6661000a,
	PR_RECIPIENT_NUMBER                                 = 0x66620003,
	PR_RECIPIENT_NUMBER_ERROR                           = 0x6662000a,
	PR_MTS_SUBJECT_ID                                   = 0x66630102,
	PR_MTS_SUBJECT_ID_ERROR                             = 0x6663000a,
	PR_REPORT_DESTINATION_NAME                          = 0x6664001e,
	PR_REPORT_DESTINATION_NAME_UNICODE                  = 0x6664001f,
	PR_REPORT_DESTINATION_NAME_ERROR                    = 0x6664000a,
	PR_REPORT_DESTINATION_ENTRYID                       = 0x66650102,
	PR_REPORT_DESTINATION_ENTRYID_ERROR                 = 0x6665000a,
	PR_CONTENT_SEARCH_KEY                               = 0x66660102,
	PR_CONTENT_SEARCH_KEY_ERROR                         = 0x6666000a,
	PR_FOREIGN_ID                                       = 0x66670102,
	PR_FOREIGN_ID_ERROR                                 = 0x6667000a,
	PR_FOREIGN_REPORT_ID                                = 0x66680102,
	PR_FOREIGN_REPORT_ID_ERROR                          = 0x6668000a,
	PR_FOREIGN_SUBJECT_ID                               = 0x66690102,
	PR_FOREIGN_SUBJECT_ID_ERROR                         = 0x6669000a,
	PR_INTERNAL_TRACE_INFO                              = 0x666a0102,
	PR_INTERNAL_TRACE_INFO_ERROR                        = 0x666a000a,
	PR_IN_CONFLICT                                      = 0x666c000b,
	PR_IN_CONFLICT_ERROR                                = 0x666c000a,
	PR_LONGTERM_ENTRYID_FROM_TABLE                      = 0x66700102,
	PR_LONGTERM_ENTRYID_FROM_TABLE_ERROR                = 0x6670000a,
	PR_MEMBER_ID                                        = 0x66710014,
	PR_MEMBER_ID_ERROR                                  = 0x6671000a,
	PR_MEMBER_NAME                                      = 0x6672001e,
	PR_MEMBER_NAME_UNICODE                              = 0x6672001f,
	PR_MEMBER_NAME_ERROR                                = 0x6672000a,
	PR_MEMBER_RIGHTS                                    = 0x66730003,
	PR_MEMBER_RIGHTS_ERROR                              = 0x6673000a,
	PR_RULE_ID                                          = 0x66740014,
	PR_RULE_ID_ERROR                                    = 0x6674000a,
	PR_RULE_IDS                                         = 0x66750102,
	PR_RULE_IDS_ERROR                                   = 0x6675000a,
	PR_RULE_SEQUENCE                                    = 0x66760003,
	PR_RULE_SEQUENCE_ERROR                              = 0x6676000a,
	PR_RULE_STATE                                       = 0x66770003,
	PR_RULE_STATE_ERROR                                 = 0x6677000a,
	PR_RULE_USER_FLAGS                                  = 0x66780003,
	PR_RULE_USER_FLAGS_ERROR                            = 0x6678000a,
	PR_RULE_CONDITION                                   = 0x667900fd,
	PR_RULE_CONDITION_ERROR                             = 0x6679000a,
	PR_PROFILE_MOAB                                     = 0x667b001e,
	PR_PROFILE_MOAB_UNICODE                             = 0x667b001f,
	PR_PROFILE_MOAB_ERROR                               = 0x667b000a,
	PR_PROFILE_MOAB_GUID                                = 0x667c001e,
	PR_PROFILE_MOAB_GUID_UNICODE                        = 0x667c001f,
	PR_PROFILE_MOAB_GUID_ERROR                          = 0x667c000a,
	PR_PROFILE_MOAB_SEQ                                 = 0x667d0003,
	PR_PROFILE_MOAB_SEQ_ERROR                           = 0x667d000a,
	PR_IMPLIED_RESTRICTIONS                             = 0x667f1102,
	PR_IMPLIED_RESTRICTIONS_ERROR                       = 0x667f000a,
	PR_RULE_ACTIONS                                     = 0x668000fe,
	PR_RULE_ACTIONS_ERROR                               = 0x6680000a,
	PR_RULE_PROVIDER                                    = 0x6681001e,
	PR_RULE_PROVIDER_UNICODE                            = 0x6681001f,
	PR_RULE_PROVIDER_ERROR                              = 0x6681000a,
	PR_RULE_NAME                                        = 0x6682001e,
	PR_RULE_NAME_UNICODE                                = 0x6682001f,
	PR_RULE_NAME_ERROR                                  = 0x6682000a,
	PR_RULE_LEVEL                                       = 0x66830003,
	PR_RULE_LEVEL_ERROR                                 = 0x6683000a,
	PR_RULE_PROVIDER_DATA                               = 0x66840102,
	PR_RULE_PROVIDER_DATA_ERROR                         = 0x6684000a,
	PR_LAST_FULL_BACKUP                                 = 0x66850040,
	PR_LAST_FULL_BACKUP_ERROR                           = 0x6685000a,
	PR_PROFILE_ADDR_INFO                                = 0x66870102,
	PR_PROFILE_ADDR_INFO_ERROR                          = 0x6687000a,
	PR_PROFILE_OPTIONS_DATA                             = 0x66890102,
	PR_PROFILE_OPTIONS_DATA_ERROR                       = 0x6689000a,
	PR_EVENTS_ROOT_FOLDER_ENTRYID                       = 0x668a0102,
	PR_EVENTS_ROOT_FOLDER_ENTRYID_ERROR                 = 0x668a000a,
	PR_INBOUND_NEWSFEED_DN                              = 0x668d001e,
	PR_INBOUND_NEWSFEED_DN_UNICODE                      = 0x668d001f,
	PR_INBOUND_NEWSFEED_DN_ERROR                        = 0x668d000a,
	PR_OUTBOUND_NEWSFEED_DN                             = 0x668e001e,
	PR_OUTBOUND_NEWSFEED_DN_UNICODE                     = 0x668e001f,
	PR_OUTBOUND_NEWSFEED_DN_ERROR                       = 0x668e000a,
	PR_DELETED_ON                                       = 0x668f0040,
	PR_DELETED_ON_ERROR                                 = 0x668f000a,
	PR_REPLICATION_STYLE                                = 0x66900003,
	PR_REPLICATION_STYLE_ERROR                          = 0x6690000a,
	PR_REPLICATION_SCHEDULE                             = 0x66910102,
	PR_REPLICATION_SCHEDULE_ERROR                       = 0x6691000a,
	PR_REPLICATION_MESSAGE_PRIORITY                     = 0x66920003,
	PR_REPLICATION_MESSAGE_PRIORITY_ERROR               = 0x6692000a,
	PR_OVERALL_MSG_AGE_LIMIT                            = 0x66930003,
	PR_OVERALL_MSG_AGE_LIMIT_ERROR                      = 0x6693000a,
	PR_REPLICATION_ALWAYS_INTERVAL                      = 0x66940003,
	PR_REPLICATION_ALWAYS_INTERVAL_ERROR                = 0x6694000a,
	PR_REPLICATION_MSG_SIZE                             = 0x66950003,
	PR_REPLICATION_MSG_SIZE_ERROR                       = 0x6695000a,
	PR_IS_NEWSGROUP_ANCHOR                              = 0x6696000b,
	PR_IS_NEWSGROUP_ANCHOR_ERROR                        = 0x6696000a,
	PR_IS_NEWSGROUP                                     = 0x6697000b,
	PR_IS_NEWSGROUP_ERROR                               = 0x6697000a,
	PR_REPLICA_LIST                                     = 0x66980102,
	PR_REPLICA_LIST_ERROR                               = 0x6698000a,
	PR_OVERALL_AGE_LIMIT                                = 0x66990003,
	PR_OVERALL_AGE_LIMIT_ERROR                          = 0x6699000a,
	PR_INTERNET_CHARSET                                 = 0x669a001e,
	PR_INTERNET_CHARSET_UNICODE                         = 0x669a001f,
	PR_INTERNET_CHARSET_ERROR                           = 0x669a000a,
	PR_DELETED_MESSAGE_SIZE_EXTENDED                    = 0x669b0014,
	PR_DELETED_MESSAGE_SIZE_EXTENDED_ERROR              = 0x669b000a,
	PR_DELETED_NORMAL_MESSAGE_SIZE_EXTENDED             = 0x669c0014,
	PR_DELETED_NORMAL_MESSAGE_SIZE_EXTENDED_ERROR       = 0x669c000a,
	PR_DELETED_ASSOC_MESSAGE_SIZE_EXTENDED              = 0x669d0014,
	PR_DELETED_ASSOC_MESSAGE_SIZE_EXTENDED_ERROR        = 0x669d000a,
	PR_SECURE_IN_SITE                                   = 0x669e000b,
	PR_SECURE_IN_SITE_ERROR                             = 0x669e000a,
	PR_NT_USER_NAME                                     = 0x66a0001e,
	PR_NT_USER_NAME_UNICODE                             = 0x66a0001f,
	PR_NT_USER_NAME_ERROR                               = 0x66a0000a,
	PR_LOCALE_ID                                        = 0x66a10003,
	PR_LOCALE_ID_ERROR                                  = 0x66a1000a,
	PR_LAST_LOGON_TIME                                  = 0x66a20040,
	PR_LAST_LOGON_TIME_ERROR                            = 0x66a2000a,
	PR_LAST_LOGOFF_TIME                                 = 0x66a30040,
	PR_LAST_LOGOFF_TIME_ERROR                           = 0x66a3000a,
	PR_STORAGE_LIMIT_INFORMATION                        = 0x66a40003,
	PR_STORAGE_LIMIT_INFORMATION_ERROR                  = 0x66a4000a,
	PR_NEWSGROUP_COMPONENT                              = 0x66a5001e,
	PR_NEWSGROUP_COMPONENT_UNICODE                      = 0x66a5001f,
	PR_NEWSGROUP_COMPONENT_ERROR                        = 0x66a5000a,
	PR_NEWSFEED_INFO                                    = 0x66a60102,
	PR_NEWSFEED_INFO_ERROR                              = 0x66a6000a,
	PR_INTERNET_NEWSGROUP_NAME                          = 0x66a7001e,
	PR_INTERNET_NEWSGROUP_NAME_UNICODE                  = 0x66a7001f,
	PR_INTERNET_NEWSGROUP_NAME_ERROR                    = 0x66a7000a,
	PR_FOLDER_FLAGS                                     = 0x66a80003,
	PR_FOLDER_FLAGS_ERROR                               = 0x66a8000a,
	PR_LAST_ACCESS_TIME                                 = 0x66a90040,
	PR_LAST_ACCESS_TIME_ERROR                           = 0x66a9000a,
	PR_RESTRICTION_COUNT                                = 0x66aa0003,
	PR_RESTRICTION_COUNT_ERROR                          = 0x66aa000a,
	PR_CATEG_COUNT                                      = 0x66ab0003,
	PR_CATEG_COUNT_ERROR                                = 0x66ab000a,
	PR_CACHED_COLUMN_COUNT                              = 0x66ac0003,
	PR_CACHED_COLUMN_COUNT_ERROR                        = 0x66ac000a,
	PR_NORMAL_MSG_W_ATTACH_COUNT                        = 0x66ad0003,
	PR_NORMAL_MSG_W_ATTACH_COUNT_ERROR                  = 0x66ad000a,
	PR_ASSOC_MSG_W_ATTACH_COUNT                         = 0x66ae0003,
	PR_ASSOC_MSG_W_ATTACH_COUNT_ERROR                   = 0x66ae000a,
	PR_RECIPIENT_ON_NORMAL_MSG_COUNT                    = 0x66af0003,
	PR_RECIPIENT_ON_NORMAL_MSG_COUNT_ERROR              = 0x66af000a,
	PR_RECIPIENT_ON_ASSOC_MSG_COUNT                     = 0x66b00003,
	PR_RECIPIENT_ON_ASSOC_MSG_COUNT_ERROR               = 0x66b0000a,
	PR_ATTACH_ON_NORMAL_MSG_COUNT                       = 0x66b10003,
	PR_ATTACH_ON_NORMAL_MSG_COUNT_ERROR                 = 0x66b1000a,
	PR_ATTACH_ON_ASSOC_MSG_COUNT                        = 0x66b20003,
	PR_ATTACH_ON_ASSOC_MSG_COUNT_ERROR                  = 0x66b2000a,
	PR_NORMAL_MESSAGE_SIZE                              = 0x66b30003,
	PR_NORMAL_MESSAGE_SIZE_ERROR                        = 0x66b3000a,
	PR_NORMAL_MESSAGE_SIZE_EXTENDED                     = 0x66b30014,
	PR_ASSOC_MESSAGE_SIZE                               = 0x66b40003,
	PR_ASSOC_MESSAGE_SIZE_ERROR                         = 0x66b4000a,
	PR_ASSOC_MESSAGE_SIZE_EXTENDED                      = 0x66b40014,
	PR_FOLDER_PATHNAME                                  = 0x66b5001e,
	PR_FOLDER_PATHNAME_UNICODE                          = 0x66b5001f,
	PR_FOLDER_PATHNAME_ERROR                            = 0x66b5000a,
	PR_OWNER_COUNT                                      = 0x66b60003,
	PR_OWNER_COUNT_ERROR                                = 0x66b6000a,
	PR_CONTACT_COUNT                                    = 0x66b70003,
	PR_CONTACT_COUNT_ERROR                              = 0x66b7000a,
	PR_CODE_PAGE_ID                                     = 0x66c30003,
	PR_CODE_PAGE_ID_ERROR                               = 0x66c3000a,
	PR_RETENTION_AGE_LIMIT                              = 0x66c40003,
	PR_RETENTION_AGE_LIMIT_ERROR                        = 0x66c4000a,
	PR_DISABLE_PERUSER_READ                             = 0x66c5000b,
	PR_DISABLE_PERUSER_READ_ERROR                       = 0x66c5000a,
	PR_INTERNET_PARSE_STATE                             = 0x66c60102,
	PR_INTERNET_PARSE_STATE_ERROR                       = 0x66c6000a,
	PR_INTERNET_MESSAGE_INFO                            = 0x66c70102,
	PR_INTERNET_MESSAGE_INFO_ERROR                      = 0x66c7000a,
	PR_PST_PATH                                         = 0x6700001e,
	PR_PST_PATH_UNICODE                                 = 0x6700001f,
	PR_PST_PATH_ERROR                                   = 0x6700000a,
	PR_PST_REMEMBER_PW                                  = 0x6701000b,
	PR_PST_REMEMBER_PW_ERROR                            = 0x6701000a,
	PR_OST_ENCRYPTION                                   = 0x67020003,
	PR_OST_ENCRYPTION_ERROR                             = 0x6702000a,
	PR_PST_PW_SZ_OLD                                    = 0x6703001e,
	PR_PST_PW_SZ_OLD_UNICODE                            = 0x6703001f,
	PR_PST_PW_SZ_OLD_ERROR                              = 0x6703000a,
	PR_PST_PW_SZ_NEW                                    = 0x6704001e,
	PR_PST_PW_SZ_NEW_UNICODE                            = 0x6704001f,
	PR_PST_PW_SZ_NEW_ERROR                              = 0x6704000a,
	PR_SORT_LOCALE_ID                                   = 0x67050003,
	PR_SORT_LOCALE_ID_ERROR                             = 0x6705000a,
	PR_URL_NAME                                         = 0x6707001e,
	PR_URL_NAME_UNICODE                                 = 0x6707001f,
	PR_URL_NAME_ERROR                                   = 0x6707000a,
	PR_LOCAL_COMMIT_TIME                                = 0x67090040,
	PR_LOCAL_COMMIT_TIME_ERROR                          = 0x6709000a,
	PR_LOCAL_COMMIT_TIME_MAX                            = 0x670a0040,
	PR_LOCAL_COMMIT_TIME_MAX_ERROR                      = 0x670a000a,
	PR_DELETED_COUNT_TOTAL                              = 0x670b0003,
	PR_DELETED_COUNT_TOTAL_ERROR                        = 0x670b000a,
	PR_AUTO_RESET                                       = 0x670c0048,
	PR_AUTO_RESET_ERROR                                 = 0x670c000a,
	PR_URL_COMP_NAME_HASH                               = 0x67100003,
	PR_URL_COMP_NAME_HASH_ERROR                         = 0x6710000a,
	PR_MSG_FOLDER_TEMPLATE_RES_2                        = 0x67110003,
	PR_MSG_FOLDER_TEMPLATE_RES_2_ERROR                  = 0x6711000a,
	PR_RANK                                             = 0x67120003,
	PR_RANK_ERROR                                       = 0x6712000a,
	PR_MSG_FOLDER_TEMPLATE_RES_4                        = 0x6713000b,
	PR_MSG_FOLDER_TEMPLATE_RES_4_ERROR                  = 0x6713000a,
	PR_MSG_FOLDER_TEMPLATE_RES_5                        = 0x6714000b,
	PR_MSG_FOLDER_TEMPLATE_RES_5_ERROR                  = 0x6714000a,
	PR_MSG_FOLDER_TEMPLATE_RES_6                        = 0x6715000b,
	PR_MSG_FOLDER_TEMPLATE_RES_6_ERROR                  = 0x6715000a,
	PR_MSG_FOLDER_TEMPLATE_RES_7                        = 0x67160102,
	PR_MSG_FOLDER_TEMPLATE_RES_7_ERROR                  = 0x6716000a,
	PR_MSG_FOLDER_TEMPLATE_RES_8                        = 0x67170102,
	PR_MSG_FOLDER_TEMPLATE_RES_8_ERROR                  = 0x6717000a,
	PR_MSG_FOLDER_TEMPLATE_RES_9                        = 0x67180102,
	PR_MSG_FOLDER_TEMPLATE_RES_9_ERROR                  = 0x6718000a,
	PR_MSG_FOLDER_TEMPLATE_RES_10                       = 0x6719001e,
	PR_MSG_FOLDER_TEMPLATE_RES_10_UNICODE               = 0x6719001f,
	PR_MSG_FOLDER_TEMPLATE_RES_10_ERROR                 = 0x6719000a,
	PR_MSG_FOLDER_TEMPLATE_RES_11                       = 0x671a001e,
	PR_MSG_FOLDER_TEMPLATE_RES_11_UNICODE               = 0x671a001f,
	PR_MSG_FOLDER_TEMPLATE_RES_11_ERROR                 = 0x671a000a,
	PR_MSG_FOLDER_TEMPLATE_RES_12                       = 0x671b001e,
	PR_MSG_FOLDER_TEMPLATE_RES_12_UNICODE               = 0x671b001f,
	PR_MSG_FOLDER_TEMPLATE_RES_12_ERROR                 = 0x671b000a,
	PR_PF_PLATINUM_HOME_MDB                             = 0x671e000b,
	PR_PF_PLATINUM_HOME_MDB_ERROR                       = 0x671e000a,
	PR_PF_PROXY_REQUIRED                                = 0x671f000b,
	PR_PF_PROXY_REQUIRED_ERROR                          = 0x671f000a,
	PR_INTERNET_FREE_DOC_INFO                           = 0x67200102,
	PR_INTERNET_FREE_DOC_INFO_ERROR                     = 0x6720000a,
	PR_PF_OVER_HARD_QUOTA_LIMIT                         = 0x67210003,
	PR_PF_OVER_HARD_QUOTA_LIMIT_ERROR                   = 0x6721000a,
	PR_PF_MSG_SIZE_LIMIT                                = 0x67220003,
	PR_PF_MSG_SIZE_LIMIT_ERROR                          = 0x6722000a,
	PR_CONNECTION_MODULUS                               = 0x67430003,
	PR_CONNECTION_MODULUS_ERROR                         = 0x6743000a,
	PR_DELIVER_TO_DN                                    = 0x6744001e,
	PR_DELIVER_TO_DN_UNICODE                            = 0x6744001f,
	PR_DELIVER_TO_DN_ERROR                              = 0x6744000a,
	PR_MIME_SIZE                                        = 0x67460003,
	PR_MIME_SIZE_ERROR                                  = 0x6746000a,
	PR_FILE_SIZE_EXTENDED                               = 0x67470014,
	PR_FILE_SIZE_EXTENDED_ERROR                         = 0x6747000a,
	PR_FID                                              = 0x67480014,
	PR_FID_ERROR                                        = 0x6748000a,
	PR_PARENT_FID                                       = 0x67490014,
	PR_PARENT_FID_ERROR                                 = 0x6749000a,
	PR_MID                                              = 0x674a0014,
	PR_MID_ERROR                                        = 0x674a000a,
	PR_CATEG_ID                                         = 0x674b0014,
	PR_CATEG_ID_ERROR                                   = 0x674b000a,
	PR_PARENT_CATEG_ID                                  = 0x674c0014,
	PR_PARENT_CATEG_ID_ERROR                            = 0x674c000a,
	PR_INST_ID                                          = 0x674d0014,
	PR_INST_ID_ERROR                                    = 0x674d000a,
	PR_INSTANCE_NUM                                     = 0x674e0003,
	PR_INSTANCE_NUM_ERROR                               = 0x674e000a,
	PR_ADDRBOOK_MID                                     = 0x674f0014,
	PR_ADDRBOOK_MID_ERROR                               = 0x674f000a,
	PR_ICS_NOTIF                                        = 0x67500003,
	PR_ICS_NOTIF_ERROR                                  = 0x6750000a,
	PR_ARTICLE_NUM_NEXT                                 = 0x67510003,
	PR_ARTICLE_NUM_NEXT_ERROR                           = 0x6751000a,
	PR_IMAP_LAST_ARTICLE_ID                             = 0x67520003,
	PR_IMAP_LAST_ARTICLE_ID_ERROR                       = 0x6752000a,
	PR_NOT_822_RENDERABLE                               = 0x6753000b,
	PR_NOT_822_RENDERABLE_ERROR                         = 0x6753000a,
	PR_LTID                                             = 0x67580102,
	PR_LTID_ERROR                                       = 0x6758000a,
	PR_CN_EXPORT                                        = 0x67590102,
	PR_CN_EXPORT_ERROR                                  = 0x6759000a,
	PR_PCL_EXPORT                                       = 0x675a0102,
	PR_PCL_EXPORT_ERROR                                 = 0x675a000a,
	PR_CN_MV_EXPORT                                     = 0x675b1102,
	PR_CN_MV_EXPORT_ERROR                               = 0x675b000a,
	PR_PF_QUOTA_STYLE                                   = 0x67790003,
	PR_PF_QUOTA_STYLE_ERROR                             = 0x6779000a,
	PR_PF_STORAGE_QUOTA                                 = 0x677b0003,
	PR_PF_STORAGE_QUOTA_ERROR                           = 0x677b000a,
	PR_SEARCH_FLAGS                                     = 0x67830003,
	PR_SEARCH_FLAGS_ERROR                               = 0x6783000a,
	PR_ASSOCIATED                                       = 0x67aa000b,
	PR_ASSOCIATED_ERROR                                 = 0x67aa000a,
	PR_PROFILE_SECURE_MAILBOX                           = 0x67f00102,
	PR_PROFILE_SECURE_MAILBOX_ERROR                     = 0x67f0000a,
	PR_MAILBEAT_BOUNCE_SERVER                           = 0x6800001e,
	PR_MAILBEAT_BOUNCE_SERVER_UNICODE                   = 0x6800001f,
	PR_MAILBEAT_BOUNCE_SERVER_ERROR                     = 0x6800000a,
	PR_MAILBEAT_REQUEST_SENT                            = 0x68010040,
	PR_MAILBEAT_REQUEST_SENT_ERROR                      = 0x6801000a,
	PR_USENET_SITE_NAME                                 = 0x6802001e,
	PR_USENET_SITE_NAME_UNICODE                         = 0x6802001f,
	PR_USENET_SITE_NAME_ERROR                           = 0x6802000a,
	PR_MAILBEAT_REQUEST_RECEIVED                        = 0x68030040,
	PR_MAILBEAT_REQUEST_RECEIVED_ERROR                  = 0x6803000a,
	PR_MAILBEAT_REQUEST_PROCESSED                       = 0x68040040,
	PR_MAILBEAT_REQUEST_PROCESSED_ERROR                 = 0x6804000a,
	PR_MAILBEAT_REPLY_SENT                              = 0x68060040,
	PR_MAILBEAT_REPLY_SENT_ERROR                        = 0x6806000a,
	PR_MAILBEAT_REPLY_SUBMIT                            = 0x68070040,
	PR_MAILBEAT_REPLY_SUBMIT_ERROR                      = 0x6807000a,
	PR_MAILBEAT_REPLY_RECEIVED                          = 0x68080040,
	PR_MAILBEAT_REPLY_RECEIVED_ERROR                    = 0x6808000a,
	PR_MAILBEAT_REPLY_PROCESSED                         = 0x68090040,
	PR_MAILBEAT_REPLY_PROCESSED_ERROR                   = 0x6809000a,
	PR_DELEGATES_DISPLAY_NAMES                          = 0x6844101e,
	PR_DELEGATES_DISPLAY_NAMES_UNICODE                  = 0x6844101f,
	PR_DELEGATES_DISPLAY_NAMES_ERROR                    = 0x6844000a,
	PR_DELEGATES_ENTRYIDS                               = 0x68451102,
	PR_DELEGATES_ENTRYIDS_ERROR                         = 0x6845000a,
	PR_FREEBUSY_START_RANGE                             = 0x68470003,
	PR_FREEBUSY_START_RANGE_ERROR                       = 0x6847000a,
	PR_FREEBUSY_END_RANGE                               = 0x68480003,
	PR_FREEBUSY_END_RANGE_ERROR                         = 0x6848000a,
	PR_FREEBUSY_EMAIL_ADDRESS                           = 0x6849001e,
	PR_FREEBUSY_EMAIL_ADDRESS_UNICODE                   = 0x6849001f,
	PR_FREEBUSY_EMAIL_ADDRESS_ERROR                     = 0x6849000a,
	PR_FREEBUSY_ALL_MONTHS                              = 0x684f1003,
	PR_FREEBUSY_ALL_MONTHS_ERROR                        = 0x684f000a,
	PR_FREEBUSY_ALL_EVENTS                              = 0x68501102,
	PR_FREEBUSY_ALL_EVENTS_ERROR                        = 0x6850000a,
	PR_FREEBUSY_TENTATIVE_MONTHS                        = 0x68511003,
	PR_FREEBUSY_TENTATIVE_MONTHS_ERROR                  = 0x6851000a,
	PR_FREEBUSY_TENTATIVE_EVENTS                        = 0x68521102,
	PR_FREEBUSY_TENTATIVE_EVENTS_ERROR                  = 0x6852000a,
	PR_FREEBUSY_BUSY_MONTHS                             = 0x68531003,
	PR_FREEBUSY_BUSY_MONTHS_ERROR                       = 0x6853000a,
	PR_FREEBUSY_BUSY_EVENTS                             = 0x68541102,
	PR_FREEBUSY_BUSY_EVENTS_ERROR                       = 0x6854000a,
	PR_FREEBUSY_OOF_MONTHS                              = 0x68551003,
	PR_FREEBUSY_OOF_MONTHS_ERROR                        = 0x6855000a,
	PR_FREEBUSY_OOF_EVENTS                              = 0x68561102,
	PR_FREEBUSY_OOF_EVENTS_ERROR                        = 0x6856000a,
	PR_FREEBUSY_LAST_MODIFIED                           = 0x68680040,
	PR_FREEBUSY_LAST_MODIFIED_ERROR                     = 0x6868000a,
	PR_FREEBUSY_NUM_MONTHS                              = 0x68690003,
	PR_FREEBUSY_NUM_MONTHS_ERROR                        = 0x6869000a,
	PR_DELEGATES_SEE_PRIVATE                            = 0x686b1003,
	PR_DELEGATES_SEE_PRIVATE_ERROR                      = 0x686b000a,
	PR_PERSONAL_FREEBUSY                                = 0x686c0102,
	PR_PERSONAL_FREEBUSY_ERROR                          = 0x686c000a,
	PR_PROCESS_MEETING_REQUESTS                         = 0x686d000b,
	PR_PROCESS_MEETING_REQUESTS_ERROR                   = 0x686d000a,
	PR_DECLINE_RECURRING_MEETING_REQUESTS               = 0x686e000b,
	PR_DECLINE_RECURRING_MEETING_REQUESTS_ERROR         = 0x686e000a,
	PR_DECLINE_CONFLICTING_MEETING_REQUESTS             = 0x686f000b,
	PR_DECLINE_CONFLICTING_MEETING_REQUESTS_ERROR       = 0x686f000a,
	PR_VD_BINARY                                        = 0x70010102,
	PR_VD_BINARY_ERROR                                  = 0x7001000a,
	PR_VD_STRINGS                                       = 0x7002001e,
	PR_VD_STRINGS_UNICODE                               = 0x7002001f,
	PR_VD_STRINGS_ERROR                                 = 0x7002000a,
	PR_VD_FLAGS                                         = 0x70030003,
	PR_VD_FLAGS_ERROR                                   = 0x7003000a,
	PR_VD_LINK_TO                                       = 0x70040102,
	PR_VD_LINK_TO_ERROR                                 = 0x7004000a,
	PR_VD_VIEW_FOLDER                                   = 0x70050102,
	PR_VD_VIEW_FOLDER_ERROR                             = 0x7005000a,
	PR_VD_NAME                                          = 0x7006001e,
	PR_VD_NAME_UNICODE                                  = 0x7006001f,
	PR_VD_NAME_ERROR                                    = 0x7006000a,
	PR_VD_VERSION                                       = 0x70070003,
	PR_VD_VERSION_ERROR                                 = 0x7007000a,
	PR_FAV_DISPLAY_NAME_A                               = 0x7c00001e,
	PR_FAV_DISPLAY_NAME_A_UNICODE                       = 0x7c00001f,
	PR_FAV_DISPLAY_NAME_A_ERROR                         = 0x7c00000a,
	PR_FAV_PUBLIC_SOURCE_KEY                            = 0x7c020102,
	PR_FAV_PUBLIC_SOURCE_KEY_ERROR                      = 0x7c02000a,
	PR_OST_OSTID                                        = 0x7c040102,
	PR_OST_OSTID_ERROR                                  = 0x7c04000a,
	PR_STORE_SLOWLINK                                   = 0x7c0a000b,
	PR_STORE_SLOWLINK_ERROR                             = 0x7c0a000a,
	PR_FAV_AUTOSUBFOLDERS                               = 0x7d010003,
	PR_FAV_AUTOSUBFOLDERS_ERROR                         = 0x7d01000a,
	PR_FAV_PARENT_SOURCE_KEY                            = 0x7d020102,
	PR_FAV_PARENT_SOURCE_KEY_ERROR                      = 0x7d02000a,
	PR_FAV_LEVEL_MASK                                   = 0x7d030003,
	PR_FAV_LEVEL_MASK_ERROR                             = 0x7d03000a,
	PR_FAV_INHERIT_AUTO                                 = 0x7d070003,
	PR_FAV_INHERIT_AUTO_ERROR                           = 0x7d07000a,
	PR_FAV_DEL_SUBS                                     = 0x7d080102,
	PR_FAV_DEL_SUBS_ERROR                               = 0x7d08000a,
	PR_ATTACHMENT_LINKID                                = 0x7ffa0003,
	PR_ATTACHMENT_LINKID_ERROR                          = 0x7ffa000a,
	PR_EXCEPTION_STARTTIME                              = 0x7ffb0040,
	PR_EXCEPTION_STARTTIME_ERROR                        = 0x7ffb000a,
	PR_EXCEPTION_ENDTIME                                = 0x7ffc0040,
	PR_EXCEPTION_ENDTIME_ERROR                          = 0x7ffc000a,
	PR_ATTACHMENT_FLAGS                                 = 0x7ffd0003,
	PR_ATTACHMENT_FLAGS_ERROR                           = 0x7ffd000a,
	PR_ATTACHMENT_HIDDEN                                = 0x7ffe000b,
	PR_ATTACHMENT_HIDDEN_ERROR                          = 0x7ffe000a,
	PR_EMS_AB_DISPLAY_NAME_OVERRIDE                     = 0x8001000b,
	PR_EMS_AB_DISPLAY_NAME_OVERRIDE_ERROR               = 0x8001000a,
	PR_EMS_AB_CA_CERTIFICATE                            = 0x80031102,
	PR_EMS_AB_CA_CERTIFICATE_ERROR                      = 0x8003000a,
	PR_EMS_AB_FOLDER_PATHNAME                           = 0x8004001e,
	PR_EMS_AB_FOLDER_PATHNAME_UNICODE                   = 0x8004001f,
	PR_EMS_AB_FOLDER_PATHNAME_ERROR                     = 0x8004000a,
	PR_EMS_AB_MANAGER                                   = 0x8005000d,
	PR_EMS_AB_MANAGER_ERROR                             = 0x8005000a,
	PR_EMS_AB_MANAGER_T                                 = 0x8005001e,
	PR_EMS_AB_MANAGER_T_UNICODE                         = 0x8005001f,
	PR_EMS_AB_HOME_MDB_O                                = 0x8006000d,
	PR_EMS_AB_HOME_MDB_O_ERROR                          = 0x8006000a,
	PR_EMS_AB_HOME_MDB                                  = 0x8006001e,
	PR_EMS_AB_HOME_MDB_UNICODE                          = 0x8006001f,
	PR_EMS_AB_HOME_MTA_O                                = 0x8007000d,
	PR_EMS_AB_HOME_MTA_O_ERROR                          = 0x8007000a,
	PR_EMS_AB_HOME_MTA                                  = 0x8007001e,
	PR_EMS_AB_HOME_MTA_UNICODE                          = 0x8007001f,
	PR_EMS_AB_IS_MEMBER_OF_DL                           = 0x8008000d,
	PR_EMS_AB_IS_MEMBER_OF_DL_ERROR                     = 0x8008000a,
	PR_EMS_AB_IS_MEMBER_OF_DL_T                         = 0x8008001e,
	PR_EMS_AB_IS_MEMBER_OF_DL_T_UNICODE                 = 0x8008001f,
	PR_EMS_AB_MEMBER                                    = 0x8009000d,
	PR_EMS_AB_MEMBER_ERROR                              = 0x8009000a,
	PR_EMS_AB_MEMBER_T                                  = 0x8009001e,
	PR_EMS_AB_MEMBER_T_UNICODE                          = 0x8009001f,
	PR_EMS_AB_AUTOREPLY_MESSAGE                         = 0x800a001e,
	PR_EMS_AB_AUTOREPLY_MESSAGE_UNICODE                 = 0x800a001f,
	PR_EMS_AB_AUTOREPLY_MESSAGE_ERROR                   = 0x800a000a,
	PR_EMS_AB_AUTOREPLY                                 = 0x800b000b,
	PR_EMS_AB_AUTOREPLY_ERROR                           = 0x800b000a,
	PR_EMS_AB_OWNER_O                                   = 0x800c000d,
	PR_EMS_AB_OWNER_O_ERROR                             = 0x800c000a,
	PR_EMS_AB_OWNER                                     = 0x800c001e,
	PR_EMS_AB_OWNER_UNICODE                             = 0x800c001f,
	PR_EMS_AB_KM_SERVER_O                               = 0x800d000d,
	PR_EMS_AB_KM_SERVER_O_ERROR                         = 0x800d000a,
	PR_EMS_AB_KM_SERVER                                 = 0x800d001e,
	PR_EMS_AB_KM_SERVER_UNICODE                         = 0x800d001f,
	PR_EMS_AB_REPORTS                                   = 0x800e000d,
	PR_EMS_AB_REPORTS_ERROR                             = 0x800e000a,
	PR_EMS_AB_PROXY_ADDRESSES                           = 0x800f101e,
	PR_EMS_AB_PROXY_ADDRESSES_UNICODE                   = 0x800f101f,
	PR_EMS_AB_PROXY_ADDRESSES_ERROR                     = 0x800f000a,
	PR_EMS_AB_HELP_DATA32                               = 0x80100102,
	PR_EMS_AB_HELP_DATA32_ERROR                         = 0x8010000a,
	PR_EMS_AB_TARGET_ADDRESS                            = 0x8011001e,
	PR_EMS_AB_TARGET_ADDRESS_UNICODE                    = 0x8011001f,
	PR_EMS_AB_TARGET_ADDRESS_ERROR                      = 0x8011000a,
	PR_EMS_AB_TELEPHONE_NUMBER                          = 0x8012101e,
	PR_EMS_AB_TELEPHONE_NUMBER_UNICODE                  = 0x8012101f,
	PR_EMS_AB_TELEPHONE_NUMBER_ERROR                    = 0x8012000a,
	PR_EMS_AB_NT_SECURITY_DESCRIPTOR                    = 0x80130102,
	PR_EMS_AB_NT_SECURITY_DESCRIPTOR_ERROR              = 0x8013000a,
	PR_EMS_AB_HOME_MDB_BL_O                             = 0x8014000d,
	PR_EMS_AB_HOME_MDB_BL_O_ERROR                       = 0x8014000a,
	PR_EMS_AB_HOME_MDB_BL                               = 0x8014101e,
	PR_EMS_AB_HOME_MDB_BL_UNICODE                       = 0x8014101f,
	PR_EMS_AB_PUBLIC_DELEGATES                          = 0x8015000d,
	PR_EMS_AB_PUBLIC_DELEGATES_ERROR                    = 0x8015000a,
	PR_EMS_AB_PUBLIC_DELEGATES_T                        = 0x8015001e,
	PR_EMS_AB_PUBLIC_DELEGATES_T_UNICODE                = 0x8015001f,
	PR_EMS_AB_CERTIFICATE_REVOCATION_LIST               = 0x80160102,
	PR_EMS_AB_CERTIFICATE_REVOCATION_LIST_ERROR         = 0x8016000a,
	PR_EMS_AB_ADDRESS_ENTRY_DISPLAY_TABLE               = 0x80170102,
	PR_EMS_AB_ADDRESS_ENTRY_DISPLAY_TABLE_ERROR         = 0x8017000a,
	PR_EMS_AB_ADDRESS_SYNTAX                            = 0x80180102,
	PR_EMS_AB_ADDRESS_SYNTAX_ERROR                      = 0x8018000a,
	PR_EMS_AB_BUSINESS_ROLES                            = 0x80230102,
	PR_EMS_AB_BUSINESS_ROLES_ERROR                      = 0x8023000a,
	PR_EMS_AB_OWNER_BL_O                                = 0x8024000d,
	PR_EMS_AB_OWNER_BL_O_ERROR                          = 0x8024000a,
	PR_EMS_AB_OWNER_BL                                  = 0x8024101e,
	PR_EMS_AB_OWNER_BL_UNICODE                          = 0x8024101f,
	PR_EMS_AB_CROSS_CERTIFICATE_PAIR                    = 0x80251102,
	PR_EMS_AB_CROSS_CERTIFICATE_PAIR_ERROR              = 0x8025000a,
	PR_EMS_AB_AUTHORITY_REVOCATION_LIST                 = 0x80261102,
	PR_EMS_AB_AUTHORITY_REVOCATION_LIST_ERROR           = 0x8026000a,
	PR_EMS_AB_ASSOC_NT_ACCOUNT                          = 0x80270102,
	PR_EMS_AB_ASSOC_NT_ACCOUNT_ERROR                    = 0x8027000a,
	PR_EMS_AB_EXPIRATION_TIME                           = 0x80280040,
	PR_EMS_AB_EXPIRATION_TIME_ERROR                     = 0x8028000a,
	PR_EMS_AB_USN_CHANGED                               = 0x80290003,
	PR_EMS_AB_USN_CHANGED_ERROR                         = 0x8029000a,
	PR_EMS_AB_EXTENSION_ATTRIBUTE_1                     = 0x802d001e,
	PR_EMS_AB_EXTENSION_ATTRIBUTE_1_UNICODE             = 0x802d001f,
	PR_EMS_AB_EXTENSION_ATTRIBUTE_1_ERROR               = 0x802d000a,
	PR_EMS_AB_EXTENSION_ATTRIBUTE_2                     = 0x802e001e,
	PR_EMS_AB_EXTENSION_ATTRIBUTE_2_UNICODE             = 0x802e001f,
	PR_EMS_AB_EXTENSION_ATTRIBUTE_2_ERROR               = 0x802e000a,
	PR_EMS_AB_EXTENSION_ATTRIBUTE_3                     = 0x802f001e,
	PR_EMS_AB_EXTENSION_ATTRIBUTE_3_UNICODE             = 0x802f001f,
	PR_EMS_AB_EXTENSION_ATTRIBUTE_3_ERROR               = 0x802f000a,
	PR_EMS_AB_EXTENSION_ATTRIBUTE_4                     = 0x8030001e,
	PR_EMS_AB_EXTENSION_ATTRIBUTE_4_UNICODE             = 0x8030001f,
	PR_EMS_AB_EXTENSION_ATTRIBUTE_4_ERROR               = 0x8030000a,
	PR_EMS_AB_EXTENSION_ATTRIBUTE_5                     = 0x8031001e,
	PR_EMS_AB_EXTENSION_ATTRIBUTE_5_UNICODE             = 0x8031001f,
	PR_EMS_AB_EXTENSION_ATTRIBUTE_5_ERROR               = 0x8031000a,
	PR_EMS_AB_EXTENSION_ATTRIBUTE_6                     = 0x8032001e,
	PR_EMS_AB_EXTENSION_ATTRIBUTE_6_UNICODE             = 0x8032001f,
	PR_EMS_AB_EXTENSION_ATTRIBUTE_6_ERROR               = 0x8032000a,
	PR_EMS_AB_EXTENSION_ATTRIBUTE_7                     = 0x8033001e,
	PR_EMS_AB_EXTENSION_ATTRIBUTE_7_UNICODE             = 0x8033001f,
	PR_EMS_AB_EXTENSION_ATTRIBUTE_7_ERROR               = 0x8033000a,
	PR_EMS_AB_EXTENSION_ATTRIBUTE_8                     = 0x8034001e,
	PR_EMS_AB_EXTENSION_ATTRIBUTE_8_UNICODE             = 0x8034001f,
	PR_EMS_AB_EXTENSION_ATTRIBUTE_8_ERROR               = 0x8034000a,
	PR_EMS_AB_EXTENSION_ATTRIBUTE_9                     = 0x8035001e,
	PR_EMS_AB_EXTENSION_ATTRIBUTE_9_UNICODE             = 0x8035001f,
	PR_EMS_AB_EXTENSION_ATTRIBUTE_9_ERROR               = 0x8035000a,
	PR_EMS_AB_EXTENSION_ATTRIBUTE_10                    = 0x8036001e,
	PR_EMS_AB_EXTENSION_ATTRIBUTE_10_UNICODE            = 0x8036001f,
	PR_EMS_AB_EXTENSION_ATTRIBUTE_10_ERROR              = 0x8036000a,
	PR_EMS_AB_SECURITY_PROTOCOL                         = 0x80371102,
	PR_EMS_AB_SECURITY_PROTOCOL_ERROR                   = 0x8037000a,
	PR_EMS_AB_PF_CONTACTS_O                             = 0x8038000d,
	PR_EMS_AB_PF_CONTACTS_O_ERROR                       = 0x8038000a,
	PR_EMS_AB_PF_CONTACTS                               = 0x8038101e,
	PR_EMS_AB_PF_CONTACTS_UNICODE                       = 0x8038101f,
	PR_EMS_AB_HELP_DATA16                               = 0x803a0102,
	PR_EMS_AB_HELP_DATA16_ERROR                         = 0x803a000a,
	PR_EMS_AB_HELP_FILE_NAME                            = 0x803b001e,
	PR_EMS_AB_HELP_FILE_NAME_UNICODE                    = 0x803b001f,
	PR_EMS_AB_HELP_FILE_NAME_ERROR                      = 0x803b000a,
	PR_EMS_AB_OBJ_DIST_NAME_O                           = 0x803c000d,
	PR_EMS_AB_OBJ_DIST_NAME_O_ERROR                     = 0x803c000a,
	PR_EMS_AB_OBJ_DIST_NAME                             = 0x803c001e,
	PR_EMS_AB_OBJ_DIST_NAME_UNICODE                     = 0x803c001f,
	PR_EMS_AB_ENCRYPT_ALG_SELECTED_OTHER                = 0x803d001e,
	PR_EMS_AB_ENCRYPT_ALG_SELECTED_OTHER_UNICODE        = 0x803d001f,
	PR_EMS_AB_ENCRYPT_ALG_SELECTED_OTHER_ERROR          = 0x803d000a,
	PR_EMS_AB_AUTOREPLY_SUBJECT                         = 0x803e001e,
	PR_EMS_AB_AUTOREPLY_SUBJECT_UNICODE                 = 0x803e001f,
	PR_EMS_AB_AUTOREPLY_SUBJECT_ERROR                   = 0x803e000a,
	PR_EMS_AB_HOME_PUBLIC_SERVER_O                      = 0x803f000d,
	PR_EMS_AB_HOME_PUBLIC_SERVER_O_ERROR                = 0x803f000a,
	PR_EMS_AB_HOME_PUBLIC_SERVER                        = 0x803f001e,
	PR_EMS_AB_HOME_PUBLIC_SERVER_UNICODE                = 0x803f001f,
	PR_EMS_AB_ENCRYPT_ALG_LIST_NA                       = 0x8040101e,
	PR_EMS_AB_ENCRYPT_ALG_LIST_NA_UNICODE               = 0x8040101f,
	PR_EMS_AB_ENCRYPT_ALG_LIST_NA_ERROR                 = 0x8040000a,
	PR_EMS_AB_ENCRYPT_ALG_LIST_OTHER                    = 0x8041101e,
	PR_EMS_AB_ENCRYPT_ALG_LIST_OTHER_UNICODE            = 0x8041101f,
	PR_EMS_AB_ENCRYPT_ALG_LIST_OTHER_ERROR              = 0x8041000a,
	PR_EMS_AB_IMPORTED_FROM                             = 0x8042001e,
	PR_EMS_AB_IMPORTED_FROM_UNICODE                     = 0x8042001f,
	PR_EMS_AB_IMPORTED_FROM_ERROR                       = 0x8042000a,
	PR_EMS_AB_ENCRYPT_ALG_SELECTED_NA                   = 0x8043001e,
	PR_EMS_AB_ENCRYPT_ALG_SELECTED_NA_UNICODE           = 0x8043001f,
	PR_EMS_AB_ENCRYPT_ALG_SELECTED_NA_ERROR             = 0x8043000a,
	PR_EMS_AB_ACCESS_CATEGORY                           = 0x80440003,
	PR_EMS_AB_ACCESS_CATEGORY_ERROR                     = 0x8044000a,
	PR_EMS_AB_ACTIVATION_SCHEDULE                       = 0x80450102,
	PR_EMS_AB_ACTIVATION_SCHEDULE_ERROR                 = 0x8045000a,
	PR_EMS_AB_ACTIVATION_STYLE                          = 0x80460003,
	PR_EMS_AB_ACTIVATION_STYLE_ERROR                    = 0x8046000a,
	PR_EMS_AB_ADDRESS_ENTRY_DISPLAY_TABLE_MSDOS         = 0x80470102,
	PR_EMS_AB_ADDRESS_ENTRY_DISPLAY_TABLE_MSDOS_ERROR   = 0x8047000a,
	PR_EMS_AB_ADDRESS_TYPE                              = 0x8048001e,
	PR_EMS_AB_ADDRESS_TYPE_UNICODE                      = 0x8048001f,
	PR_EMS_AB_ADDRESS_TYPE_ERROR                        = 0x8048000a,
	PR_EMS_AB_ADMD                                      = 0x8049001e,
	PR_EMS_AB_ADMD_UNICODE                              = 0x8049001f,
	PR_EMS_AB_ADMD_ERROR                                = 0x8049000a,
	PR_EMS_AB_ADMIN_DESCRIPTION                         = 0x804a001e,
	PR_EMS_AB_ADMIN_DESCRIPTION_UNICODE                 = 0x804a001f,
	PR_EMS_AB_ADMIN_DESCRIPTION_ERROR                   = 0x804a000a,
	PR_EMS_AB_ADMIN_DISPLAY_NAME                        = 0x804b001e,
	PR_EMS_AB_ADMIN_DISPLAY_NAME_UNICODE                = 0x804b001f,
	PR_EMS_AB_ADMIN_DISPLAY_NAME_ERROR                  = 0x804b000a,
	PR_EMS_AB_ADMIN_EXTENSION_DLL                       = 0x804c001e,
	PR_EMS_AB_ADMIN_EXTENSION_DLL_UNICODE               = 0x804c001f,
	PR_EMS_AB_ADMIN_EXTENSION_DLL_ERROR                 = 0x804c000a,
	PR_EMS_AB_ALIASED_OBJECT_NAME_O                     = 0x804d000d,
	PR_EMS_AB_ALIASED_OBJECT_NAME_O_ERROR               = 0x804d000a,
	PR_EMS_AB_ALIASED_OBJECT_NAME                       = 0x804d001e,
	PR_EMS_AB_ALIASED_OBJECT_NAME_UNICODE               = 0x804d001f,
	PR_EMS_AB_ALT_RECIPIENT_O                           = 0x804e000d,
	PR_EMS_AB_ALT_RECIPIENT_O_ERROR                     = 0x804e000a,
	PR_EMS_AB_ALT_RECIPIENT                             = 0x804e001e,
	PR_EMS_AB_ALT_RECIPIENT_UNICODE                     = 0x804e001f,
	PR_EMS_AB_ALT_RECIPIENT_BL_O                        = 0x804f000d,
	PR_EMS_AB_ALT_RECIPIENT_BL_O_ERROR                  = 0x804f000a,
	PR_EMS_AB_ALT_RECIPIENT_BL                          = 0x804f101e,
	PR_EMS_AB_ALT_RECIPIENT_BL_UNICODE                  = 0x804f101f,
	PR_EMS_AB_ANCESTOR_ID                               = 0x80500102,
	PR_EMS_AB_ANCESTOR_ID_ERROR                         = 0x8050000a,
	PR_EMS_AB_ASSOC_REMOTE_DXA_O                        = 0x8051000d,
	PR_EMS_AB_ASSOC_REMOTE_DXA_O_ERROR                  = 0x8051000a,
	PR_EMS_AB_ASSOC_REMOTE_DXA                          = 0x8051101e,
	PR_EMS_AB_ASSOC_REMOTE_DXA_UNICODE                  = 0x8051101f,
	PR_EMS_AB_ASSOCIATION_LIFETIME                      = 0x80520003,
	PR_EMS_AB_ASSOCIATION_LIFETIME_ERROR                = 0x8052000a,
	PR_EMS_AB_AUTH_ORIG_BL_O                            = 0x8053000d,
	PR_EMS_AB_AUTH_ORIG_BL_O_ERROR                      = 0x8053000a,
	PR_EMS_AB_AUTH_ORIG_BL                              = 0x8053101e,
	PR_EMS_AB_AUTH_ORIG_BL_UNICODE                      = 0x8053101f,
	PR_EMS_AB_AUTHORIZED_DOMAIN                         = 0x8054001e,
	PR_EMS_AB_AUTHORIZED_DOMAIN_UNICODE                 = 0x8054001f,
	PR_EMS_AB_AUTHORIZED_DOMAIN_ERROR                   = 0x8054000a,
	PR_EMS_AB_AUTHORIZED_PASSWORD                       = 0x80550102,
	PR_EMS_AB_AUTHORIZED_PASSWORD_ERROR                 = 0x8055000a,
	PR_EMS_AB_AUTHORIZED_USER                           = 0x8056001e,
	PR_EMS_AB_AUTHORIZED_USER_UNICODE                   = 0x8056001f,
	PR_EMS_AB_AUTHORIZED_USER_ERROR                     = 0x8056000a,
	PR_EMS_AB_BUSINESS_CATEGORY                         = 0x8057101e,
	PR_EMS_AB_BUSINESS_CATEGORY_UNICODE                 = 0x8057101f,
	PR_EMS_AB_BUSINESS_CATEGORY_ERROR                   = 0x8057000a,
	PR_EMS_AB_CAN_CREATE_PF_O                           = 0x8058000d,
	PR_EMS_AB_CAN_CREATE_PF_O_ERROR                     = 0x8058000a,
	PR_EMS_AB_CAN_CREATE_PF                             = 0x8058101e,
	PR_EMS_AB_CAN_CREATE_PF_UNICODE                     = 0x8058101f,
	PR_EMS_AB_CAN_CREATE_PF_BL_O                        = 0x8059000d,
	PR_EMS_AB_CAN_CREATE_PF_BL_O_ERROR                  = 0x8059000a,
	PR_EMS_AB_CAN_CREATE_PF_BL                          = 0x8059101e,
	PR_EMS_AB_CAN_CREATE_PF_BL_UNICODE                  = 0x8059101f,
	PR_EMS_AB_CAN_CREATE_PF_DL_O                        = 0x805a000d,
	PR_EMS_AB_CAN_CREATE_PF_DL_O_ERROR                  = 0x805a000a,
	PR_EMS_AB_CAN_CREATE_PF_DL                          = 0x805a101e,
	PR_EMS_AB_CAN_CREATE_PF_DL_UNICODE                  = 0x805a101f,
	PR_EMS_AB_CAN_CREATE_PF_DL_BL_O                     = 0x805b000d,
	PR_EMS_AB_CAN_CREATE_PF_DL_BL_O_ERROR               = 0x805b000a,
	PR_EMS_AB_CAN_CREATE_PF_DL_BL                       = 0x805b101e,
	PR_EMS_AB_CAN_CREATE_PF_DL_BL_UNICODE               = 0x805b101f,
	PR_EMS_AB_CAN_NOT_CREATE_PF_O                       = 0x805c000d,
	PR_EMS_AB_CAN_NOT_CREATE_PF_O_ERROR                 = 0x805c000a,
	PR_EMS_AB_CAN_NOT_CREATE_PF                         = 0x805c101e,
	PR_EMS_AB_CAN_NOT_CREATE_PF_UNICODE                 = 0x805c101f,
	PR_EMS_AB_CAN_NOT_CREATE_PF_BL_O                    = 0x805d000d,
	PR_EMS_AB_CAN_NOT_CREATE_PF_BL_O_ERROR              = 0x805d000a,
	PR_EMS_AB_CAN_NOT_CREATE_PF_BL                      = 0x805d101e,
	PR_EMS_AB_CAN_NOT_CREATE_PF_BL_UNICODE              = 0x805d101f,
	PR_EMS_AB_CAN_NOT_CREATE_PF_DL_O                    = 0x805e000d,
	PR_EMS_AB_CAN_NOT_CREATE_PF_DL_O_ERROR              = 0x805e000a,
	PR_EMS_AB_CAN_NOT_CREATE_PF_DL                      = 0x805e101e,
	PR_EMS_AB_CAN_NOT_CREATE_PF_DL_UNICODE              = 0x805e101f,
	PR_EMS_AB_CAN_NOT_CREATE_PF_DL_BL_O                 = 0x805f000d,
	PR_EMS_AB_CAN_NOT_CREATE_PF_DL_BL_O_ERROR           = 0x805f000a,
	PR_EMS_AB_CAN_NOT_CREATE_PF_DL_BL                   = 0x805f101e,
	PR_EMS_AB_CAN_NOT_CREATE_PF_DL_BL_UNICODE           = 0x805f101f,
	PR_EMS_AB_CAN_PRESERVE_DNS                          = 0x8060000b,
	PR_EMS_AB_CAN_PRESERVE_DNS_ERROR                    = 0x8060000a,
	PR_EMS_AB_CLOCK_ALERT_OFFSET                        = 0x80610003,
	PR_EMS_AB_CLOCK_ALERT_OFFSET_ERROR                  = 0x8061000a,
	PR_EMS_AB_CLOCK_ALERT_REPAIR                        = 0x8062000b,
	PR_EMS_AB_CLOCK_ALERT_REPAIR_ERROR                  = 0x8062000a,
	PR_EMS_AB_CLOCK_WARNING_OFFSET                      = 0x80630003,
	PR_EMS_AB_CLOCK_WARNING_OFFSET_ERROR                = 0x8063000a,
	PR_EMS_AB_CLOCK_WARNING_REPAIR                      = 0x8064000b,
	PR_EMS_AB_CLOCK_WARNING_REPAIR_ERROR                = 0x8064000a,
	PR_EMS_AB_COMPUTER_NAME                             = 0x8065001e,
	PR_EMS_AB_COMPUTER_NAME_UNICODE                     = 0x8065001f,
	PR_EMS_AB_COMPUTER_NAME_ERROR                       = 0x8065000a,
	PR_EMS_AB_CONNECTED_DOMAINS                         = 0x8066101e,
	PR_EMS_AB_CONNECTED_DOMAINS_UNICODE                 = 0x8066101f,
	PR_EMS_AB_CONNECTED_DOMAINS_ERROR                   = 0x8066000a,
	PR_EMS_AB_CONTAINER_INFO                            = 0x80670003,
	PR_EMS_AB_CONTAINER_INFO_ERROR                      = 0x8067000a,
	PR_EMS_AB_COST                                      = 0x80680003,
	PR_EMS_AB_COST_ERROR                                = 0x8068000a,
	PR_EMS_AB_COUNTRY_NAME                              = 0x8069001e,
	PR_EMS_AB_COUNTRY_NAME_UNICODE                      = 0x8069001f,
	PR_EMS_AB_COUNTRY_NAME_ERROR                        = 0x8069000a,
	PR_EMS_AB_DELIV_CONT_LENGTH                         = 0x806a0003,
	PR_EMS_AB_DELIV_CONT_LENGTH_ERROR                   = 0x806a000a,
	PR_EMS_AB_DELIV_EITS                                = 0x806b1102,
	PR_EMS_AB_DELIV_EITS_ERROR                          = 0x806b000a,
	PR_EMS_AB_DELIV_EXT_CONT_TYPES                      = 0x806c1102,
	PR_EMS_AB_DELIV_EXT_CONT_TYPES_ERROR                = 0x806c000a,
	PR_EMS_AB_DELIVER_AND_REDIRECT                      = 0x806d000b,
	PR_EMS_AB_DELIVER_AND_REDIRECT_ERROR                = 0x806d000a,
	PR_EMS_AB_DELIVERY_MECHANISM                        = 0x806e0003,
	PR_EMS_AB_DELIVERY_MECHANISM_ERROR                  = 0x806e000a,
	PR_EMS_AB_DESCRIPTION                               = 0x806f101e,
	PR_EMS_AB_DESCRIPTION_UNICODE                       = 0x806f101f,
	PR_EMS_AB_DESCRIPTION_ERROR                         = 0x806f000a,
	PR_EMS_AB_DESTINATION_INDICATOR                     = 0x8070101e,
	PR_EMS_AB_DESTINATION_INDICATOR_UNICODE             = 0x8070101f,
	PR_EMS_AB_DESTINATION_INDICATOR_ERROR               = 0x8070000a,
	PR_EMS_AB_DIAGNOSTIC_REG_KEY                        = 0x8071001e,
	PR_EMS_AB_DIAGNOSTIC_REG_KEY_UNICODE                = 0x8071001f,
	PR_EMS_AB_DIAGNOSTIC_REG_KEY_ERROR                  = 0x8071000a,
	PR_EMS_AB_DL_MEM_REJECT_PERMS_BL_O                  = 0x8072000d,
	PR_EMS_AB_DL_MEM_REJECT_PERMS_BL_O_ERROR            = 0x8072000a,
	PR_EMS_AB_DL_MEM_REJECT_PERMS_BL                    = 0x8072101e,
	PR_EMS_AB_DL_MEM_REJECT_PERMS_BL_UNICODE            = 0x8072101f,
	PR_EMS_AB_DL_MEM_SUBMIT_PERMS_BL_O                  = 0x8073000d,
	PR_EMS_AB_DL_MEM_SUBMIT_PERMS_BL_O_ERROR            = 0x8073000a,
	PR_EMS_AB_DL_MEM_SUBMIT_PERMS_BL                    = 0x8073101e,
	PR_EMS_AB_DL_MEM_SUBMIT_PERMS_BL_UNICODE            = 0x8073101f,
	PR_EMS_AB_DL_MEMBER_RULE                            = 0x80741102,
	PR_EMS_AB_DL_MEMBER_RULE_ERROR                      = 0x8074000a,
	PR_EMS_AB_DOMAIN_DEF_ALT_RECIP_O                    = 0x8075000d,
	PR_EMS_AB_DOMAIN_DEF_ALT_RECIP_O_ERROR              = 0x8075000a,
	PR_EMS_AB_DOMAIN_DEF_ALT_RECIP                      = 0x8075001e,
	PR_EMS_AB_DOMAIN_DEF_ALT_RECIP_UNICODE              = 0x8075001f,
	PR_EMS_AB_DOMAIN_NAME                               = 0x8076001e,
	PR_EMS_AB_DOMAIN_NAME_UNICODE                       = 0x8076001f,
	PR_EMS_AB_DOMAIN_NAME_ERROR                         = 0x8076000a,
	PR_EMS_AB_DSA_SIGNATURE                             = 0x80770102,
	PR_EMS_AB_DSA_SIGNATURE_ERROR                       = 0x8077000a,
	PR_EMS_AB_DXA_ADMIN_COPY                            = 0x8078000b,
	PR_EMS_AB_DXA_ADMIN_COPY_ERROR                      = 0x8078000a,
	PR_EMS_AB_DXA_ADMIN_FORWARD                         = 0x8079000b,
	PR_EMS_AB_DXA_ADMIN_FORWARD_ERROR                   = 0x8079000a,
	PR_EMS_AB_DXA_ADMIN_UPDATE                          = 0x807a0003,
	PR_EMS_AB_DXA_ADMIN_UPDATE_ERROR                    = 0x807a000a,
	PR_EMS_AB_DXA_APPEND_REQCN                          = 0x807b000b,
	PR_EMS_AB_DXA_APPEND_REQCN_ERROR                    = 0x807b000a,
	PR_EMS_AB_DXA_CONF_CONTAINER_LIST_O                 = 0x807c000d,
	PR_EMS_AB_DXA_CONF_CONTAINER_LIST_O_ERROR           = 0x807c000a,
	PR_EMS_AB_DXA_CONF_CONTAINER_LIST                   = 0x807c101e,
	PR_EMS_AB_DXA_CONF_CONTAINER_LIST_UNICODE           = 0x807c101f,
	PR_EMS_AB_DXA_CONF_REQ_TIME                         = 0x807d0040,
	PR_EMS_AB_DXA_CONF_REQ_TIME_ERROR                   = 0x807d000a,
	PR_EMS_AB_DXA_CONF_SEQ                              = 0x807e001e,
	PR_EMS_AB_DXA_CONF_SEQ_UNICODE                      = 0x807e001f,
	PR_EMS_AB_DXA_CONF_SEQ_ERROR                        = 0x807e000a,
	PR_EMS_AB_DXA_CONF_SEQ_USN                          = 0x807f0003,
	PR_EMS_AB_DXA_CONF_SEQ_USN_ERROR                    = 0x807f000a,
	PR_EMS_AB_DXA_EXCHANGE_OPTIONS                      = 0x80800003,
	PR_EMS_AB_DXA_EXCHANGE_OPTIONS_ERROR                = 0x8080000a,
	PR_EMS_AB_DXA_EXPORT_NOW                            = 0x8081000b,
	PR_EMS_AB_DXA_EXPORT_NOW_ERROR                      = 0x8081000a,
	PR_EMS_AB_DXA_FLAGS                                 = 0x80820003,
	PR_EMS_AB_DXA_FLAGS_ERROR                           = 0x8082000a,
	PR_EMS_AB_DXA_IMP_SEQ                               = 0x8083001e,
	PR_EMS_AB_DXA_IMP_SEQ_UNICODE                       = 0x8083001f,
	PR_EMS_AB_DXA_IMP_SEQ_ERROR                         = 0x8083000a,
	PR_EMS_AB_DXA_IMP_SEQ_TIME                          = 0x80840040,
	PR_EMS_AB_DXA_IMP_SEQ_TIME_ERROR                    = 0x8084000a,
	PR_EMS_AB_DXA_IMP_SEQ_USN                           = 0x80850003,
	PR_EMS_AB_DXA_IMP_SEQ_USN_ERROR                     = 0x8085000a,
	PR_EMS_AB_DXA_IMPORT_NOW                            = 0x8086000b,
	PR_EMS_AB_DXA_IMPORT_NOW_ERROR                      = 0x8086000a,
	PR_EMS_AB_DXA_IN_TEMPLATE_MAP                       = 0x8087101e,
	PR_EMS_AB_DXA_IN_TEMPLATE_MAP_UNICODE               = 0x8087101f,
	PR_EMS_AB_DXA_IN_TEMPLATE_MAP_ERROR                 = 0x8087000a,
	PR_EMS_AB_DXA_LOCAL_ADMIN_O                         = 0x8088000d,
	PR_EMS_AB_DXA_LOCAL_ADMIN_O_ERROR                   = 0x8088000a,
	PR_EMS_AB_DXA_LOCAL_ADMIN                           = 0x8088001e,
	PR_EMS_AB_DXA_LOCAL_ADMIN_UNICODE                   = 0x8088001f,
	PR_EMS_AB_DXA_LOGGING_LEVEL                         = 0x80890003,
	PR_EMS_AB_DXA_LOGGING_LEVEL_ERROR                   = 0x8089000a,
	PR_EMS_AB_DXA_NATIVE_ADDRESS_TYPE                   = 0x808a001e,
	PR_EMS_AB_DXA_NATIVE_ADDRESS_TYPE_UNICODE           = 0x808a001f,
	PR_EMS_AB_DXA_NATIVE_ADDRESS_TYPE_ERROR             = 0x808a000a,
	PR_EMS_AB_DXA_OUT_TEMPLATE_MAP                      = 0x808b101e,
	PR_EMS_AB_DXA_OUT_TEMPLATE_MAP_UNICODE              = 0x808b101f,
	PR_EMS_AB_DXA_OUT_TEMPLATE_MAP_ERROR                = 0x808b000a,
	PR_EMS_AB_DXA_PASSWORD                              = 0x808c001e,
	PR_EMS_AB_DXA_PASSWORD_UNICODE                      = 0x808c001f,
	PR_EMS_AB_DXA_PASSWORD_ERROR                        = 0x808c000a,
	PR_EMS_AB_DXA_PREV_EXCHANGE_OPTIONS                 = 0x808d0003,
	PR_EMS_AB_DXA_PREV_EXCHANGE_OPTIONS_ERROR           = 0x808d000a,
	PR_EMS_AB_DXA_PREV_EXPORT_NATIVE_ONLY               = 0x808e000b,
	PR_EMS_AB_DXA_PREV_EXPORT_NATIVE_ONLY_ERROR         = 0x808e000a,
	PR_EMS_AB_DXA_PREV_IN_EXCHANGE_SENSITIVITY          = 0x808f0003,
	PR_EMS_AB_DXA_PREV_IN_EXCHANGE_SENSITIVITY_ERROR    = 0x808f000a,
	PR_EMS_AB_DXA_PREV_REMOTE_ENTRIES_O                 = 0x8090000d,
	PR_EMS_AB_DXA_PREV_REMOTE_ENTRIES_O_ERROR           = 0x8090000a,
	PR_EMS_AB_DXA_PREV_REMOTE_ENTRIES                   = 0x8090001e,
	PR_EMS_AB_DXA_PREV_REMOTE_ENTRIES_UNICODE           = 0x8090001f,
	PR_EMS_AB_DXA_PREV_REPLICATION_SENSITIVITY          = 0x80910003,
	PR_EMS_AB_DXA_PREV_REPLICATION_SENSITIVITY_ERROR    = 0x8091000a,
	PR_EMS_AB_DXA_PREV_TEMPLATE_OPTIONS                 = 0x80920003,
	PR_EMS_AB_DXA_PREV_TEMPLATE_OPTIONS_ERROR           = 0x8092000a,
	PR_EMS_AB_DXA_PREV_TYPES                            = 0x80930003,
	PR_EMS_AB_DXA_PREV_TYPES_ERROR                      = 0x8093000a,
	PR_EMS_AB_DXA_RECIPIENT_CP                          = 0x8094001e,
	PR_EMS_AB_DXA_RECIPIENT_CP_UNICODE                  = 0x8094001f,
	PR_EMS_AB_DXA_RECIPIENT_CP_ERROR                    = 0x8094000a,
	PR_EMS_AB_DXA_REMOTE_CLIENT_O                       = 0x8095000d,
	PR_EMS_AB_DXA_REMOTE_CLIENT_O_ERROR                 = 0x8095000a,
	PR_EMS_AB_DXA_REMOTE_CLIENT                         = 0x8095001e,
	PR_EMS_AB_DXA_REMOTE_CLIENT_UNICODE                 = 0x8095001f,
	PR_EMS_AB_DXA_REQ_SEQ                               = 0x8096001e,
	PR_EMS_AB_DXA_REQ_SEQ_UNICODE                       = 0x8096001f,
	PR_EMS_AB_DXA_REQ_SEQ_ERROR                         = 0x8096000a,
	PR_EMS_AB_DXA_REQ_SEQ_TIME                          = 0x80970040,
	PR_EMS_AB_DXA_REQ_SEQ_TIME_ERROR                    = 0x8097000a,
	PR_EMS_AB_DXA_REQ_SEQ_USN                           = 0x80980003,
	PR_EMS_AB_DXA_REQ_SEQ_USN_ERROR                     = 0x8098000a,
	PR_EMS_AB_DXA_REQNAME                               = 0x8099001e,
	PR_EMS_AB_DXA_REQNAME_UNICODE                       = 0x8099001f,
	PR_EMS_AB_DXA_REQNAME_ERROR                         = 0x8099000a,
	PR_EMS_AB_DXA_SVR_SEQ                               = 0x809a001e,
	PR_EMS_AB_DXA_SVR_SEQ_UNICODE                       = 0x809a001f,
	PR_EMS_AB_DXA_SVR_SEQ_ERROR                         = 0x809a000a,
	PR_EMS_AB_DXA_SVR_SEQ_TIME                          = 0x809b0040,
	PR_EMS_AB_DXA_SVR_SEQ_TIME_ERROR                    = 0x809b000a,
	PR_EMS_AB_DXA_SVR_SEQ_USN                           = 0x809c0003,
	PR_EMS_AB_DXA_SVR_SEQ_USN_ERROR                     = 0x809c000a,
	PR_EMS_AB_DXA_TASK                                  = 0x809d0003,
	PR_EMS_AB_DXA_TASK_ERROR                            = 0x809d000a,
	PR_EMS_AB_DXA_TEMPLATE_OPTIONS                      = 0x809e0003,
	PR_EMS_AB_DXA_TEMPLATE_OPTIONS_ERROR                = 0x809e000a,
	PR_EMS_AB_DXA_TEMPLATE_TIMESTAMP                    = 0x809f0040,
	PR_EMS_AB_DXA_TEMPLATE_TIMESTAMP_ERROR              = 0x809f000a,
	PR_EMS_AB_DXA_TYPES                                 = 0x80a00003,
	PR_EMS_AB_DXA_TYPES_ERROR                           = 0x80a0000a,
	PR_EMS_AB_DXA_UNCONF_CONTAINER_LIST_O               = 0x80a1000d,
	PR_EMS_AB_DXA_UNCONF_CONTAINER_LIST_O_ERROR         = 0x80a1000a,
	PR_EMS_AB_DXA_UNCONF_CONTAINER_LIST                 = 0x80a1101e,
	PR_EMS_AB_DXA_UNCONF_CONTAINER_LIST_UNICODE         = 0x80a1101f,
	PR_EMS_AB_ENCAPSULATION_METHOD                      = 0x80a20003,
	PR_EMS_AB_ENCAPSULATION_METHOD_ERROR                = 0x80a2000a,
	PR_EMS_AB_ENCRYPT                                   = 0x80a3000b,
	PR_EMS_AB_ENCRYPT_ERROR                             = 0x80a3000a,
	PR_EMS_AB_EXPAND_DLS_LOCALLY                        = 0x80a4000b,
	PR_EMS_AB_EXPAND_DLS_LOCALLY_ERROR                  = 0x80a4000a,
	PR_EMS_AB_EXPORT_CONTAINERS_O                       = 0x80a5000d,
	PR_EMS_AB_EXPORT_CONTAINERS_O_ERROR                 = 0x80a5000a,
	PR_EMS_AB_EXPORT_CONTAINERS                         = 0x80a5101e,
	PR_EMS_AB_EXPORT_CONTAINERS_UNICODE                 = 0x80a5101f,
	PR_EMS_AB_EXPORT_CUSTOM_RECIPIENTS                  = 0x80a6000b,
	PR_EMS_AB_EXPORT_CUSTOM_RECIPIENTS_ERROR            = 0x80a6000a,
	PR_EMS_AB_EXTENDED_CHARS_ALLOWED                    = 0x80a7000b,
	PR_EMS_AB_EXTENDED_CHARS_ALLOWED_ERROR              = 0x80a7000a,
	PR_EMS_AB_EXTENSION_DATA                            = 0x80a81102,
	PR_EMS_AB_EXTENSION_DATA_ERROR                      = 0x80a8000a,
	PR_EMS_AB_EXTENSION_NAME                            = 0x80a9101e,
	PR_EMS_AB_EXTENSION_NAME_UNICODE                    = 0x80a9101f,
	PR_EMS_AB_EXTENSION_NAME_ERROR                      = 0x80a9000a,
	PR_EMS_AB_EXTENSION_NAME_INHERITED                  = 0x80aa101e,
	PR_EMS_AB_EXTENSION_NAME_INHERITED_UNICODE          = 0x80aa101f,
	PR_EMS_AB_EXTENSION_NAME_INHERITED_ERROR            = 0x80aa000a,
	PR_EMS_AB_FACSIMILE_TELEPHONE_NUMBER                = 0x80ab1102,
	PR_EMS_AB_FACSIMILE_TELEPHONE_NUMBER_ERROR          = 0x80ab000a,
	PR_EMS_AB_FILE_VERSION                              = 0x80ac0102,
	PR_EMS_AB_FILE_VERSION_ERROR                        = 0x80ac000a,
	PR_EMS_AB_FILTER_LOCAL_ADDRESSES                    = 0x80ad000b,
	PR_EMS_AB_FILTER_LOCAL_ADDRESSES_ERROR              = 0x80ad000a,
	PR_EMS_AB_FOLDERS_CONTAINER_O                       = 0x80ae000d,
	PR_EMS_AB_FOLDERS_CONTAINER_O_ERROR                 = 0x80ae000a,
	PR_EMS_AB_FOLDERS_CONTAINER                         = 0x80ae001e,
	PR_EMS_AB_FOLDERS_CONTAINER_UNICODE                 = 0x80ae001f,
	PR_EMS_AB_GARBAGE_COLL_PERIOD                       = 0x80af0003,
	PR_EMS_AB_GARBAGE_COLL_PERIOD_ERROR                 = 0x80af000a,
	PR_EMS_AB_GATEWAY_LOCAL_CRED                        = 0x80b0001e,
	PR_EMS_AB_GATEWAY_LOCAL_CRED_UNICODE                = 0x80b0001f,
	PR_EMS_AB_GATEWAY_LOCAL_CRED_ERROR                  = 0x80b0000a,
	PR_EMS_AB_GATEWAY_LOCAL_DESIG                       = 0x80b1001e,
	PR_EMS_AB_GATEWAY_LOCAL_DESIG_UNICODE               = 0x80b1001f,
	PR_EMS_AB_GATEWAY_LOCAL_DESIG_ERROR                 = 0x80b1000a,
	PR_EMS_AB_GATEWAY_PROXY                             = 0x80b2101e,
	PR_EMS_AB_GATEWAY_PROXY_UNICODE                     = 0x80b2101f,
	PR_EMS_AB_GATEWAY_PROXY_ERROR                       = 0x80b2000a,
	PR_EMS_AB_GATEWAY_ROUTING_TREE                      = 0x80b30102,
	PR_EMS_AB_GATEWAY_ROUTING_TREE_ERROR                = 0x80b3000a,
	PR_EMS_AB_GWART_LAST_MODIFIED                       = 0x80b40040,
	PR_EMS_AB_GWART_LAST_MODIFIED_ERROR                 = 0x80b4000a,
	PR_EMS_AB_HAS_FULL_REPLICA_NCS_O                    = 0x80b5000d,
	PR_EMS_AB_HAS_FULL_REPLICA_NCS_O_ERROR              = 0x80b5000a,
	PR_EMS_AB_HAS_FULL_REPLICA_NCS                      = 0x80b5101e,
	PR_EMS_AB_HAS_FULL_REPLICA_NCS_UNICODE              = 0x80b5101f,
	PR_EMS_AB_HAS_MASTER_NCS_O                          = 0x80b6000d,
	PR_EMS_AB_HAS_MASTER_NCS_O_ERROR                    = 0x80b6000a,
	PR_EMS_AB_HAS_MASTER_NCS                            = 0x80b6101e,
	PR_EMS_AB_HAS_MASTER_NCS_UNICODE                    = 0x80b6101f,
	PR_EMS_AB_HEURISTICS                                = 0x80b70003,
	PR_EMS_AB_HEURISTICS_ERROR                          = 0x80b7000a,
	PR_EMS_AB_HIDE_DL_MEMBERSHIP                        = 0x80b8000b,
	PR_EMS_AB_HIDE_DL_MEMBERSHIP_ERROR                  = 0x80b8000a,
	PR_EMS_AB_HIDE_FROM_ADDRESS_BOOK                    = 0x80b9000b,
	PR_EMS_AB_HIDE_FROM_ADDRESS_BOOK_ERROR              = 0x80b9000a,
	PR_EMS_AB_IMPORT_CONTAINER_O                        = 0x80ba000d,
	PR_EMS_AB_IMPORT_CONTAINER_O_ERROR                  = 0x80ba000a,
	PR_EMS_AB_IMPORT_CONTAINER                          = 0x80ba001e,
	PR_EMS_AB_IMPORT_CONTAINER_UNICODE                  = 0x80ba001f,
	PR_EMS_AB_IMPORT_SENSITIVITY                        = 0x80bb0003,
	PR_EMS_AB_IMPORT_SENSITIVITY_ERROR                  = 0x80bb000a,
	PR_EMS_AB_INBOUND_SITES_O                           = 0x80bc000d,
	PR_EMS_AB_INBOUND_SITES_O_ERROR                     = 0x80bc000a,
	PR_EMS_AB_INBOUND_SITES                             = 0x80bc101e,
	PR_EMS_AB_INBOUND_SITES_UNICODE                     = 0x80bc101f,
	PR_EMS_AB_INSTANCE_TYPE                             = 0x80bd0003,
	PR_EMS_AB_INSTANCE_TYPE_ERROR                       = 0x80bd000a,
	PR_EMS_AB_INTERNATIONAL_ISDN_NUMBER                 = 0x80be101e,
	PR_EMS_AB_INTERNATIONAL_ISDN_NUMBER_UNICODE         = 0x80be101f,
	PR_EMS_AB_INTERNATIONAL_ISDN_NUMBER_ERROR           = 0x80be000a,
	PR_EMS_AB_INVOCATION_ID                             = 0x80bf0102,
	PR_EMS_AB_INVOCATION_ID_ERROR                       = 0x80bf000a,
	PR_EMS_AB_IS_DELETED                                = 0x80c0000b,
	PR_EMS_AB_IS_DELETED_ERROR                          = 0x80c0000a,
	PR_EMS_AB_IS_SINGLE_VALUED                          = 0x80c1000b,
	PR_EMS_AB_IS_SINGLE_VALUED_ERROR                    = 0x80c1000a,
	PR_EMS_AB_KCC_STATUS                                = 0x80c21102,
	PR_EMS_AB_KCC_STATUS_ERROR                          = 0x80c2000a,
	PR_EMS_AB_KNOWLEDGE_INFORMATION                     = 0x80c3101e,
	PR_EMS_AB_KNOWLEDGE_INFORMATION_UNICODE             = 0x80c3101f,
	PR_EMS_AB_KNOWLEDGE_INFORMATION_ERROR               = 0x80c3000a,
	PR_EMS_AB_LINE_WRAP                                 = 0x80c40003,
	PR_EMS_AB_LINE_WRAP_ERROR                           = 0x80c4000a,
	PR_EMS_AB_LINK_ID                                   = 0x80c50003,
	PR_EMS_AB_LINK_ID_ERROR                             = 0x80c5000a,
	PR_EMS_AB_LOCAL_BRIDGE_HEAD                         = 0x80c6001e,
	PR_EMS_AB_LOCAL_BRIDGE_HEAD_UNICODE                 = 0x80c6001f,
	PR_EMS_AB_LOCAL_BRIDGE_HEAD_ERROR                   = 0x80c6000a,
	PR_EMS_AB_LOCAL_BRIDGE_HEAD_ADDRESS                 = 0x80c7001e,
	PR_EMS_AB_LOCAL_BRIDGE_HEAD_ADDRESS_UNICODE         = 0x80c7001f,
	PR_EMS_AB_LOCAL_BRIDGE_HEAD_ADDRESS_ERROR           = 0x80c7000a,
	PR_EMS_AB_LOCAL_INITIAL_TURN                        = 0x80c8000b,
	PR_EMS_AB_LOCAL_INITIAL_TURN_ERROR                  = 0x80c8000a,
	PR_EMS_AB_LOCAL_SCOPE_O                             = 0x80c9000d,
	PR_EMS_AB_LOCAL_SCOPE_O_ERROR                       = 0x80c9000a,
	PR_EMS_AB_LOCAL_SCOPE                               = 0x80c9101e,
	PR_EMS_AB_LOCAL_SCOPE_UNICODE                       = 0x80c9101f,
	PR_EMS_AB_LOG_FILENAME                              = 0x80ca001e,
	PR_EMS_AB_LOG_FILENAME_UNICODE                      = 0x80ca001f,
	PR_EMS_AB_LOG_FILENAME_ERROR                        = 0x80ca000a,
	PR_EMS_AB_LOG_ROLLOVER_INTERVAL                     = 0x80cb0003,
	PR_EMS_AB_LOG_ROLLOVER_INTERVAL_ERROR               = 0x80cb000a,
	PR_EMS_AB_MAINTAIN_AUTOREPLY_HISTORY                = 0x80cc000b,
	PR_EMS_AB_MAINTAIN_AUTOREPLY_HISTORY_ERROR          = 0x80cc000a,
	PR_EMS_AB_MAPI_DISPLAY_TYPE                         = 0x80cd0003,
	PR_EMS_AB_MAPI_DISPLAY_TYPE_ERROR                   = 0x80cd000a,
	PR_EMS_AB_MAPI_ID                                   = 0x80ce0003,
	PR_EMS_AB_MAPI_ID_ERROR                             = 0x80ce000a,
	PR_EMS_AB_MDB_BACKOFF_INTERVAL                      = 0x80cf0003,
	PR_EMS_AB_MDB_BACKOFF_INTERVAL_ERROR                = 0x80cf000a,
	PR_EMS_AB_MDB_MSG_TIME_OUT_PERIOD                   = 0x80d00003,
	PR_EMS_AB_MDB_MSG_TIME_OUT_PERIOD_ERROR             = 0x80d0000a,
	PR_EMS_AB_MDB_OVER_QUOTA_LIMIT                      = 0x80d10003,
	PR_EMS_AB_MDB_OVER_QUOTA_LIMIT_ERROR                = 0x80d1000a,
	PR_EMS_AB_MDB_STORAGE_QUOTA                         = 0x80d20003,
	PR_EMS_AB_MDB_STORAGE_QUOTA_ERROR                   = 0x80d2000a,
	PR_EMS_AB_MDB_UNREAD_LIMIT                          = 0x80d30003,
	PR_EMS_AB_MDB_UNREAD_LIMIT_ERROR                    = 0x80d3000a,
	PR_EMS_AB_MDB_USE_DEFAULTS                          = 0x80d4000b,
	PR_EMS_AB_MDB_USE_DEFAULTS_ERROR                    = 0x80d4000a,
	PR_EMS_AB_MESSAGE_TRACKING_ENABLED                  = 0x80d5000b,
	PR_EMS_AB_MESSAGE_TRACKING_ENABLED_ERROR            = 0x80d5000a,
	PR_EMS_AB_MONITOR_CLOCK                             = 0x80d6000b,
	PR_EMS_AB_MONITOR_CLOCK_ERROR                       = 0x80d6000a,
	PR_EMS_AB_MONITOR_SERVERS                           = 0x80d7000b,
	PR_EMS_AB_MONITOR_SERVERS_ERROR                     = 0x80d7000a,
	PR_EMS_AB_MONITOR_SERVICES                          = 0x80d8000b,
	PR_EMS_AB_MONITOR_SERVICES_ERROR                    = 0x80d8000a,
	PR_EMS_AB_MONITORED_CONFIGURATIONS_O                = 0x80d9000d,
	PR_EMS_AB_MONITORED_CONFIGURATIONS_O_ERROR          = 0x80d9000a,
	PR_EMS_AB_MONITORED_CONFIGURATIONS                  = 0x80d9101e,
	PR_EMS_AB_MONITORED_CONFIGURATIONS_UNICODE          = 0x80d9101f,
	PR_EMS_AB_MONITORED_SERVERS_O                       = 0x80da000d,
	PR_EMS_AB_MONITORED_SERVERS_O_ERROR                 = 0x80da000a,
	PR_EMS_AB_MONITORED_SERVERS                         = 0x80da101e,
	PR_EMS_AB_MONITORED_SERVERS_UNICODE                 = 0x80da101f,
	PR_EMS_AB_MONITORED_SERVICES                        = 0x80db101e,
	PR_EMS_AB_MONITORED_SERVICES_UNICODE                = 0x80db101f,
	PR_EMS_AB_MONITORED_SERVICES_ERROR                  = 0x80db000a,
	PR_EMS_AB_MONITORING_ALERT_DELAY                    = 0x80dc0003,
	PR_EMS_AB_MONITORING_ALERT_DELAY_ERROR              = 0x80dc000a,
	PR_EMS_AB_MONITORING_ALERT_UNITS                    = 0x80dd0003,
	PR_EMS_AB_MONITORING_ALERT_UNITS_ERROR              = 0x80dd000a,
	PR_EMS_AB_MONITORING_AVAILABILITY_STYLE             = 0x80de0003,
	PR_EMS_AB_MONITORING_AVAILABILITY_STYLE_ERROR       = 0x80de000a,
	PR_EMS_AB_MONITORING_AVAILABILITY_WINDOW            = 0x80df0102,
	PR_EMS_AB_MONITORING_AVAILABILITY_WINDOW_ERROR      = 0x80df000a,
	PR_EMS_AB_MONITORING_CACHED_VIA_MAIL_O              = 0x80e0000d,
	PR_EMS_AB_MONITORING_CACHED_VIA_MAIL_O_ERROR        = 0x80e0000a,
	PR_EMS_AB_MONITORING_CACHED_VIA_MAIL                = 0x80e0101e,
	PR_EMS_AB_MONITORING_CACHED_VIA_MAIL_UNICODE        = 0x80e0101f,
	PR_EMS_AB_MONITORING_CACHED_VIA_RPC_O               = 0x80e1000d,
	PR_EMS_AB_MONITORING_CACHED_VIA_RPC_O_ERROR         = 0x80e1000a,
	PR_EMS_AB_MONITORING_CACHED_VIA_RPC                 = 0x80e1101e,
	PR_EMS_AB_MONITORING_CACHED_VIA_RPC_UNICODE         = 0x80e1101f,
	PR_EMS_AB_MONITORING_ESCALATION_PROCEDURE           = 0x80e21102,
	PR_EMS_AB_MONITORING_ESCALATION_PROCEDURE_ERROR     = 0x80e2000a,
	PR_EMS_AB_MONITORING_HOTSITE_POLL_INTERVAL          = 0x80e30003,
	PR_EMS_AB_MONITORING_HOTSITE_POLL_INTERVAL_ERROR    = 0x80e3000a,
	PR_EMS_AB_MONITORING_HOTSITE_POLL_UNITS             = 0x80e40003,
	PR_EMS_AB_MONITORING_HOTSITE_POLL_UNITS_ERROR       = 0x80e4000a,
	PR_EMS_AB_MONITORING_MAIL_UPDATE_INTERVAL           = 0x80e50003,
	PR_EMS_AB_MONITORING_MAIL_UPDATE_INTERVAL_ERROR     = 0x80e5000a,
	PR_EMS_AB_MONITORING_MAIL_UPDATE_UNITS              = 0x80e60003,
	PR_EMS_AB_MONITORING_MAIL_UPDATE_UNITS_ERROR        = 0x80e6000a,
	PR_EMS_AB_MONITORING_NORMAL_POLL_INTERVAL           = 0x80e70003,
	PR_EMS_AB_MONITORING_NORMAL_POLL_INTERVAL_ERROR     = 0x80e7000a,
	PR_EMS_AB_MONITORING_NORMAL_POLL_UNITS              = 0x80e80003,
	PR_EMS_AB_MONITORING_NORMAL_POLL_UNITS_ERROR        = 0x80e8000a,
	PR_EMS_AB_MONITORING_RECIPIENTS_O                   = 0x80e9000d,
	PR_EMS_AB_MONITORING_RECIPIENTS_O_ERROR             = 0x80e9000a,
	PR_EMS_AB_MONITORING_RECIPIENTS                     = 0x80e9101e,
	PR_EMS_AB_MONITORING_RECIPIENTS_UNICODE             = 0x80e9101f,
	PR_EMS_AB_MONITORING_RECIPIENTS_NDR_O               = 0x80ea000d,
	PR_EMS_AB_MONITORING_RECIPIENTS_NDR_O_ERROR         = 0x80ea000a,
	PR_EMS_AB_MONITORING_RECIPIENTS_NDR                 = 0x80ea101e,
	PR_EMS_AB_MONITORING_RECIPIENTS_NDR_UNICODE         = 0x80ea101f,
	PR_EMS_AB_MONITORING_RPC_UPDATE_INTERVAL            = 0x80eb0003,
	PR_EMS_AB_MONITORING_RPC_UPDATE_INTERVAL_ERROR      = 0x80eb000a,
	PR_EMS_AB_MONITORING_RPC_UPDATE_UNITS               = 0x80ec0003,
	PR_EMS_AB_MONITORING_RPC_UPDATE_UNITS_ERROR         = 0x80ec000a,
	PR_EMS_AB_MONITORING_WARNING_DELAY                  = 0x80ed0003,
	PR_EMS_AB_MONITORING_WARNING_DELAY_ERROR            = 0x80ed000a,
	PR_EMS_AB_MONITORING_WARNING_UNITS                  = 0x80ee0003,
	PR_EMS_AB_MONITORING_WARNING_UNITS_ERROR            = 0x80ee000a,
	PR_EMS_AB_MTA_LOCAL_CRED                            = 0x80ef001e,
	PR_EMS_AB_MTA_LOCAL_CRED_UNICODE                    = 0x80ef001f,
	PR_EMS_AB_MTA_LOCAL_CRED_ERROR                      = 0x80ef000a,
	PR_EMS_AB_MTA_LOCAL_DESIG                           = 0x80f0001e,
	PR_EMS_AB_MTA_LOCAL_DESIG_UNICODE                   = 0x80f0001f,
	PR_EMS_AB_MTA_LOCAL_DESIG_ERROR                     = 0x80f0000a,
	PR_EMS_AB_N_ADDRESS                                 = 0x80f10102,
	PR_EMS_AB_N_ADDRESS_ERROR                           = 0x80f1000a,
	PR_EMS_AB_N_ADDRESS_TYPE                            = 0x80f20003,
	PR_EMS_AB_N_ADDRESS_TYPE_ERROR                      = 0x80f2000a,
	PR_EMS_AB_NT_MACHINE_NAME                           = 0x80f3001e,
	PR_EMS_AB_NT_MACHINE_NAME_UNICODE                   = 0x80f3001f,
	PR_EMS_AB_NT_MACHINE_NAME_ERROR                     = 0x80f3000a,
	PR_EMS_AB_NUM_OF_OPEN_RETRIES                       = 0x80f40003,
	PR_EMS_AB_NUM_OF_OPEN_RETRIES_ERROR                 = 0x80f4000a,
	PR_EMS_AB_NUM_OF_TRANSFER_RETRIES                   = 0x80f50003,
	PR_EMS_AB_NUM_OF_TRANSFER_RETRIES_ERROR             = 0x80f5000a,
	PR_EMS_AB_OBJECT_CLASS_CATEGORY                     = 0x80f60003,
	PR_EMS_AB_OBJECT_CLASS_CATEGORY_ERROR               = 0x80f6000a,
	PR_EMS_AB_OBJECT_VERSION                            = 0x80f70003,
	PR_EMS_AB_OBJECT_VERSION_ERROR                      = 0x80f7000a,
	PR_EMS_AB_OFF_LINE_AB_CONTAINERS_O                  = 0x80f8000d,
	PR_EMS_AB_OFF_LINE_AB_CONTAINERS_O_ERROR            = 0x80f8000a,
	PR_EMS_AB_OFF_LINE_AB_CONTAINERS                    = 0x80f8101e,
	PR_EMS_AB_OFF_LINE_AB_CONTAINERS_UNICODE            = 0x80f8101f,
	PR_EMS_AB_OFF_LINE_AB_SCHEDULE                      = 0x80f90102,
	PR_EMS_AB_OFF_LINE_AB_SCHEDULE_ERROR                = 0x80f9000a,
	PR_EMS_AB_OFF_LINE_AB_SERVER_O                      = 0x80fa000d,
	PR_EMS_AB_OFF_LINE_AB_SERVER_O_ERROR                = 0x80fa000a,
	PR_EMS_AB_OFF_LINE_AB_SERVER                        = 0x80fa001e,
	PR_EMS_AB_OFF_LINE_AB_SERVER_UNICODE                = 0x80fa001f,
	PR_EMS_AB_OFF_LINE_AB_STYLE                         = 0x80fb0003,
	PR_EMS_AB_OFF_LINE_AB_STYLE_ERROR                   = 0x80fb000a,
	PR_EMS_AB_OID_TYPE                                  = 0x80fc0003,
	PR_EMS_AB_OID_TYPE_ERROR                            = 0x80fc000a,
	PR_EMS_AB_OM_OBJECT_CLASS                           = 0x80fd0102,
	PR_EMS_AB_OM_OBJECT_CLASS_ERROR                     = 0x80fd000a,
	PR_EMS_AB_OM_SYNTAX                                 = 0x80fe0003,
	PR_EMS_AB_OM_SYNTAX_ERROR                           = 0x80fe000a,
	PR_EMS_AB_OOF_REPLY_TO_ORIGINATOR                   = 0x80ff000b,
	PR_EMS_AB_OOF_REPLY_TO_ORIGINATOR_ERROR             = 0x80ff000a,
	PR_EMS_AB_OPEN_RETRY_INTERVAL                       = 0x81000003,
	PR_EMS_AB_OPEN_RETRY_INTERVAL_ERROR                 = 0x8100000a,
	PR_EMS_AB_ORGANIZATION_NAME                         = 0x8101101e,
	PR_EMS_AB_ORGANIZATION_NAME_UNICODE                 = 0x8101101f,
	PR_EMS_AB_ORGANIZATION_NAME_ERROR                   = 0x8101000a,
	PR_EMS_AB_ORGANIZATIONAL_UNIT_NAME                  = 0x8102101e,
	PR_EMS_AB_ORGANIZATIONAL_UNIT_NAME_UNICODE          = 0x8102101f,
	PR_EMS_AB_ORGANIZATIONAL_UNIT_NAME_ERROR            = 0x8102000a,
	PR_EMS_AB_ORIGINAL_DISPLAY_TABLE                    = 0x81030102,
	PR_EMS_AB_ORIGINAL_DISPLAY_TABLE_ERROR              = 0x8103000a,
	PR_EMS_AB_ORIGINAL_DISPLAY_TABLE_MSDOS              = 0x81040102,
	PR_EMS_AB_ORIGINAL_DISPLAY_TABLE_MSDOS_ERROR        = 0x8104000a,
	PR_EMS_AB_OUTBOUND_SITES_O                          = 0x8105000d,
	PR_EMS_AB_OUTBOUND_SITES_O_ERROR                    = 0x8105000a,
	PR_EMS_AB_OUTBOUND_SITES                            = 0x8105101e,
	PR_EMS_AB_OUTBOUND_SITES_UNICODE                    = 0x8105101f,
	PR_EMS_AB_P_SELECTOR                                = 0x81060102,
	PR_EMS_AB_P_SELECTOR_ERROR                          = 0x8106000a,
	PR_EMS_AB_P_SELECTOR_INBOUND                        = 0x81070102,
	PR_EMS_AB_P_SELECTOR_INBOUND_ERROR                  = 0x8107000a,
	PR_EMS_AB_PER_MSG_DIALOG_DISPLAY_TABLE              = 0x81080102,
	PR_EMS_AB_PER_MSG_DIALOG_DISPLAY_TABLE_ERROR        = 0x8108000a,
	PR_EMS_AB_PER_RECIP_DIALOG_DISPLAY_TABLE            = 0x81090102,
	PR_EMS_AB_PER_RECIP_DIALOG_DISPLAY_TABLE_ERROR      = 0x8109000a,
	PR_EMS_AB_PERIOD_REP_SYNC_TIMES                     = 0x810a0102,
	PR_EMS_AB_PERIOD_REP_SYNC_TIMES_ERROR               = 0x810a000a,
	PR_EMS_AB_PERIOD_REPL_STAGGER                       = 0x810b0003,
	PR_EMS_AB_PERIOD_REPL_STAGGER_ERROR                 = 0x810b000a,
	PR_EMS_AB_POSTAL_ADDRESS                            = 0x810c1102,
	PR_EMS_AB_POSTAL_ADDRESS_ERROR                      = 0x810c000a,
	PR_EMS_AB_PREFERRED_DELIVERY_METHOD                 = 0x810d1003,
	PR_EMS_AB_PREFERRED_DELIVERY_METHOD_ERROR           = 0x810d000a,
	PR_EMS_AB_PRMD                                      = 0x810e001e,
	PR_EMS_AB_PRMD_UNICODE                              = 0x810e001f,
	PR_EMS_AB_PRMD_ERROR                                = 0x810e000a,
	PR_EMS_AB_PROXY_GENERATOR_DLL                       = 0x810f001e,
	PR_EMS_AB_PROXY_GENERATOR_DLL_UNICODE               = 0x810f001f,
	PR_EMS_AB_PROXY_GENERATOR_DLL_ERROR                 = 0x810f000a,
	PR_EMS_AB_PUBLIC_DELEGATES_BL_O                     = 0x8110000d,
	PR_EMS_AB_PUBLIC_DELEGATES_BL_O_ERROR               = 0x8110000a,
	PR_EMS_AB_PUBLIC_DELEGATES_BL                       = 0x8110101e,
	PR_EMS_AB_PUBLIC_DELEGATES_BL_UNICODE               = 0x8110101f,
	PR_EMS_AB_QUOTA_NOTIFICATION_SCHEDULE               = 0x81110102,
	PR_EMS_AB_QUOTA_NOTIFICATION_SCHEDULE_ERROR         = 0x8111000a,
	PR_EMS_AB_QUOTA_NOTIFICATION_STYLE                  = 0x81120003,
	PR_EMS_AB_QUOTA_NOTIFICATION_STYLE_ERROR            = 0x8112000a,
	PR_EMS_AB_RANGE_LOWER                               = 0x81130003,
	PR_EMS_AB_RANGE_LOWER_ERROR                         = 0x8113000a,
	PR_EMS_AB_RANGE_UPPER                               = 0x81140003,
	PR_EMS_AB_RANGE_UPPER_ERROR                         = 0x8114000a,
	PR_EMS_AB_RAS_CALLBACK_NUMBER                       = 0x8115001e,
	PR_EMS_AB_RAS_CALLBACK_NUMBER_UNICODE               = 0x8115001f,
	PR_EMS_AB_RAS_CALLBACK_NUMBER_ERROR                 = 0x8115000a,
	PR_EMS_AB_RAS_PHONE_NUMBER                          = 0x8116001e,
	PR_EMS_AB_RAS_PHONE_NUMBER_UNICODE                  = 0x8116001f,
	PR_EMS_AB_RAS_PHONE_NUMBER_ERROR                    = 0x8116000a,
	PR_EMS_AB_RAS_PHONEBOOK_ENTRY_NAME                  = 0x8117001e,
	PR_EMS_AB_RAS_PHONEBOOK_ENTRY_NAME_UNICODE          = 0x8117001f,
	PR_EMS_AB_RAS_PHONEBOOK_ENTRY_NAME_ERROR            = 0x8117000a,
	PR_EMS_AB_RAS_REMOTE_SRVR_NAME                      = 0x8118001e,
	PR_EMS_AB_RAS_REMOTE_SRVR_NAME_UNICODE              = 0x8118001f,
	PR_EMS_AB_RAS_REMOTE_SRVR_NAME_ERROR                = 0x8118000a,
	PR_EMS_AB_REGISTERED_ADDRESS                        = 0x81191102,
	PR_EMS_AB_REGISTERED_ADDRESS_ERROR                  = 0x8119000a,
	PR_EMS_AB_REMOTE_BRIDGE_HEAD                        = 0x811a001e,
	PR_EMS_AB_REMOTE_BRIDGE_HEAD_UNICODE                = 0x811a001f,
	PR_EMS_AB_REMOTE_BRIDGE_HEAD_ERROR                  = 0x811a000a,
	PR_EMS_AB_REMOTE_BRIDGE_HEAD_ADDRESS                = 0x811b001e,
	PR_EMS_AB_REMOTE_BRIDGE_HEAD_ADDRESS_UNICODE        = 0x811b001f,
	PR_EMS_AB_REMOTE_BRIDGE_HEAD_ADDRESS_ERROR          = 0x811b000a,
	PR_EMS_AB_REMOTE_OUT_BH_SERVER_O                    = 0x811c000d,
	PR_EMS_AB_REMOTE_OUT_BH_SERVER_O_ERROR              = 0x811c000a,
	PR_EMS_AB_REMOTE_OUT_BH_SERVER                      = 0x811c001e,
	PR_EMS_AB_REMOTE_OUT_BH_SERVER_UNICODE              = 0x811c001f,
	PR_EMS_AB_REMOTE_SITE_O                             = 0x811d000d,
	PR_EMS_AB_REMOTE_SITE_O_ERROR                       = 0x811d000a,
	PR_EMS_AB_REMOTE_SITE                               = 0x811d001e,
	PR_EMS_AB_REMOTE_SITE_UNICODE                       = 0x811d001f,
	PR_EMS_AB_REPLICATION_SENSITIVITY                   = 0x811e0003,
	PR_EMS_AB_REPLICATION_SENSITIVITY_ERROR             = 0x811e000a,
	PR_EMS_AB_REPLICATION_STAGGER                       = 0x811f0003,
	PR_EMS_AB_REPLICATION_STAGGER_ERROR                 = 0x811f000a,
	PR_EMS_AB_REPORT_TO_ORIGINATOR                      = 0x8120000b,
	PR_EMS_AB_REPORT_TO_ORIGINATOR_ERROR                = 0x8120000a,
	PR_EMS_AB_REPORT_TO_OWNER                           = 0x8121000b,
	PR_EMS_AB_REPORT_TO_OWNER_ERROR                     = 0x8121000a,
	PR_EMS_AB_REQ_SEQ                                   = 0x81220003,
	PR_EMS_AB_REQ_SEQ_ERROR                             = 0x8122000a,
	PR_EMS_AB_RESPONSIBLE_LOCAL_DXA_O                   = 0x8123000d,
	PR_EMS_AB_RESPONSIBLE_LOCAL_DXA_O_ERROR             = 0x8123000a,
	PR_EMS_AB_RESPONSIBLE_LOCAL_DXA                     = 0x8123001e,
	PR_EMS_AB_RESPONSIBLE_LOCAL_DXA_UNICODE             = 0x8123001f,
	PR_EMS_AB_RID_SERVER_O                              = 0x8124000d,
	PR_EMS_AB_RID_SERVER_O_ERROR                        = 0x8124000a,
	PR_EMS_AB_RID_SERVER                                = 0x8124001e,
	PR_EMS_AB_RID_SERVER_UNICODE                        = 0x8124001f,
	PR_EMS_AB_ROLE_OCCUPANT_O                           = 0x8125000d,
	PR_EMS_AB_ROLE_OCCUPANT_O_ERROR                     = 0x8125000a,
	PR_EMS_AB_ROLE_OCCUPANT                             = 0x8125101e,
	PR_EMS_AB_ROLE_OCCUPANT_UNICODE                     = 0x8125101f,
	PR_EMS_AB_ROUTING_LIST                              = 0x8126101e,
	PR_EMS_AB_ROUTING_LIST_UNICODE                      = 0x8126101f,
	PR_EMS_AB_ROUTING_LIST_ERROR                        = 0x8126000a,
	PR_EMS_AB_RTS_CHECKPOINT_SIZE                       = 0x81270003,
	PR_EMS_AB_RTS_CHECKPOINT_SIZE_ERROR                 = 0x8127000a,
	PR_EMS_AB_RTS_RECOVERY_TIMEOUT                      = 0x81280003,
	PR_EMS_AB_RTS_RECOVERY_TIMEOUT_ERROR                = 0x8128000a,
	PR_EMS_AB_RTS_WINDOW_SIZE                           = 0x81290003,
	PR_EMS_AB_RTS_WINDOW_SIZE_ERROR                     = 0x8129000a,
	PR_EMS_AB_RUNS_ON_O                                 = 0x812a000d,
	PR_EMS_AB_RUNS_ON_O_ERROR                           = 0x812a000a,
	PR_EMS_AB_RUNS_ON                                   = 0x812a101e,
	PR_EMS_AB_RUNS_ON_UNICODE                           = 0x812a101f,
	PR_EMS_AB_S_SELECTOR                                = 0x812b0102,
	PR_EMS_AB_S_SELECTOR_ERROR                          = 0x812b000a,
	PR_EMS_AB_S_SELECTOR_INBOUND                        = 0x812c0102,
	PR_EMS_AB_S_SELECTOR_INBOUND_ERROR                  = 0x812c000a,
	PR_EMS_AB_SEARCH_FLAGS                              = 0x812d0003,
	PR_EMS_AB_SEARCH_FLAGS_ERROR                        = 0x812d000a,
	PR_EMS_AB_SEARCH_GUIDE                              = 0x812e1102,
	PR_EMS_AB_SEARCH_GUIDE_ERROR                        = 0x812e000a,
	PR_EMS_AB_SEE_ALSO_O                                = 0x812f000d,
	PR_EMS_AB_SEE_ALSO_O_ERROR                          = 0x812f000a,
	PR_EMS_AB_SEE_ALSO                                  = 0x812f101e,
	PR_EMS_AB_SEE_ALSO_UNICODE                          = 0x812f101f,
	PR_EMS_AB_SERIAL_NUMBER                             = 0x8130101e,
	PR_EMS_AB_SERIAL_NUMBER_UNICODE                     = 0x8130101f,
	PR_EMS_AB_SERIAL_NUMBER_ERROR                       = 0x8130000a,
	PR_EMS_AB_SERVICE_ACTION_FIRST                      = 0x81310003,
	PR_EMS_AB_SERVICE_ACTION_FIRST_ERROR                = 0x8131000a,
	PR_EMS_AB_SERVICE_ACTION_OTHER                      = 0x81320003,
	PR_EMS_AB_SERVICE_ACTION_OTHER_ERROR                = 0x8132000a,
	PR_EMS_AB_SERVICE_ACTION_SECOND                     = 0x81330003,
	PR_EMS_AB_SERVICE_ACTION_SECOND_ERROR               = 0x8133000a,
	PR_EMS_AB_SERVICE_RESTART_DELAY                     = 0x81340003,
	PR_EMS_AB_SERVICE_RESTART_DELAY_ERROR               = 0x8134000a,
	PR_EMS_AB_SERVICE_RESTART_MESSAGE                   = 0x8135001e,
	PR_EMS_AB_SERVICE_RESTART_MESSAGE_UNICODE           = 0x8135001f,
	PR_EMS_AB_SERVICE_RESTART_MESSAGE_ERROR             = 0x8135000a,
	PR_EMS_AB_SESSION_DISCONNECT_TIMER                  = 0x81360003,
	PR_EMS_AB_SESSION_DISCONNECT_TIMER_ERROR            = 0x8136000a,
	PR_EMS_AB_SITE_AFFINITY                             = 0x8137101e,
	PR_EMS_AB_SITE_AFFINITY_UNICODE                     = 0x8137101f,
	PR_EMS_AB_SITE_AFFINITY_ERROR                       = 0x8137000a,
	PR_EMS_AB_SITE_PROXY_SPACE                          = 0x8138101e,
	PR_EMS_AB_SITE_PROXY_SPACE_UNICODE                  = 0x8138101f,
	PR_EMS_AB_SITE_PROXY_SPACE_ERROR                    = 0x8138000a,
	PR_EMS_AB_SPACE_LAST_COMPUTED                       = 0x81390040,
	PR_EMS_AB_SPACE_LAST_COMPUTED_ERROR                 = 0x8139000a,
	PR_EMS_AB_STREET_ADDRESS                            = 0x813a001e,
	PR_EMS_AB_STREET_ADDRESS_UNICODE                    = 0x813a001f,
	PR_EMS_AB_STREET_ADDRESS_ERROR                      = 0x813a000a,
	PR_EMS_AB_SUB_REFS_O                                = 0x813b000d,
	PR_EMS_AB_SUB_REFS_O_ERROR                          = 0x813b000a,
	PR_EMS_AB_SUB_REFS                                  = 0x813b101e,
	PR_EMS_AB_SUB_REFS_UNICODE                          = 0x813b101f,
	PR_EMS_AB_SUBMISSION_CONT_LENGTH                    = 0x813c0003,
	PR_EMS_AB_SUBMISSION_CONT_LENGTH_ERROR              = 0x813c000a,
	PR_EMS_AB_SUPPORTED_APPLICATION_CONTEXT             = 0x813d1102,
	PR_EMS_AB_SUPPORTED_APPLICATION_CONTEXT_ERROR       = 0x813d000a,
	PR_EMS_AB_SUPPORTING_STACK_O                        = 0x813e000d,
	PR_EMS_AB_SUPPORTING_STACK_O_ERROR                  = 0x813e000a,
	PR_EMS_AB_SUPPORTING_STACK                          = 0x813e101e,
	PR_EMS_AB_SUPPORTING_STACK_UNICODE                  = 0x813e101f,
	PR_EMS_AB_SUPPORTING_STACK_BL_O                     = 0x813f000d,
	PR_EMS_AB_SUPPORTING_STACK_BL_O_ERROR               = 0x813f000a,
	PR_EMS_AB_SUPPORTING_STACK_BL                       = 0x813f101e,
	PR_EMS_AB_SUPPORTING_STACK_BL_UNICODE               = 0x813f101f,
	PR_EMS_AB_T_SELECTOR                                = 0x81400102,
	PR_EMS_AB_T_SELECTOR_ERROR                          = 0x8140000a,
	PR_EMS_AB_T_SELECTOR_INBOUND                        = 0x81410102,
	PR_EMS_AB_T_SELECTOR_INBOUND_ERROR                  = 0x8141000a,
	PR_EMS_AB_TARGET_MTAS                               = 0x8142101e,
	PR_EMS_AB_TARGET_MTAS_UNICODE                       = 0x8142101f,
	PR_EMS_AB_TARGET_MTAS_ERROR                         = 0x8142000a,
	PR_EMS_AB_TELETEX_TERMINAL_IDENTIFIER               = 0x81431102,
	PR_EMS_AB_TELETEX_TERMINAL_IDENTIFIER_ERROR         = 0x8143000a,
	PR_EMS_AB_TEMP_ASSOC_THRESHOLD                      = 0x81440003,
	PR_EMS_AB_TEMP_ASSOC_THRESHOLD_ERROR                = 0x8144000a,
	PR_EMS_AB_TOMBSTONE_LIFETIME                        = 0x81450003,
	PR_EMS_AB_TOMBSTONE_LIFETIME_ERROR                  = 0x8145000a,
	PR_EMS_AB_TRACKING_LOG_PATH_NAME                    = 0x8146001e,
	PR_EMS_AB_TRACKING_LOG_PATH_NAME_UNICODE            = 0x8146001f,
	PR_EMS_AB_TRACKING_LOG_PATH_NAME_ERROR              = 0x8146000a,
	PR_EMS_AB_TRANS_RETRY_MINS                          = 0x81470003,
	PR_EMS_AB_TRANS_RETRY_MINS_ERROR                    = 0x8147000a,
	PR_EMS_AB_TRANS_TIMEOUT_MINS                        = 0x81480003,
	PR_EMS_AB_TRANS_TIMEOUT_MINS_ERROR                  = 0x8148000a,
	PR_EMS_AB_TRANSFER_RETRY_INTERVAL                   = 0x81490003,
	PR_EMS_AB_TRANSFER_RETRY_INTERVAL_ERROR             = 0x8149000a,
	PR_EMS_AB_TRANSFER_TIMEOUT_NON_URGENT               = 0x814a0003,
	PR_EMS_AB_TRANSFER_TIMEOUT_NON_URGENT_ERROR         = 0x814a000a,
	PR_EMS_AB_TRANSFER_TIMEOUT_NORMAL                   = 0x814b0003,
	PR_EMS_AB_TRANSFER_TIMEOUT_NORMAL_ERROR             = 0x814b000a,
	PR_EMS_AB_TRANSFER_TIMEOUT_URGENT                   = 0x814c0003,
	PR_EMS_AB_TRANSFER_TIMEOUT_URGENT_ERROR             = 0x814c000a,
	PR_EMS_AB_TRANSLATION_TABLE_USED                    = 0x814d0003,
	PR_EMS_AB_TRANSLATION_TABLE_USED_ERROR              = 0x814d000a,
	PR_EMS_AB_TRANSPORT_EXPEDITED_DATA                  = 0x814e000b,
	PR_EMS_AB_TRANSPORT_EXPEDITED_DATA_ERROR            = 0x814e000a,
	PR_EMS_AB_TRUST_LEVEL                               = 0x814f0003,
	PR_EMS_AB_TRUST_LEVEL_ERROR                         = 0x814f000a,
	PR_EMS_AB_TURN_REQUEST_THRESHOLD                    = 0x81500003,
	PR_EMS_AB_TURN_REQUEST_THRESHOLD_ERROR              = 0x8150000a,
	PR_EMS_AB_TWO_WAY_ALTERNATE_FACILITY                = 0x8151000b,
	PR_EMS_AB_TWO_WAY_ALTERNATE_FACILITY_ERROR          = 0x8151000a,
	PR_EMS_AB_UNAUTH_ORIG_BL_O                          = 0x8152000d,
	PR_EMS_AB_UNAUTH_ORIG_BL_O_ERROR                    = 0x8152000a,
	PR_EMS_AB_UNAUTH_ORIG_BL                            = 0x8152101e,
	PR_EMS_AB_UNAUTH_ORIG_BL_UNICODE                    = 0x8152101f,
	PR_EMS_AB_USER_PASSWORD                             = 0x81531102,
	PR_EMS_AB_USER_PASSWORD_ERROR                       = 0x8153000a,
	PR_EMS_AB_USN_CREATED                               = 0x81540003,
	PR_EMS_AB_USN_CREATED_ERROR                         = 0x8154000a,
	PR_EMS_AB_USN_DSA_LAST_OBJ_REMOVED                  = 0x81550003,
	PR_EMS_AB_USN_DSA_LAST_OBJ_REMOVED_ERROR            = 0x8155000a,
	PR_EMS_AB_USN_LAST_OBJ_REM                          = 0x81560003,
	PR_EMS_AB_USN_LAST_OBJ_REM_ERROR                    = 0x8156000a,
	PR_EMS_AB_USN_SOURCE                                = 0x81570003,
	PR_EMS_AB_USN_SOURCE_ERROR                          = 0x8157000a,
	PR_EMS_AB_X121_ADDRESS                              = 0x8158101e,
	PR_EMS_AB_X121_ADDRESS_UNICODE                      = 0x8158101f,
	PR_EMS_AB_X121_ADDRESS_ERROR                        = 0x8158000a,
	PR_EMS_AB_X25_CALL_USER_DATA_INCOMING               = 0x81590102,
	PR_EMS_AB_X25_CALL_USER_DATA_INCOMING_ERROR         = 0x8159000a,
	PR_EMS_AB_X25_CALL_USER_DATA_OUTGOING               = 0x815a0102,
	PR_EMS_AB_X25_CALL_USER_DATA_OUTGOING_ERROR         = 0x815a000a,
	PR_EMS_AB_X25_FACILITIES_DATA_INCOMING              = 0x815b0102,
	PR_EMS_AB_X25_FACILITIES_DATA_INCOMING_ERROR        = 0x815b000a,
	PR_EMS_AB_X25_FACILITIES_DATA_OUTGOING              = 0x815c0102,
	PR_EMS_AB_X25_FACILITIES_DATA_OUTGOING_ERROR        = 0x815c000a,
	PR_EMS_AB_X25_LEASED_LINE_PORT                      = 0x815d0102,
	PR_EMS_AB_X25_LEASED_LINE_PORT_ERROR                = 0x815d000a,
	PR_EMS_AB_X25_LEASED_OR_SWITCHED                    = 0x815e000b,
	PR_EMS_AB_X25_LEASED_OR_SWITCHED_ERROR              = 0x815e000a,
	PR_EMS_AB_X25_REMOTE_MTA_PHONE                      = 0x815f001e,
	PR_EMS_AB_X25_REMOTE_MTA_PHONE_UNICODE              = 0x815f001f,
	PR_EMS_AB_X25_REMOTE_MTA_PHONE_ERROR                = 0x815f000a,
	PR_EMS_AB_X400_ATTACHMENT_TYPE                      = 0x81600102,
	PR_EMS_AB_X400_ATTACHMENT_TYPE_ERROR                = 0x8160000a,
	PR_EMS_AB_X400_SELECTOR_SYNTAX                      = 0x81610003,
	PR_EMS_AB_X400_SELECTOR_SYNTAX_ERROR                = 0x8161000a,
	PR_EMS_AB_X500_ACCESS_CONTROL_LIST                  = 0x81620102,
	PR_EMS_AB_X500_ACCESS_CONTROL_LIST_ERROR            = 0x8162000a,
	PR_EMS_AB_XMIT_TIMEOUT_NON_URGENT                   = 0x81630003,
	PR_EMS_AB_XMIT_TIMEOUT_NON_URGENT_ERROR             = 0x8163000a,
	PR_EMS_AB_XMIT_TIMEOUT_NORMAL                       = 0x81640003,
	PR_EMS_AB_XMIT_TIMEOUT_NORMAL_ERROR                 = 0x8164000a,
	PR_EMS_AB_XMIT_TIMEOUT_URGENT                       = 0x81650003,
	PR_EMS_AB_XMIT_TIMEOUT_URGENT_ERROR                 = 0x8165000a,
	PR_EMS_AB_SITE_FOLDER_GUID                          = 0x81660102,
	PR_EMS_AB_SITE_FOLDER_GUID_ERROR                    = 0x8166000a,
	PR_EMS_AB_SITE_FOLDER_SERVER_O                      = 0x8167000d,
	PR_EMS_AB_SITE_FOLDER_SERVER_O_ERROR                = 0x8167000a,
	PR_EMS_AB_SITE_FOLDER_SERVER                        = 0x8167001e,
	PR_EMS_AB_SITE_FOLDER_SERVER_UNICODE                = 0x8167001f,
	PR_EMS_AB_REPLICATION_MAIL_MSG_SIZE                 = 0x81680003,
	PR_EMS_AB_REPLICATION_MAIL_MSG_SIZE_ERROR           = 0x8168000a,
	PR_EMS_AB_MAXIMUM_OBJECT_ID                         = 0x81690102,
	PR_EMS_AB_MAXIMUM_OBJECT_ID_ERROR                   = 0x8169000a,
	PR_EMS_AB_NETWORK_ADDRESS                           = 0x8170101e,
	PR_EMS_AB_NETWORK_ADDRESS_UNICODE                   = 0x8170101f,
	PR_EMS_AB_NETWORK_ADDRESS_ERROR                     = 0x8170000a,
	PR_EMS_AB_LDAP_DISPLAY_NAME                         = 0x8171101e,
	PR_EMS_AB_LDAP_DISPLAY_NAME_UNICODE                 = 0x8171101f,
	PR_EMS_AB_LDAP_DISPLAY_NAME_ERROR                   = 0x8171000a,
	PR_EMS_AB_SCHEMA_FLAGS                              = 0x81730003,
	PR_EMS_AB_SCHEMA_FLAGS_ERROR                        = 0x8173000a,
	PR_EMS_AB_BRIDGEHEAD_SERVERS_O                      = 0x8174000d,
	PR_EMS_AB_BRIDGEHEAD_SERVERS_O_ERROR                = 0x8174000a,
	PR_EMS_AB_BRIDGEHEAD_SERVERS                        = 0x8174101e,
	PR_EMS_AB_BRIDGEHEAD_SERVERS_UNICODE                = 0x8174101f,
	PR_EMS_AB_WWW_HOME_PAGE                             = 0x8175001e,
	PR_EMS_AB_WWW_HOME_PAGE_UNICODE                     = 0x8175001f,
	PR_EMS_AB_WWW_HOME_PAGE_ERROR                       = 0x8175000a,
	PR_EMS_AB_NNTP_CONTENT_FORMAT                       = 0x8176001e,
	PR_EMS_AB_NNTP_CONTENT_FORMAT_UNICODE               = 0x8176001f,
	PR_EMS_AB_NNTP_CONTENT_FORMAT_ERROR                 = 0x8176000a,
	PR_EMS_AB_POP_CONTENT_FORMAT                        = 0x8177001e,
	PR_EMS_AB_POP_CONTENT_FORMAT_UNICODE                = 0x8177001f,
	PR_EMS_AB_POP_CONTENT_FORMAT_ERROR                  = 0x8177000a,
	PR_EMS_AB_LANGUAGE                                  = 0x81780003,
	PR_EMS_AB_LANGUAGE_ERROR                            = 0x8178000a,
	PR_EMS_AB_POP_CHARACTER_SET                         = 0x8179001e,
	PR_EMS_AB_POP_CHARACTER_SET_UNICODE                 = 0x8179001f,
	PR_EMS_AB_POP_CHARACTER_SET_ERROR                   = 0x8179000a,
	PR_EMS_AB_USN_INTERSITE                             = 0x817a0003,
	PR_EMS_AB_USN_INTERSITE_ERROR                       = 0x817a000a,
	PR_EMS_AB_SUB_SITE                                  = 0x817b001e,
	PR_EMS_AB_SUB_SITE_UNICODE                          = 0x817b001f,
	PR_EMS_AB_SUB_SITE_ERROR                            = 0x817b000a,
	PR_EMS_AB_SCHEMA_VERSION                            = 0x817c1003,
	PR_EMS_AB_SCHEMA_VERSION_ERROR                      = 0x817c000a,
	PR_EMS_AB_NNTP_CHARACTER_SET                        = 0x817d001e,
	PR_EMS_AB_NNTP_CHARACTER_SET_UNICODE                = 0x817d001f,
	PR_EMS_AB_NNTP_CHARACTER_SET_ERROR                  = 0x817d000a,
	PR_EMS_AB_USE_SERVER_VALUES                         = 0x817e000b,
	PR_EMS_AB_USE_SERVER_VALUES_ERROR                   = 0x817e000a,
	PR_EMS_AB_ENABLED_PROTOCOLS                         = 0x817f0003,
	PR_EMS_AB_ENABLED_PROTOCOLS_ERROR                   = 0x817f000a,
	PR_EMS_AB_CONNECTION_LIST_FILTER                    = 0x81800102,
	PR_EMS_AB_CONNECTION_LIST_FILTER_ERROR              = 0x8180000a,
	PR_EMS_AB_AVAILABLE_AUTHORIZATION_PACKAGES          = 0x8181101e,
	PR_EMS_AB_AVAILABLE_AUTHORIZATION_PACKAGES_UNICODE  = 0x8181101f,
	PR_EMS_AB_AVAILABLE_AUTHORIZATION_PACKAGES_ERROR    = 0x8181000a,
	PR_EMS_AB_CHARACTER_SET_LIST                        = 0x8182101e,
	PR_EMS_AB_CHARACTER_SET_LIST_UNICODE                = 0x8182101f,
	PR_EMS_AB_CHARACTER_SET_LIST_ERROR                  = 0x8182000a,
	PR_EMS_AB_USE_SITE_VALUES                           = 0x8183000b,
	PR_EMS_AB_USE_SITE_VALUES_ERROR                     = 0x8183000a,
	PR_EMS_AB_ENABLED_AUTHORIZATION_PACKAGES            = 0x8184101e,
	PR_EMS_AB_ENABLED_AUTHORIZATION_PACKAGES_UNICODE    = 0x8184101f,
	PR_EMS_AB_ENABLED_AUTHORIZATION_PACKAGES_ERROR      = 0x8184000a,
	PR_EMS_AB_CHARACTER_SET                             = 0x8185001e,
	PR_EMS_AB_CHARACTER_SET_UNICODE                     = 0x8185001f,
	PR_EMS_AB_CHARACTER_SET_ERROR                       = 0x8185000a,
	PR_EMS_AB_CONTENT_TYPE                              = 0x81860003,
	PR_EMS_AB_CONTENT_TYPE_ERROR                        = 0x8186000a,
	PR_EMS_AB_ANONYMOUS_ACCESS                          = 0x8187000b,
	PR_EMS_AB_ANONYMOUS_ACCESS_ERROR                    = 0x8187000a,
	PR_EMS_AB_CONTROL_MSG_FOLDER_ID                     = 0x81880102,
	PR_EMS_AB_CONTROL_MSG_FOLDER_ID_ERROR               = 0x8188000a,
	PR_EMS_AB_USENET_SITE_NAME                          = 0x8189001e,
	PR_EMS_AB_USENET_SITE_NAME_UNICODE                  = 0x8189001f,
	PR_EMS_AB_USENET_SITE_NAME_ERROR                    = 0x8189000a,
	PR_EMS_AB_CONTROL_MSG_RULES                         = 0x818a0102,
	PR_EMS_AB_CONTROL_MSG_RULES_ERROR                   = 0x818a000a,
	PR_EMS_AB_AVAILABLE_DISTRIBUTIONS                   = 0x818b001e,
	PR_EMS_AB_AVAILABLE_DISTRIBUTIONS_UNICODE           = 0x818b001f,
	PR_EMS_AB_AVAILABLE_DISTRIBUTIONS_ERROR             = 0x818b000a,
	PR_EMS_AB_OUTBOUND_HOST                             = 0x818d0102,
	PR_EMS_AB_OUTBOUND_HOST_ERROR                       = 0x818d000a,
	PR_EMS_AB_INBOUND_HOST                              = 0x818e101e,
	PR_EMS_AB_INBOUND_HOST_UNICODE                      = 0x818e101f,
	PR_EMS_AB_INBOUND_HOST_ERROR                        = 0x818e000a,
	PR_EMS_AB_OUTGOING_MSG_SIZE_LIMIT                   = 0x818f0003,
	PR_EMS_AB_OUTGOING_MSG_SIZE_LIMIT_ERROR             = 0x818f000a,
	PR_EMS_AB_INCOMING_MSG_SIZE_LIMIT                   = 0x81900003,
	PR_EMS_AB_INCOMING_MSG_SIZE_LIMIT_ERROR             = 0x8190000a,
	PR_EMS_AB_SEND_TNEF                                 = 0x8191000b,
	PR_EMS_AB_SEND_TNEF_ERROR                           = 0x8191000a,
	PR_EMS_AB_AUTHORIZED_PASSWORD_CONFIRM               = 0x81920102,
	PR_EMS_AB_AUTHORIZED_PASSWORD_CONFIRM_ERROR         = 0x8192000a,
	PR_EMS_AB_INBOUND_NEWSFEED                          = 0x8193001e,
	PR_EMS_AB_INBOUND_NEWSFEED_UNICODE                  = 0x8193001f,
	PR_EMS_AB_INBOUND_NEWSFEED_ERROR                    = 0x8193000a,
	PR_EMS_AB_NEWSFEED_TYPE                             = 0x81940003,
	PR_EMS_AB_NEWSFEED_TYPE_ERROR                       = 0x8194000a,
	PR_EMS_AB_OUTBOUND_NEWSFEED                         = 0x8195001e,
	PR_EMS_AB_OUTBOUND_NEWSFEED_UNICODE                 = 0x8195001f,
	PR_EMS_AB_OUTBOUND_NEWSFEED_ERROR                   = 0x8195000a,
	PR_EMS_AB_NEWSGROUP_LIST                            = 0x81960102,
	PR_EMS_AB_NEWSGROUP_LIST_ERROR                      = 0x8196000a,
	PR_EMS_AB_NNTP_DISTRIBUTIONS                        = 0x8197101e,
	PR_EMS_AB_NNTP_DISTRIBUTIONS_UNICODE                = 0x8197101f,
	PR_EMS_AB_NNTP_DISTRIBUTIONS_ERROR                  = 0x8197000a,
	PR_EMS_AB_NEWSGROUP                                 = 0x8198001e,
	PR_EMS_AB_NEWSGROUP_UNICODE                         = 0x8198001f,
	PR_EMS_AB_NEWSGROUP_ERROR                           = 0x8198000a,
	PR_EMS_AB_MODERATOR                                 = 0x8199001e,
	PR_EMS_AB_MODERATOR_UNICODE                         = 0x8199001f,
	PR_EMS_AB_MODERATOR_ERROR                           = 0x8199000a,
	PR_EMS_AB_AUTHENTICATION_TO_USE                     = 0x819a001e,
	PR_EMS_AB_AUTHENTICATION_TO_USE_UNICODE             = 0x819a001f,
	PR_EMS_AB_AUTHENTICATION_TO_USE_ERROR               = 0x819a000a,
	PR_EMS_AB_HTTP_PUB_GAL                              = 0x819b000b,
	PR_EMS_AB_HTTP_PUB_GAL_ERROR                        = 0x819b000a,
	PR_EMS_AB_HTTP_PUB_GAL_LIMIT                        = 0x819c0003,
	PR_EMS_AB_HTTP_PUB_GAL_LIMIT_ERROR                  = 0x819c000a,
	PR_EMS_AB_HTTP_PUB_PF                               = 0x819e1102,
	PR_EMS_AB_HTTP_PUB_PF_ERROR                         = 0x819e000a,
	PR_EMS_AB_X500_RDN                                  = 0x81a1001e,
	PR_EMS_AB_X500_RDN_UNICODE                          = 0x81a1001f,
	PR_EMS_AB_X500_RDN_ERROR                            = 0x81a1000a,
	PR_EMS_AB_X500_NC                                   = 0x81a2001e,
	PR_EMS_AB_X500_NC_UNICODE                           = 0x81a2001f,
	PR_EMS_AB_X500_NC_ERROR                             = 0x81a2000a,
	PR_EMS_AB_REFERRAL_LIST                             = 0x81a3101e,
	PR_EMS_AB_REFERRAL_LIST_UNICODE                     = 0x81a3101f,
	PR_EMS_AB_REFERRAL_LIST_ERROR                       = 0x81a3000a,
	PR_EMS_AB_NNTP_DISTRIBUTIONS_FLAG                   = 0x81a4000b,
	PR_EMS_AB_NNTP_DISTRIBUTIONS_FLAG_ERROR             = 0x81a4000a,
	PR_EMS_AB_ASSOC_PROTOCOL_CFG_NNTP_O                 = 0x81a5000d,
	PR_EMS_AB_ASSOC_PROTOCOL_CFG_NNTP_O_ERROR           = 0x81a5000a,
	PR_EMS_AB_ASSOC_PROTOCOL_CFG_NNTP                   = 0x81a5001e,
	PR_EMS_AB_ASSOC_PROTOCOL_CFG_NNTP_UNICODE           = 0x81a5001f,
	PR_EMS_AB_NNTP_NEWSFEEDS_O                          = 0x81a6000d,
	PR_EMS_AB_NNTP_NEWSFEEDS_O_ERROR                    = 0x81a6000a,
	PR_EMS_AB_NNTP_NEWSFEEDS                            = 0x81a6101e,
	PR_EMS_AB_NNTP_NEWSFEEDS_UNICODE                    = 0x81a6101f,
	PR_EMS_AB_ENABLED_PROTOCOL_CFG                      = 0x81a8000b,
	PR_EMS_AB_ENABLED_PROTOCOL_CFG_ERROR                = 0x81a8000a,
	PR_EMS_AB_HTTP_PUB_AB_ATTRIBUTES                    = 0x81a9101e,
	PR_EMS_AB_HTTP_PUB_AB_ATTRIBUTES_UNICODE            = 0x81a9101f,
	PR_EMS_AB_HTTP_PUB_AB_ATTRIBUTES_ERROR              = 0x81a9000a,
	PR_EMS_AB_HTTP_SERVERS                              = 0x81ab101e,
	PR_EMS_AB_HTTP_SERVERS_UNICODE                      = 0x81ab101f,
	PR_EMS_AB_HTTP_SERVERS_ERROR                        = 0x81ab000a,
	PR_EMS_AB_MODERATED                                 = 0x81ac000b,
	PR_EMS_AB_MODERATED_ERROR                           = 0x81ac000a,
	PR_EMS_AB_RAS_ACCOUNT                               = 0x81ad001e,
	PR_EMS_AB_RAS_ACCOUNT_UNICODE                       = 0x81ad001f,
	PR_EMS_AB_RAS_ACCOUNT_ERROR                         = 0x81ad000a,
	PR_EMS_AB_RAS_PASSWORD                              = 0x81ae0102,
	PR_EMS_AB_RAS_PASSWORD_ERROR                        = 0x81ae000a,
	PR_EMS_AB_INCOMING_PASSWORD                         = 0x81af0102,
	PR_EMS_AB_INCOMING_PASSWORD_ERROR                   = 0x81af000a,
	PR_EMS_AB_OUTBOUND_HOST_TYPE                        = 0x81b0000b,
	PR_EMS_AB_OUTBOUND_HOST_TYPE_ERROR                  = 0x81b0000a,
	PR_EMS_AB_PROXY_GENERATION_ENABLED                  = 0x81b1000b,
	PR_EMS_AB_PROXY_GENERATION_ENABLED_ERROR            = 0x81b1000a,
	PR_EMS_AB_ROOT_NEWSGROUPS_FOLDER_ID                 = 0x81b20102,
	PR_EMS_AB_ROOT_NEWSGROUPS_FOLDER_ID_ERROR           = 0x81b2000a,
	PR_EMS_AB_CONNECTION_TYPE                           = 0x81b3000b,
	PR_EMS_AB_CONNECTION_TYPE_ERROR                     = 0x81b3000a,
	PR_EMS_AB_CONNECTION_LIST_FILTER_TYPE               = 0x81b40003,
	PR_EMS_AB_CONNECTION_LIST_FILTER_TYPE_ERROR         = 0x81b4000a,
	PR_EMS_AB_PORT_NUMBER                               = 0x81b50003,
	PR_EMS_AB_PORT_NUMBER_ERROR                         = 0x81b5000a,
	PR_EMS_AB_PROTOCOL_SETTINGS                         = 0x81b6101e,
	PR_EMS_AB_PROTOCOL_SETTINGS_UNICODE                 = 0x81b6101f,
	PR_EMS_AB_PROTOCOL_SETTINGS_ERROR                   = 0x81b6000a,
	PR_EMS_AB_GROUP_BY_ATTR_1                           = 0x81b7001e,
	PR_EMS_AB_GROUP_BY_ATTR_1_UNICODE                   = 0x81b7001f,
	PR_EMS_AB_GROUP_BY_ATTR_1_ERROR                     = 0x81b7000a,
	PR_EMS_AB_GROUP_BY_ATTR_2                           = 0x81b8001e,
	PR_EMS_AB_GROUP_BY_ATTR_2_UNICODE                   = 0x81b8001f,
	PR_EMS_AB_GROUP_BY_ATTR_2_ERROR                     = 0x81b8000a,
	PR_EMS_AB_GROUP_BY_ATTR_3                           = 0x81b9001e,
	PR_EMS_AB_GROUP_BY_ATTR_3_UNICODE                   = 0x81b9001f,
	PR_EMS_AB_GROUP_BY_ATTR_3_ERROR                     = 0x81b9000a,
	PR_EMS_AB_GROUP_BY_ATTR_4                           = 0x81ba001e,
	PR_EMS_AB_GROUP_BY_ATTR_4_UNICODE                   = 0x81ba001f,
	PR_EMS_AB_GROUP_BY_ATTR_4_ERROR                     = 0x81ba000a,
	PR_EMS_AB_VIEW_SITE                                 = 0x81be001e,
	PR_EMS_AB_VIEW_SITE_UNICODE                         = 0x81be001f,
	PR_EMS_AB_VIEW_SITE_ERROR                           = 0x81be000a,
	PR_EMS_AB_VIEW_CONTAINER_1                          = 0x81bf001e,
	PR_EMS_AB_VIEW_CONTAINER_1_UNICODE                  = 0x81bf001f,
	PR_EMS_AB_VIEW_CONTAINER_1_ERROR                    = 0x81bf000a,
	PR_EMS_AB_VIEW_CONTAINER_2                          = 0x81c0001e,
	PR_EMS_AB_VIEW_CONTAINER_2_UNICODE                  = 0x81c0001f,
	PR_EMS_AB_VIEW_CONTAINER_2_ERROR                    = 0x81c0000a,
	PR_EMS_AB_VIEW_CONTAINER_3                          = 0x81c1001e,
	PR_EMS_AB_VIEW_CONTAINER_3_UNICODE                  = 0x81c1001f,
	PR_EMS_AB_VIEW_CONTAINER_3_ERROR                    = 0x81c1000a,
	PR_EMS_AB_PROMO_EXPIRATION                          = 0x81c20040,
	PR_EMS_AB_PROMO_EXPIRATION_ERROR                    = 0x81c2000a,
	PR_EMS_AB_DISABLED_GATEWAY_PROXY                    = 0x81c3101e,
	PR_EMS_AB_DISABLED_GATEWAY_PROXY_UNICODE            = 0x81c3101f,
	PR_EMS_AB_DISABLED_GATEWAY_PROXY_ERROR              = 0x81c3000a,
	PR_EMS_AB_COMPROMISED_KEY_LIST                      = 0x81c40102,
	PR_EMS_AB_COMPROMISED_KEY_LIST_ERROR                = 0x81c4000a,
	PR_EMS_AB_INSADMIN_O                                = 0x81c5000d,
	PR_EMS_AB_INSADMIN_O_ERROR                          = 0x81c5000a,
	PR_EMS_AB_INSADMIN                                  = 0x81c5001e,
	PR_EMS_AB_INSADMIN_UNICODE                          = 0x81c5001f,
	PR_EMS_AB_OVERRIDE_NNTP_CONTENT_FORMAT              = 0x81c6000b,
	PR_EMS_AB_OVERRIDE_NNTP_CONTENT_FORMAT_ERROR        = 0x81c6000a,
	PR_EMS_AB_OBJ_VIEW_CONTAINERS_O                     = 0x81c7000d,
	PR_EMS_AB_OBJ_VIEW_CONTAINERS_O_ERROR               = 0x81c7000a,
	PR_EMS_AB_OBJ_VIEW_CONTAINERS                       = 0x81c7101e,
	PR_EMS_AB_OBJ_VIEW_CONTAINERS_UNICODE               = 0x81c7101f,
	PR_EMS_AB_VIEW_FLAGS                                = 0x8c180003,
	PR_EMS_AB_VIEW_FLAGS_ERROR                          = 0x8c18000a,
	PR_EMS_AB_GROUP_BY_ATTR_VALUE_STR                   = 0x8c19001e,
	PR_EMS_AB_GROUP_BY_ATTR_VALUE_STR_UNICODE           = 0x8c19001f,
	PR_EMS_AB_GROUP_BY_ATTR_VALUE_STR_ERROR             = 0x8c19000a,
	PR_EMS_AB_GROUP_BY_ATTR_VALUE_DN_O                  = 0x8c1a000d,
	PR_EMS_AB_GROUP_BY_ATTR_VALUE_DN_O_ERROR            = 0x8c1a000a,
	PR_EMS_AB_GROUP_BY_ATTR_VALUE_DN                    = 0x8c1a001e,
	PR_EMS_AB_GROUP_BY_ATTR_VALUE_DN_UNICODE            = 0x8c1a001f,
	PR_EMS_AB_VIEW_DEFINITION                           = 0x8c1b1102,
	PR_EMS_AB_VIEW_DEFINITION_ERROR                     = 0x8c1b000a,
	PR_EMS_AB_MIME_TYPES                                = 0x8c1c0102,
	PR_EMS_AB_MIME_TYPES_ERROR                          = 0x8c1c000a,
	PR_EMS_AB_LDAP_SEARCH_CFG                           = 0x8c1d0003,
	PR_EMS_AB_LDAP_SEARCH_CFG_ERROR                     = 0x8c1d000a,
	PR_EMS_AB_INBOUND_DN_O                              = 0x8c1e000d,
	PR_EMS_AB_INBOUND_DN_O_ERROR                        = 0x8c1e000a,
	PR_EMS_AB_INBOUND_DN                                = 0x8c1e001e,
	PR_EMS_AB_INBOUND_DN_UNICODE                        = 0x8c1e001f,
	PR_EMS_AB_INBOUND_NEWSFEED_TYPE                     = 0x8c1f000b,
	PR_EMS_AB_INBOUND_NEWSFEED_TYPE_ERROR               = 0x8c1f000a,
	PR_EMS_AB_INBOUND_ACCEPT_ALL                        = 0x8c20000b,
	PR_EMS_AB_INBOUND_ACCEPT_ALL_ERROR                  = 0x8c20000a,
	PR_EMS_AB_ENABLED                                   = 0x8c21000b,
	PR_EMS_AB_ENABLED_ERROR                             = 0x8c21000a,
	PR_EMS_AB_PRESERVE_INTERNET_CONTENT                 = 0x8c22000b,
	PR_EMS_AB_PRESERVE_INTERNET_CONTENT_ERROR           = 0x8c22000a,
	PR_EMS_AB_DISABLE_DEFERRED_COMMIT                   = 0x8c23000b,
	PR_EMS_AB_DISABLE_DEFERRED_COMMIT_ERROR             = 0x8c23000a,
	PR_EMS_AB_CLIENT_ACCESS_ENABLED                     = 0x8c24000b,
	PR_EMS_AB_CLIENT_ACCESS_ENABLED_ERROR               = 0x8c24000a,
	PR_EMS_AB_REQUIRE_SSL                               = 0x8c25000b,
	PR_EMS_AB_REQUIRE_SSL_ERROR                         = 0x8c25000a,
	PR_EMS_AB_ANONYMOUS_ACCOUNT                         = 0x8c26001e,
	PR_EMS_AB_ANONYMOUS_ACCOUNT_UNICODE                 = 0x8c26001f,
	PR_EMS_AB_ANONYMOUS_ACCOUNT_ERROR                   = 0x8c26000a,
	PR_EMS_AB_CERTIFICATE_CHAIN_V3                      = 0x8c270102,
	PR_EMS_AB_CERTIFICATE_CHAIN_V3_ERROR                = 0x8c27000a,
	PR_EMS_AB_CERTIFICATE_REVOCATION_LIST_V3            = 0x8c280102,
	PR_EMS_AB_CERTIFICATE_REVOCATION_LIST_V3_ERROR      = 0x8c28000a,
	PR_EMS_AB_CERTIFICATE_REVOCATION_LIST_V1            = 0x8c290102,
	PR_EMS_AB_CERTIFICATE_REVOCATION_LIST_V1_ERROR      = 0x8c29000a,
	PR_EMS_AB_CROSS_CERTIFICATE_CRL                     = 0x8c301102,
	PR_EMS_AB_CROSS_CERTIFICATE_CRL_ERROR               = 0x8c30000a,
	PR_EMS_AB_SEND_EMAIL_MESSAGE                        = 0x8c31000b,
	PR_EMS_AB_SEND_EMAIL_MESSAGE_ERROR                  = 0x8c31000a,
	PR_EMS_AB_ENABLE_COMPATIBILITY                      = 0x8c32000b,
	PR_EMS_AB_ENABLE_COMPATIBILITY_ERROR                = 0x8c32000a,
	PR_EMS_AB_SMIME_ALG_LIST_NA                         = 0x8c33101e,
	PR_EMS_AB_SMIME_ALG_LIST_NA_UNICODE                 = 0x8c33101f,
	PR_EMS_AB_SMIME_ALG_LIST_NA_ERROR                   = 0x8c33000a,
	PR_EMS_AB_SMIME_ALG_LIST_OTHER                      = 0x8c34101e,
	PR_EMS_AB_SMIME_ALG_LIST_OTHER_UNICODE              = 0x8c34101f,
	PR_EMS_AB_SMIME_ALG_LIST_OTHER_ERROR                = 0x8c34000a,
	PR_EMS_AB_SMIME_ALG_SELECTED_NA                     = 0x8c35001e,
	PR_EMS_AB_SMIME_ALG_SELECTED_NA_UNICODE             = 0x8c35001f,
	PR_EMS_AB_SMIME_ALG_SELECTED_NA_ERROR               = 0x8c35000a,
	PR_EMS_AB_SMIME_ALG_SELECTED_OTHER                  = 0x8c36001e,
	PR_EMS_AB_SMIME_ALG_SELECTED_OTHER_UNICODE          = 0x8c36001f,
	PR_EMS_AB_SMIME_ALG_SELECTED_OTHER_ERROR            = 0x8c36000a,
	PR_EMS_AB_DEFAULT_MESSAGE_FORMAT                    = 0x8c37000b,
	PR_EMS_AB_DEFAULT_MESSAGE_FORMAT_ERROR              = 0x8c37000a,
	PR_EMS_AB_TYPE                                      = 0x8c38001e,
	PR_EMS_AB_TYPE_UNICODE                              = 0x8c38001f,
	PR_EMS_AB_TYPE_ERROR                                = 0x8c38000a,
	PR_EMS_AB_DO_OAB_VERSION                            = 0x8c3a0003,
	PR_EMS_AB_DO_OAB_VERSION_ERROR                      = 0x8c3a000a,
	PR_EMS_AB_VOICE_MAIL_SYSTEM_GUID                    = 0x8c3b0102,
	PR_EMS_AB_VOICE_MAIL_SYSTEM_GUID_ERROR              = 0x8c3b000a,
	PR_EMS_AB_VOICE_MAIL_USER_ID                        = 0x8c3c001e,
	PR_EMS_AB_VOICE_MAIL_USER_ID_UNICODE                = 0x8c3c001f,
	PR_EMS_AB_VOICE_MAIL_USER_ID_ERROR                  = 0x8c3c000a,
	PR_EMS_AB_VOICE_MAIL_PASSWORD                       = 0x8c3d001e,
	PR_EMS_AB_VOICE_MAIL_PASSWORD_UNICODE               = 0x8c3d001f,
	PR_EMS_AB_VOICE_MAIL_PASSWORD_ERROR                 = 0x8c3d000a,
	PR_EMS_AB_VOICE_MAIL_RECORDED_NAME                  = 0x8c3e0102,
	PR_EMS_AB_VOICE_MAIL_RECORDED_NAME_ERROR            = 0x8c3e000a,
	PR_EMS_AB_VOICE_MAIL_GREETINGS                      = 0x8c3f101e,
	PR_EMS_AB_VOICE_MAIL_GREETINGS_UNICODE              = 0x8c3f101f,
	PR_EMS_AB_VOICE_MAIL_GREETINGS_ERROR                = 0x8c3f000a,
	PR_EMS_AB_VOICE_MAIL_FLAGS                          = 0x8c401102,
	PR_EMS_AB_VOICE_MAIL_FLAGS_ERROR                    = 0x8c40000a,
	PR_EMS_AB_VOICE_MAIL_VOLUME                         = 0x8c410003,
	PR_EMS_AB_VOICE_MAIL_VOLUME_ERROR                   = 0x8c41000a,
	PR_EMS_AB_VOICE_MAIL_SPEED                          = 0x8c420003,
	PR_EMS_AB_VOICE_MAIL_SPEED_ERROR                    = 0x8c42000a,
	PR_EMS_AB_VOICE_MAIL_RECORDING_LENGTH               = 0x8c431003,
	PR_EMS_AB_VOICE_MAIL_RECORDING_LENGTH_ERROR         = 0x8c43000a,
	PR_EMS_AB_DISPLAY_NAME_SUFFIX                       = 0x8c44001e,
	PR_EMS_AB_DISPLAY_NAME_SUFFIX_UNICODE               = 0x8c44001f,
	PR_EMS_AB_DISPLAY_NAME_SUFFIX_ERROR                 = 0x8c44000a,
	PR_EMS_AB_ATTRIBUTE_CERTIFICATE                     = 0x8c451102,
	PR_EMS_AB_ATTRIBUTE_CERTIFICATE_ERROR               = 0x8c45000a,
	PR_EMS_AB_DELTA_REVOCATION_LIST                     = 0x8c461102,
	PR_EMS_AB_DELTA_REVOCATION_LIST_ERROR               = 0x8c46000a,
	PR_EMS_AB_SECURITY_POLICY                           = 0x8c471102,
	PR_EMS_AB_SECURITY_POLICY_ERROR                     = 0x8c47000a,
	PR_EMS_AB_SUPPORT_SMIME_SIGNATURES                  = 0x8c48000b,
	PR_EMS_AB_SUPPORT_SMIME_SIGNATURES_ERROR            = 0x8c48000a,
	PR_EMS_AB_DELEGATE_USER                             = 0x8c49000b,
	PR_EMS_AB_DELEGATE_USER_ERROR                       = 0x8c49000a,
	PR_EMS_AB_LIST_PUBLIC_FOLDERS                       = 0x8c50000b,
	PR_EMS_AB_LIST_PUBLIC_FOLDERS_ERROR                 = 0x8c50000a,
	PR_EMS_AB_LABELEDURI                                = 0x8c51001e,
	PR_EMS_AB_LABELEDURI_UNICODE                        = 0x8c51001f,
	PR_EMS_AB_LABELEDURI_ERROR                          = 0x8c51000a,
	PR_EMS_AB_RETURN_EXACT_MSG_SIZE                     = 0x8c52000b,
	PR_EMS_AB_RETURN_EXACT_MSG_SIZE_ERROR               = 0x8c52000a,
	PR_EMS_AB_GENERATION_QUALIFIER                      = 0x8c53001e,
	PR_EMS_AB_GENERATION_QUALIFIER_UNICODE              = 0x8c53001f,
	PR_EMS_AB_GENERATION_QUALIFIER_ERROR                = 0x8c53000a,
	PR_EMS_AB_HOUSE_IDENTIFIER                          = 0x8c54001e,
	PR_EMS_AB_HOUSE_IDENTIFIER_UNICODE                  = 0x8c54001f,
	PR_EMS_AB_HOUSE_IDENTIFIER_ERROR                    = 0x8c54000a,
	PR_EMS_AB_SUPPORTED_ALGORITHMS                      = 0x8c550102,
	PR_EMS_AB_SUPPORTED_ALGORITHMS_ERROR                = 0x8c55000a,
	PR_EMS_AB_DMD_NAME                                  = 0x8c56001e,
	PR_EMS_AB_DMD_NAME_UNICODE                          = 0x8c56001f,
	PR_EMS_AB_DMD_NAME_ERROR                            = 0x8c56000a,
	PR_EMS_AB_EXTENSION_ATTRIBUTE_11                    = 0x8c57001e,
	PR_EMS_AB_EXTENSION_ATTRIBUTE_11_UNICODE            = 0x8c57001f,
	PR_EMS_AB_EXTENSION_ATTRIBUTE_11_ERROR              = 0x8c57000a,
	PR_EMS_AB_EXTENSION_ATTRIBUTE_12                    = 0x8c58001e,
	PR_EMS_AB_EXTENSION_ATTRIBUTE_12_UNICODE            = 0x8c58001f,
	PR_EMS_AB_EXTENSION_ATTRIBUTE_12_ERROR              = 0x8c58000a,
	PR_EMS_AB_EXTENSION_ATTRIBUTE_13                    = 0x8c59001e,
	PR_EMS_AB_EXTENSION_ATTRIBUTE_13_UNICODE            = 0x8c59001f,
	PR_EMS_AB_EXTENSION_ATTRIBUTE_13_ERROR              = 0x8c59000a,
	PR_EMS_AB_EXTENSION_ATTRIBUTE_14                    = 0x8c60001e,
	PR_EMS_AB_EXTENSION_ATTRIBUTE_14_UNICODE            = 0x8c60001f,
	PR_EMS_AB_EXTENSION_ATTRIBUTE_14_ERROR              = 0x8c60000a,
	PR_EMS_AB_EXTENSION_ATTRIBUTE_15                    = 0x8c61001e,
	PR_EMS_AB_EXTENSION_ATTRIBUTE_15_UNICODE            = 0x8c61001f,
	PR_EMS_AB_EXTENSION_ATTRIBUTE_15_ERROR              = 0x8c61000a,
	PR_EMS_AB_REPLICATED_OBJECT_VERSION                 = 0x8c620003,
	PR_EMS_AB_REPLICATED_OBJECT_VERSION_ERROR           = 0x8c62000a,
	PR_EMS_AB_MAIL_DROP                                 = 0x8c63001e,
	PR_EMS_AB_MAIL_DROP_UNICODE                         = 0x8c63001f,
	PR_EMS_AB_MAIL_DROP_ERROR                           = 0x8c63000a,
	PR_EMS_AB_FORWARDING_ADDRESS                        = 0x8c64001e,
	PR_EMS_AB_FORWARDING_ADDRESS_UNICODE                = 0x8c64001f,
	PR_EMS_AB_FORWARDING_ADDRESS_ERROR                  = 0x8c64000a,
	PR_EMS_AB_FORM_DATA                                 = 0x8c650102,
	PR_EMS_AB_FORM_DATA_ERROR                           = 0x8c65000a,
	PR_EMS_AB_OWA_SERVER                                = 0x8c66001e,
	PR_EMS_AB_OWA_SERVER_UNICODE                        = 0x8c66001f,
	PR_EMS_AB_OWA_SERVER_ERROR                          = 0x8c66000a,
	PR_EMS_AB_EMPLOYEE_NUMBER                           = 0x8c67001e,
	PR_EMS_AB_EMPLOYEE_NUMBER_UNICODE                   = 0x8c67001f,
	PR_EMS_AB_EMPLOYEE_NUMBER_ERROR                     = 0x8c67000a,
	PR_EMS_AB_TELEPHONE_PERSONAL_PAGER                  = 0x8c68001e,
	PR_EMS_AB_TELEPHONE_PERSONAL_PAGER_UNICODE          = 0x8c68001f,
	PR_EMS_AB_TELEPHONE_PERSONAL_PAGER_ERROR            = 0x8c68000a,
	PR_EMS_AB_EMPLOYEE_TYPE                             = 0x8c69001e,
	PR_EMS_AB_EMPLOYEE_TYPE_UNICODE                     = 0x8c69001f,
	PR_EMS_AB_EMPLOYEE_TYPE_ERROR                       = 0x8c69000a,
	PR_EMS_AB_TAGGED_X509_CERT                          = 0x8c6a1102,
	PR_EMS_AB_TAGGED_X509_CERT_ERROR                    = 0x8c6a000a,
	PR_EMS_AB_PERSONAL_TITLE                            = 0x8c6b001e,
	PR_EMS_AB_PERSONAL_TITLE_UNICODE                    = 0x8c6b001f,
	PR_EMS_AB_PERSONAL_TITLE_ERROR                      = 0x8c6b000a,
	PR_EMS_AB_LANGUAGE_ISO639                           = 0x8c6c001e,
	PR_EMS_AB_LANGUAGE_ISO639_UNICODE                   = 0x8c6c001f,
	PR_EMS_AB_LANGUAGE_ISO639_ERROR                     = 0x8c6c000a,
	PR_EMS_AB_OTHER_RECIPS                              = 0xf000000d,
	PR_EMS_AB_OTHER_RECIPS_ERROR                        = 0xf000000a,
	PR_EMS_AB_CHILD_RDNS                                = 0xfff8101e,
	PR_EMS_AB_CHILD_RDNS_UNICODE                        = 0xfff8101f,
	PR_EMS_AB_CHILD_RDNS_ERROR                          = 0xfff8000a,
	PR_EMS_AB_HIERARCHY_PATH                            = 0xfff9001e,
	PR_EMS_AB_HIERARCHY_PATH_UNICODE                    = 0xfff9001f,
	PR_EMS_AB_HIERARCHY_PATH_ERROR                      = 0xfff9000a,
	PR_EMS_AB_OBJECT_OID                                = 0xfffa0102,
	PR_EMS_AB_OBJECT_OID_ERROR                          = 0xfffa000a,
	PR_EMS_AB_IS_MASTER                                 = 0xfffb000b,
	PR_EMS_AB_IS_MASTER_ERROR                           = 0xfffb000a,
	PR_EMS_AB_PARENT_ENTRYID                            = 0xfffc0102,
	PR_EMS_AB_PARENT_ENTRYID_ERROR                      = 0xfffc000a,
	PR_EMS_AB_CONTAINERID                               = 0xfffd0003,
	PR_EMS_AB_CONTAINERID_ERROR                         = 0xfffd000a,
	PR_EMS_AB_SERVER                                    = 0xfffe001e,
	PR_EMS_AB_SERVER_UNICODE                            = 0xfffe001f,
	PR_EMS_AB_SERVER_ERROR                              = 0xfffe000a,
	MAPI_PROP_RESERVED                                  = 0xFFFFFFFF
} MAPITAGS;

